@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -29,21 +29,12 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     29/01/98
-// RCS-ID:      $Id: CFile.cpp,v 1.9.6.1.2.7 2004/05/31 22:02:46 fsch2010 Exp $
+// RCS-ID:      $Id: CFile.cpp,v 1.27 2004/08/13 15:50:58 HopeSeekr Exp $
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif // HAVE_CONFIG_H
-
-// Test if we have _GNU_SOURCE before the next step will mess up
-// setting __USE_GNU
-// (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
-#include "wx/setup.h"
-#include <errno.h>
-#include <string.h>
+#include <cerrno>                           // Needed for errno
 
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
@@ -57,10 +48,10 @@
 #endif
 
 // For compilers that support precompilation, includes "wx.h".
-#include "wx/wxprec.h"
-#include "CFile.h"
-#include "xmule.h"
-#include "xmuleDlg.h"
+#include "CFile.h"                          // needed for this interface's prototype
+
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for CxmuleDlg
 
 #ifdef __BORLANDC__
 #	pragma hdrstop
@@ -311,7 +302,7 @@ bool CFile::Open(const wxChar * szFileName, OpenMode mode, int accessMode)
     int fd = wxOpen(szFileName, flags ACCESS(accessMode));
     if (fd == - 1)
     {
-        theApp.xmuledlg -> AddLogLine(true, _("Can't open file '%s'"), szFileName);
+        theApp.xmuledlg->AddLogLine(true, _("Can't open file '%s'"), szFileName);
         return FALSE;
     }
     else
@@ -484,11 +475,11 @@ off_t CFile::Length() const
     if (iRc != - 1)
     {
         // @ have to use const_cast :-(
-        int iLen = ((CFile *) this) -> SeekEnd();
+        int iLen = ((CFile *) this)->SeekEnd();
         if (iLen != - 1)
         {
             // restore old position
-            if (((CFile *) this) -> Seek(iRc) == - 1)
+            if (((CFile *) this)->Seek(iRc) == - 1)
             {
                 // error
                 iLen = - 1;
