@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -17,18 +17,11 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// ColorFrameCtrl.cpp : implementation file
-//
-
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "wintypes.h"
-#	include "ColorFrameCtrl.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/dcclient.h>
-#include <wx/dc.h>
+#include "ColorFrameCtrl.h"                 // Needed for this Interface's Prototype
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -45,7 +38,7 @@ static char THIS_FILE[] = __FILE__;
 
 /////////////////////////////////////////////////////////////////////////////
 // CColorFrameCtrl
-CColorFrameCtrl:: CColorFrameCtrl(wxWindow *parent, int id, int wid, int hei)
+CColorFrameCtrl::CColorFrameCtrl(wxWindow *parent, int id, int wid, int hei)
 : wxControl(parent, id, wxDefaultPosition, wxSize(wid, hei)),
 m_brushBack(wxColour(0, 0, 0), wxSOLID),
 m_brushFrame(wxColour(0, 255, 255), wxSOLID)
@@ -60,7 +53,7 @@ m_brushFrame(wxColour(0, 255, 255), wxSOLID)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-CColorFrameCtrl:: ~CColorFrameCtrl()
+CColorFrameCtrl::~CColorFrameCtrl()
 {
     //m_brushFrame.DeleteObject() ;
     //m_brushBack.DeleteObject();
@@ -77,8 +70,8 @@ END_MESSAGE_MAP()
 #endif
 
 BEGIN_EVENT_TABLE(CColorFrameCtrl, wxControl)
-EVT_PAINT(CColorFrameCtrl:: OnPaint)
-EVT_SIZE(CColorFrameCtrl:: OnSize)
+EVT_PAINT(CColorFrameCtrl::OnPaint)
+EVT_SIZE(CColorFrameCtrl::OnSize)
 END_EVENT_TABLE()
 
 /////////////////////////////////////////////////////////////////////////////
@@ -86,15 +79,15 @@ END_EVENT_TABLE()
 
 #if 0
 /////////////////////////////////////////////////////////////////////////////
-BOOL CColorFrameCtrl:: Create(DWORD dwStyle, const RECT &rect,
+BOOL CColorFrameCtrl::Create(DWORD dwStyle, const RECT &rect,
 CWnd *pParentWnd, UINT nID)
 {
     BOOL result;
     static CString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
-    result = CWnd:: CreateEx(WS_EX_STATICEDGE,
+    result = CWnd::CreateEx(WS_EX_STATICEDGE,
     className, NULL, dwStyle,
     rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
-    pParentWnd -> GetSafeHwnd(), (HMENU) nID);
+    pParentWnd->GetSafeHwnd(), (HMENU) nID);
     if (result != 0)
     Invalidate();
     return result;
@@ -104,7 +97,7 @@ CWnd *pParentWnd, UINT nID)
 #endif
 
 /////////////////////////////////////////////////////////////////////////////
-void CColorFrameCtrl:: SetFrameColor(COLORREF color)
+void CColorFrameCtrl::SetFrameColor(COLORREF color)
 {
     m_crFrameColor = color;
     //m_brushFrame.DeleteObject() ;
@@ -119,7 +112,7 @@ void CColorFrameCtrl:: SetFrameColor(COLORREF color)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void CColorFrameCtrl:: SetBackgroundColor(COLORREF color)
+void CColorFrameCtrl::SetBackgroundColor(COLORREF color)
 {
     m_crBackColor = color;
     //m_brushBack.DeleteObject() ;
@@ -134,7 +127,7 @@ void CColorFrameCtrl:: SetBackgroundColor(COLORREF color)
 }
 
 ////////////////////////////////////////////////////////////////////////////
-void CColorFrameCtrl:: OnPaint(wxPaintEvent &evt)
+void CColorFrameCtrl::OnPaint(wxPaintEvent &evt)
 {
     //CPaintDC dc(this) ;  // device context for painting
     wxPaintDC dc(this);
@@ -170,7 +163,7 @@ void CColorFrameCtrl:: OnPaint(wxPaintEvent &evt)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void CColorFrameCtrl:: OnSize(wxSizeEvent &evt)
+void CColorFrameCtrl::OnSize(wxSizeEvent &evt)
 {
     //CWnd::OnSize(nType, cx, cy) ;
     // NOTE: OnSize automatically gets called during the setup of the control
