@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -24,15 +24,12 @@
 /////////////////////////////////////////////
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "wintypes.h"
-#	include "DirectoryTreeCtrl.h"
-#	include "otherfunctions.h"
-#	include "xmule.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/log.h>
+#include "DirectoryTreeCtrl.h"              // Needed for this Interface's Prototype
+
+#include <wx/log.h>                         // Needed for wxLogNull
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -50,7 +47,7 @@ static char THIS_FILE[] = __FILE__;
 #define HTREEITEM wxCTreeItemId
 
 IMPLEMENT_DYNAMIC_CLASS(CDirectoryTreeCtrl, wxCTreeCtrl)
-CDirectoryTreeCtrl:: CDirectoryTreeCtrl(wxWindow *parent, int id, const wxPoint &pos, wxSize siz, int flags)
+CDirectoryTreeCtrl::CDirectoryTreeCtrl(wxWindow *parent, int id, const wxPoint &pos, wxSize siz, int flags)
 : wxCTreeCtrl(parent, id, pos, siz, flags, wxDefaultValidator, "ShareTree"),
 m_image(16, 16)
 {
@@ -59,7 +56,7 @@ m_image(16, 16)
     Init();
 }
 
-CDirectoryTreeCtrl:: ~CDirectoryTreeCtrl()
+CDirectoryTreeCtrl::~CDirectoryTreeCtrl()
 {
 }
 
@@ -77,7 +74,7 @@ END_MESSAGE_MAP()
 
 // CDirectoryTreeCtrl message handlers
 
-void CDirectoryTreeCtrl:: OnTvnItemexpanding(wxCTreeEvent &evt)
+void CDirectoryTreeCtrl::OnTvnItemexpanding(wxCTreeEvent &evt)
 {
     //LPNMTREEVIEW pNMTreeView = reinterpret_cast<LPNMTREEVIEW>(pNMHDR);
     //int iAction = pNMTreeView->action;
@@ -94,7 +91,7 @@ void CDirectoryTreeCtrl:: OnTvnItemexpanding(wxCTreeEvent &evt)
     //*pResult = 0;
 }
 
-void CDirectoryTreeCtrl:: OnLButtonDown(wxCTreeEvent &evt)
+void CDirectoryTreeCtrl::OnLButtonDown(wxCTreeEvent &evt)
 {
     //VQB adjustments to provide for sharing or unsharing of subdirectories when control key is Down
     static int __counter = 0;
@@ -137,7 +134,7 @@ void CDirectoryTreeCtrl:: OnLButtonDown(wxCTreeEvent &evt)
     HasChanged = true;
 }
 
-void CDirectoryTreeCtrl:: MarkChilds(HTREEITEM hChild, bool mark)
+void CDirectoryTreeCtrl::MarkChilds(HTREEITEM hChild, bool mark)
 {
     static long int __counter = 1;
     CheckChanged(hChild, mark);
@@ -160,16 +157,16 @@ void CDirectoryTreeCtrl:: MarkChilds(HTREEITEM hChild, bool mark)
 }
 
 #if 0
-void CDirectoryTreeCtrl:: OnTvnGetdispinfo(NMHDR *pNMHDR, LRESULT *pResult)
+void CDirectoryTreeCtrl::OnTvnGetdispinfo(NMHDR *pNMHDR, LRESULT *pResult)
 {
     LPNMTVDISPINFO pTVDispInfo = reinterpret_cast < LPNMTVDISPINFO > (pNMHDR);
-    pTVDispInfo -> item.cChildren = 1;
+    pTVDispInfo->item.cChildren = 1;
     *pResult = 0;
 }
 
 #endif
 
-void CDirectoryTreeCtrl:: Init(void)
+void CDirectoryTreeCtrl::Init(void)
 {
 #if 0
     ShowWindow(SW_HIDE);
@@ -177,7 +174,7 @@ void CDirectoryTreeCtrl:: Init(void)
     ModifyStyle(0, TVS_CHECKBOXES);
     // START: added by FoRcHa /////////////
     // maybe causes problems on 98 & nt4:
-    WORD wWinVer = theApp.glob_prefs -> GetWindowsVersion();
+    WORD wWinVer = theApp.glob_prefs->GetWindowsVersion();
     if (wWinVer == _WINVER_2K_ || wWinVer == _WINVER_XP_ || wWinVer == _WINVER_ME_)
     {
         SHFILEINFO shFinfo;
@@ -194,7 +191,7 @@ void CDirectoryTreeCtrl:: Init(void)
     }
     ////////////////////////////////
     char drivebuffer[500];
-    :: GetLogicalDriveStrings(500, drivebuffer);
+    ::GetLogicalDriveStrings(500, drivebuffer);
     while (drivebuffer[0] != '\0')
     {
         char drive[4];
@@ -223,7 +220,7 @@ void CDirectoryTreeCtrl:: Init(void)
     HasChanged = false;
 }
 
-HTREEITEM CDirectoryTreeCtrl:: AddChildItem(HTREEITEM hRoot, wxString strText)
+HTREEITEM CDirectoryTreeCtrl::AddChildItem(HTREEITEM hRoot, wxString strText)
 {
     wxString strPath = GetFullPath(hRoot);
     if (hRoot.IsOk() &&strPath.Right(1) != "/")
@@ -239,11 +236,12 @@ HTREEITEM CDirectoryTreeCtrl:: AddChildItem(HTREEITEM hRoot, wxString strText)
     if (HasSubdirectories(strDir))
     // trick. will show +:
     AppendItem(item, ".");
+    return item;
 #if 0
     TV_INSERTSTRUCT itInsert;
     memset( &itInsert, 0, sizeof(itInsert));
     // START: changed by FoRcHa /////
-    WORD wWinVer = theApp.glob_prefs -> GetWindowsVersion();
+    WORD wWinVer = theApp.glob_prefs->GetWindowsVersion();
     if (wWinVer == _WINVER_2K_ || wWinVer == _WINVER_XP_ || wWinVer == _WINVER_ME_)
     {
         itInsert.item.mask = TVIF_CHILDREN | TVIF_HANDLE | TVIF_TEXT |
@@ -312,7 +310,7 @@ HTREEITEM CDirectoryTreeCtrl:: AddChildItem(HTREEITEM hRoot, wxString strText)
 #endif
 }
 
-wxString CDirectoryTreeCtrl:: GetFullPath(HTREEITEM hItem)
+wxString CDirectoryTreeCtrl::GetFullPath(HTREEITEM hItem)
 {
     wxString strDir;
     HTREEITEM hSearchItem = hItem;
@@ -326,7 +324,7 @@ wxString CDirectoryTreeCtrl:: GetFullPath(HTREEITEM hItem)
     return strDir;
 }
 
-void CDirectoryTreeCtrl:: AddSubdirectories(HTREEITEM hRoot, wxString strDir)
+void CDirectoryTreeCtrl::AddSubdirectories(HTREEITEM hRoot, wxString strDir)
 {
     if (strDir.Right(1) != "/")
     strDir += "/";
@@ -349,12 +347,12 @@ void CDirectoryTreeCtrl:: AddSubdirectories(HTREEITEM hRoot, wxString strDir)
         fname = wxFindNextFile();
     }
     // then add them
-    for (int i = 0 ; i < ary.GetCount() ; i++)
+    for (unsigned int i = 0 ; i < ary.GetCount() ; i++)
     {
         AddChildItem(hRoot, ary[i]);
     }
 #if 0
-    if (!:: SetCurrentDirectory(strDir))
+    if (!::SetCurrentDirectory(strDir))
     return;
     CFileFind finder;
     BOOL bWorking = finder.FindFile("*.*");
@@ -376,7 +374,7 @@ void CDirectoryTreeCtrl:: AddSubdirectories(HTREEITEM hRoot, wxString strDir)
 #endif
 }
 
-bool CDirectoryTreeCtrl:: HasSubdirectories(wxString strDir)
+bool CDirectoryTreeCtrl::HasSubdirectories(wxString strDir)
 {
     // prevent stupid log windows if we try to traverse somewhere we:
     wxLogNull logNo;
@@ -390,7 +388,7 @@ bool CDirectoryTreeCtrl:: HasSubdirectories(wxString strDir)
     // no match:
     return FALSE;
 #if 0
-    :: SetCurrentDirectory(strDir);
+    ::SetCurrentDirectory(strDir);
     CFileFind finder;
     BOOL bWorking = finder.FindFile("*.*");
     while (bWorking)
@@ -410,20 +408,20 @@ bool CDirectoryTreeCtrl:: HasSubdirectories(wxString strDir)
 #endif
 }
 
-void CDirectoryTreeCtrl:: GetSharedDirectories(wxArrayString *list)
+void CDirectoryTreeCtrl::GetSharedDirectories(wxArrayString *list)
 {
     //for (POSITION pos = m_lstShared.GetHeadPosition(); pos != NULL; )
-    for (int i = 0 ; i < m_lstShared.GetCount() ; i++)
-    list -> Add(m_lstShared[i]);
+    for (unsigned int i = 0 ; i < m_lstShared.GetCount() ; i++)
+    list->Add(m_lstShared[i]);
 }
 
-void CDirectoryTreeCtrl:: SetSharedDirectories(wxArrayString *list)
+void CDirectoryTreeCtrl::SetSharedDirectories(wxArrayString *list)
 {
     m_lstShared.Clear();
-    for (int i = 0 ; i < list -> GetCount() ; i++)
+    for (unsigned int i = 0 ; i < list->GetCount() ; i++)
     {
         //list->GetNext(pos);:
-        wxString str = list -> Item(i);
+        wxString str = list->Item(i);
         if (str.Right(1) != '/')
         str += '/';
         m_lstShared.Add(str);
@@ -431,12 +429,12 @@ void CDirectoryTreeCtrl:: SetSharedDirectories(wxArrayString *list)
     //  Init();
 }
 
-bool CDirectoryTreeCtrl:: HasSharedSubdirectory(wxString strDir)
+bool CDirectoryTreeCtrl::HasSharedSubdirectory(wxString strDir)
 {
     if (strDir.Right(1) != '/')
     strDir += "/";
     strDir.MakeLower();
-    for (int i = 0 ; i < m_lstShared.GetCount() ; i++)
+    for (unsigned int i = 0 ; i < m_lstShared.GetCount() ; i++)
     {
         //.GetNext(pos);:
         wxString str = m_lstShared[i];
@@ -448,7 +446,7 @@ bool CDirectoryTreeCtrl:: HasSharedSubdirectory(wxString strDir)
     return false;
 }
 
-void CDirectoryTreeCtrl:: CheckChanged(HTREEITEM hItem, bool bChecked)
+void CDirectoryTreeCtrl::CheckChanged(HTREEITEM hItem, bool bChecked)
 {
     wxString strDir = GetFullPath(hItem);
     if (bChecked)
@@ -457,15 +455,15 @@ void CDirectoryTreeCtrl:: CheckChanged(HTREEITEM hItem, bool bChecked)
     DelShare(strDir);
 #if 0
     UpdateParentItems(hItem);
-    GetItemParent() -> SendMessage(WM_COMMAND, USRMSG_ITEMSTATECHANGED, (long) m_hWnd);
+    GetItemParent()->SendMessage(WM_COMMAND, USRMSG_ITEMSTATECHANGED, (long) m_hWnd);
 #endif
 }
 
-bool CDirectoryTreeCtrl:: IsShared(wxString strDir)
+bool CDirectoryTreeCtrl::IsShared(wxString strDir)
 {
     if (strDir.Right(1) != '/')
     strDir += '/';
-    for (int i = 0 ; i < m_lstShared.GetCount() ; i++)
+    for (unsigned int i = 0 ; i < m_lstShared.GetCount() ; i++)
     {
         wxString str = m_lstShared[i];
         if (str.Right(1) != '/')
@@ -476,7 +474,7 @@ bool CDirectoryTreeCtrl:: IsShared(wxString strDir)
     return false;
 }
 
-void CDirectoryTreeCtrl:: AddShare(wxString strDir)
+void CDirectoryTreeCtrl::AddShare(wxString strDir)
 {
     if (strDir.Right(1) != '/')
     strDir += '/';
@@ -485,14 +483,14 @@ void CDirectoryTreeCtrl:: AddShare(wxString strDir)
     m_lstShared.Add(strDir);
 }
 
-void CDirectoryTreeCtrl:: DelShare(wxString strDir)
+void CDirectoryTreeCtrl::DelShare(wxString strDir)
 {
     if (strDir.Right(1) != '/')
     strDir += '/';
     m_lstShared.Remove(strDir.GetData());
 }
 
-void CDirectoryTreeCtrl:: UpdateParentItems(HTREEITEM hChild)
+void CDirectoryTreeCtrl::UpdateParentItems(HTREEITEM hChild)
 {
 #if 0
     HTREEITEM hSearch = GetItemParentItem(hChild);
@@ -508,11 +506,11 @@ void CDirectoryTreeCtrl:: UpdateParentItems(HTREEITEM hChild)
 }
 
 #if 0
-void CDirectoryTreeCtrl:: OnNMRclickSharedList(NMHDR *pNMHDR, LRESULT *pResult)
+void CDirectoryTreeCtrl::OnNMRclickSharedList(NMHDR *pNMHDR, LRESULT *pResult)
 {
     // get item under cursor
     POINT point;
-    :: GetCursorPos( &point);
+    ::GetCursorPos( &point);
     CPoint p = point;
     ScreenToClient( &p);
     HTREEITEM hItem = HitTest(p);
@@ -542,7 +540,7 @@ void CDirectoryTreeCtrl:: OnNMRclickSharedList(NMHDR *pNMHDR, LRESULT *pResult)
 #endif
 
 #if 0
-BOOL CDirectoryTreeCtrl:: OnCommand(WPARAM wParam, LPARAM lParam)
+BOOL CDirectoryTreeCtrl::OnCommand(WPARAM wParam, LPARAM lParam)
 {
     if (wParam < MP_SHAREDFOLDERS_FIRST)
     {
@@ -565,7 +563,7 @@ BOOL CDirectoryTreeCtrl:: OnCommand(WPARAM wParam, LPARAM lParam)
 
 #endif
 
-bool CDirectoryTreeCtrl:: ProcessEvent(wxEvent &evt)
+bool CDirectoryTreeCtrl::ProcessEvent(wxEvent &evt)
 {
     if (evt.GetEventType() == wxEVT_COMMAND_CTREE_ITEM_EXPANDING)
     {
@@ -577,6 +575,6 @@ bool CDirectoryTreeCtrl:: ProcessEvent(wxEvent &evt)
         OnLButtonDown((wxCTreeEvent &) evt);
         return true;
     }
-    return wxCTreeCtrl:: ProcessEvent(evt);
+    return wxCTreeCtrl::ProcessEvent(evt);
 }
 
