@@ -1,48 +1,45 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // parts of this file are based on work from pan One (http://home-3.tiscali.nl/~meost/pms/)
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "ini2.h"
-#	include "KnownFile.h"
-#	include "KnownFileList.h"
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#	include "Preferences.h"
-#	include "SharedFileList.h"
-#	include "SharedFilesWnd.h"
-#	include "updownclient.h"
-#	include "UploadQueue.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <sys/stat.h>                       // Needed for stat
 
-extern MAP * listof_sourcesKF;
+#include "KnownFile.h"
 
-// constants for MD4Transform
+#include "PartFile.h"                       // Needed for PR_HIGH
+#include "ini2.h"                           // Needed for CIni
+#include "KnownFileList.h"                  // Needed for CKnownFileList
+#include "otherfunctions.h"                 // Needed for nstrdup
+#include "SharedFileList.h"                 // Needed for UpdateItem
+#include "SharedFilesWnd.h"                 // Needed for CSharedFilesWnd
+#include "updownclient.h"                   // Needed for IsUpPartAvailable
+#include "UploadQueue.h"                    // Needed for FindSourcesForFileById
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for CxmuleDlg
+
+// constants for MD42Transform
 #define S11 3
 #define S12 7
 #define S13 11
@@ -56,33 +53,33 @@ extern MAP * listof_sourcesKF;
 #define S33 11
 #define S34 15
 
-static void MD4Transform(uint32 Hash[4], uint32 x[16]);
+static void MD42Transform(uint32 Hash[4], uint32 x[16]);
 
-void CFileStatistic:: AddRequest()
+void CFileStatistic::AddRequest()
 {
     requested++;
     alltimerequested++;
-    theApp.knownfiles -> requested++;
-    theApp.sharedfiles -> UpdateItem(fileParent);
+    theApp.knownfiles->requested++;
+    theApp.sharedfiles->UpdateItem(fileParent);
 }
 
-void CFileStatistic:: AddAccepted()
+void CFileStatistic::AddAccepted()
 {
     accepted++;
     alltimeaccepted++;
-    theApp.knownfiles -> accepted++;
-    theApp.sharedfiles -> UpdateItem(fileParent);
+    theApp.knownfiles->accepted++;
+    theApp.sharedfiles->UpdateItem(fileParent);
 }
 
-void CFileStatistic:: AddTransferred(uint64 bytes)
+void CFileStatistic::AddTransferred(uint64 bytes)
 {
     transfered += bytes;
     alltimetransfered += bytes;
-    theApp.knownfiles -> transfered += bytes;
-    theApp.sharedfiles -> UpdateItem(fileParent);
+    theApp.knownfiles->transfered += bytes;
+    theApp.sharedfiles->UpdateItem(fileParent);
 }
 
-CKnownFile:: CKnownFile()
+CKnownFile::CKnownFile()
 {
     m_iFileType = 2;
     directory = NULL;
@@ -91,7 +88,7 @@ CKnownFile:: CKnownFile()
     date = 0;
     m_iPermissions = PERM_ALL;
     statistic.fileParent = this;
-    if (theApp.glob_prefs -> GetNewAutoUp())
+    if (theApp.glob_prefs->GetNewAutoUp())
     {
         m_iUpPriority = PR_HIGH;
         m_bAutoUpPriority = true;
@@ -108,7 +105,7 @@ CKnownFile:: CKnownFile()
     m_iPartCount = 0;
 }
 
-CKnownFile:: ~CKnownFile()
+CKnownFile::~CKnownFile()
 {
     for (int i = 0 ; i != hashlist.GetSize() ; i++)
     if (hashlist[i])
@@ -122,9 +119,9 @@ CKnownFile:: ~CKnownFile()
     m_AvailPartFrequency.RemoveAll();
 }
 
-CBarShader CKnownFile:: s_ShareStatusBar(16);
+CBarShader CKnownFile::s_ShareStatusBar(16);
 
-void CKnownFile:: DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
+void CKnownFile::DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
  /*
  DWORD crBoth;
@@ -164,7 +161,7 @@ void CKnownFile:: DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, b
     s_ShareStatusBar.Draw(dc, rect.GetLeft(), rect.GetTop(), bFlat);
 }
 
-void CKnownFile:: NewAvailPartsInfo()
+void CKnownFile::NewAvailPartsInfo()
 {
     // Cache part count
     uint16 partcount = GetPartCount();
@@ -176,21 +173,21 @@ void CKnownFile:: NewAvailPartsInfo()
         m_AvailPartFrequency.Add(0);
     }
     CUpDownClient *cur_src;
-    if (this -> IsPartFile())
+    if (this->IsPartFile())
     cur_src = NULL;
     for (POSITION pos = m_ClientUploadList.GetHeadPosition() ; pos != 0 ;)
     {
         cur_src = m_ClientUploadList.GetNext(pos);
         for (int i = 0 ; i != partcount ; i++)
         {
-            if (cur_src -> IsUpPartAvailable(i))
+            if (cur_src->IsUpPartAvailable(i))
             m_AvailPartFrequency[i] += 1;
         }
     }
-    theApp.xmuledlg -> sharedfileswnd -> sharedfilesctrl -> UpdateItem(this);
+    theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
 }
 
-void CKnownFile:: AddUploadingClient(CUpDownClient *client)
+void CKnownFile::AddUploadingClient(CUpDownClient *client)
 {
     // to be sure:
     POSITION pos = m_ClientUploadList.Find(client);
@@ -200,7 +197,7 @@ void CKnownFile:: AddUploadingClient(CUpDownClient *client)
     }
 }
 
-void CKnownFile:: RemoveUploadingClient(CUpDownClient *client)
+void CKnownFile::RemoveUploadingClient(CUpDownClient *client)
 {
     // to be sure:
     POSITION pos = m_ClientUploadList.Find(client);
@@ -210,14 +207,14 @@ void CKnownFile:: RemoveUploadingClient(CUpDownClient *client)
     }
 }
 
-void CKnownFile:: SetPath(char *path)
+void CKnownFile::SetPath(char *path)
 {
     if (directory)
     delete[] directory;
     directory = nstrdup(path);
 }
 
-bool CKnownFile:: CreateFromFile(char *in_directory, char *in_filename, volatile int const *notify)
+bool CKnownFile::CreateFromFile(char *in_directory, char *in_filename, volatile int const *notify)
 {
     // TODO Errorhandling
     //first create the filehashset
@@ -287,16 +284,16 @@ bool CKnownFile:: CreateFromFile(char *in_directory, char *in_filename, volatile
 }
 
 // needed for memfiles. its probably better to switch everything to CFile...
-bool CKnownFile:: LoadHashsetFromFile(CFile *file, bool checkhash)
+bool CKnownFile::LoadHashsetFromFile(CFile *file, bool checkhash)
 {
     uchar checkid[16];
-    file -> Read( &checkid, 16);
+    file->Read( &checkid, 16);
     uint16 parts;
-    file -> Read( &parts, 2);
+    file->Read( &parts, 2);
     for (int i = 0 ; i != parts ; i++)
     {
         uchar *cur_hash = new uchar[16];
-        file -> Read(cur_hash, 16);
+        file->Read(cur_hash, 16);
         hashlist.Add(cur_hash);
     }
     if (!checkhash)
@@ -328,29 +325,29 @@ bool CKnownFile:: LoadHashsetFromFile(CFile *file, bool checkhash)
     }
 }
 
-bool CKnownFile:: LoadTagsFromFile(CFile *file)
+bool CKnownFile::LoadTagsFromFile(CFile *file)
 {
     try
     {
         uint32 tagcount;
-        if (4 != file -> Read( &tagcount, 4))
+        if (4 != file->Read( &tagcount, 4))
         throw CInvalidPacket("short file reading tag count");
         for (uint32 j = 0 ; j < tagcount ; j++)
         {
             try
             {
                 CTag *newtag = new CTag(file);
-                switch (newtag -> tag -> specialtag)
+                switch (newtag->tag->specialtag)
                 {
                 case FT_FILENAME:
                     {
-                        m_pszFileName = nstrdup(newtag -> tag -> stringvalue);
+                        m_pszFileName = nstrdup(newtag->tag->stringvalue);
                         delete newtag;
                         break;
                     }
                 case FT_FILESIZE:
                     {
-                        m_nFileSize = newtag -> tag -> intvalue;
+                        m_nFileSize = newtag->tag->intvalue;
                         m_AvailPartFrequency.SetSize(GetPartCount());
                         for (uint32 i = 0 ; i != GetPartCount() ; i++)
                         m_AvailPartFrequency.Add(0);
@@ -359,19 +356,19 @@ bool CKnownFile:: LoadTagsFromFile(CFile *file)
                     }
                 case FT_ATTRANSFERED:
                     {
-                        statistic.alltimetransfered = newtag -> tag -> intvalue;
+                        statistic.alltimetransfered = newtag->tag->intvalue;
                         delete newtag;
                         break;
                     }
                 case FT_ATREQUESTED:
                     {
-                        statistic.alltimerequested = newtag -> tag -> intvalue;
+                        statistic.alltimerequested = newtag->tag->intvalue;
                         delete newtag;
                         break;
                     }
                 case FT_ATACCEPTED:
                     {
-                        statistic.alltimeaccepted = newtag -> tag -> intvalue;
+                        statistic.alltimeaccepted = newtag->tag->intvalue;
                         delete newtag;
                         break;
                     }
@@ -384,7 +381,7 @@ bool CKnownFile:: LoadTagsFromFile(CFile *file)
                 case FT_ULPRIORITY:
                     {
                         uint8 autoprio = PR_AUTO;
-                        m_iUpPriority = newtag -> tag -> intvalue;
+                        m_iUpPriority = newtag->tag->intvalue;
                         if (m_iUpPriority == autoprio)
                         {
                             m_iUpPriority = PR_HIGH;
@@ -397,7 +394,7 @@ bool CKnownFile:: LoadTagsFromFile(CFile *file)
                     }
                 case FT_PERMISSIONS:
                     {
-                        m_iPermissions = newtag -> tag -> intvalue;
+                        m_iPermissions = newtag->tag->intvalue;
                         delete newtag;
                         break;
                     }
@@ -418,17 +415,17 @@ bool CKnownFile:: LoadTagsFromFile(CFile *file)
     return true;
 }
 
-bool CKnownFile:: LoadDateFromFile(CFile *file)
+bool CKnownFile::LoadDateFromFile(CFile *file)
 {
-    return(4 == file -> Read( &date, 4));
+    return(4 == file->Read( &date, 4));
 }
 
-bool CKnownFile:: LoadFromFile(CFile *file)
+bool CKnownFile::LoadFromFile(CFile *file)
 {
     return(LoadDateFromFile(file) &&LoadHashsetFromFile(file, false) &&LoadTagsFromFile(file));
 }
 
-bool CKnownFile:: WriteToFile(FILE *file)
+bool CKnownFile::WriteToFile(FILE *file)
 {
     // date
     fwrite( &date, 4, 1, file);
@@ -458,12 +455,12 @@ bool CKnownFile:: WriteToFile(FILE *file)
     CTag(FT_PERMISSIONS, m_iPermissions) .WriteTagToFile(file);
     //other tags
     for (uint32 j = 0 ; j < tagcount - NR_TAGS ; j++)
-    taglist[j] -> WriteTagToFile(file);
+    taglist[j]->WriteTagToFile(file);
     return ferror(file);
 #undef NR_TAGS
 }
 
-void CKnownFile:: CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar *Output, uchar *in_string)
+void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar *Output, uchar *in_string)
 {
     // time critial
     bool PaddingStarted = false;
@@ -485,14 +482,14 @@ void CKnownFile:: CreateHashFromInput(FILE *file, CFile *file2, int Length, ucha
         if (len > sizeof(X) / (64 *sizeof(X[0])))
         len = sizeof(X) / (64 *sizeof(X[0]));
         if (in_string)
-        data -> Read( &X, len *64);
+        data->Read( &X, len *64);
         else if(file)
         fread( &X, len *64, 1, file);
         else if(file2)
-        file2 -> Read( &X, len *64);
+        file2->Read( &X, len *64);
         for (uint32 i = 0 ; i < len ; i++)
         {
-            MD4Transform(Hash, (uint32 *)(X + i *64));
+            MD42Transform(Hash, (uint32 *)(X + i *64));
         }
         Required -= len *64;
     }
@@ -501,11 +498,11 @@ void CKnownFile:: CreateHashFromInput(FILE *file, CFile *file2, int Length, ucha
     if (Required != 0)
     {
         if (in_string)
-        data -> Read( &X, Required);
+        data->Read( &X, Required);
         else if(file)
         fread( &X, Required, 1, file);
         else if(file2)
-        file2 -> Read( &X, Required);
+        file2->Read( &X, Required);
     }
     // in byte scale 512 = 64, 448 = 56
     if (Required >= 56)
@@ -513,7 +510,7 @@ void CKnownFile:: CreateHashFromInput(FILE *file, CFile *file2, int Length, ucha
         X[Required] = 0x80;
         PaddingStarted = TRUE;
         memset( &X[Required + 1], 0, 63 - Required);
-        MD4Transform(Hash, (uint32 *) X);
+        MD42Transform(Hash, (uint32 *) X);
         Required = 0;
     }
     if (!PaddingStarted)
@@ -526,19 +523,19 @@ void CKnownFile:: CreateHashFromInput(FILE *file, CFile *file2, int Length, ucha
     Length <<= 3;
     memcpy( &X[56], &Length, 4);
     memcpy( &X[60], &Length2, 4);
-    MD4Transform(Hash, (uint32 *) X);
+    MD42Transform(Hash, (uint32 *) X);
     memcpy(Output, Hash, 16);
     safe_delete(data);
 }
 
-uchar *CKnownFile:: GetPartHash(uint16 part)
+uchar *CKnownFile::GetPartHash(uint16 part)
 {
     if (part >= hashlist.GetCount())
     return 0;
     return hashlist[part];
 }
 
-static void MD4Transform(uint32 Hash[4], uint32 x[16])
+static void MD42Transform(uint32 Hash[4], uint32 x[16])
 {
     uint32 a = Hash[0];
     uint32 b = Hash[1];
@@ -546,103 +543,103 @@ static void MD4Transform(uint32 Hash[4], uint32 x[16])
     uint32 d = Hash[3];
     /* Round 1 */
     // 01:
-    MD4_FF(a, b, c, d, x[ 0], S11);
+    MD42FF(a, b, c, d, x[ 0], S11);
     // 02:
-    MD4_FF(d, a, b, c, x[ 1], S12);
+    MD42FF(d, a, b, c, x[ 1], S12);
     // 03:
-    MD4_FF(c, d, a, b, x[ 2], S13);
+    MD42FF(c, d, a, b, x[ 2], S13);
     // 04:
-    MD4_FF(b, c, d, a, x[ 3], S14);
+    MD42FF(b, c, d, a, x[ 3], S14);
     // 05:
-    MD4_FF(a, b, c, d, x[ 4], S11);
+    MD42FF(a, b, c, d, x[ 4], S11);
     // 06:
-    MD4_FF(d, a, b, c, x[ 5], S12);
+    MD42FF(d, a, b, c, x[ 5], S12);
     // 07:
-    MD4_FF(c, d, a, b, x[ 6], S13);
+    MD42FF(c, d, a, b, x[ 6], S13);
     // 08:
-    MD4_FF(b, c, d, a, x[ 7], S14);
+    MD42FF(b, c, d, a, x[ 7], S14);
     // 09:
-    MD4_FF(a, b, c, d, x[ 8], S11);
+    MD42FF(a, b, c, d, x[ 8], S11);
     // 10:
-    MD4_FF(d, a, b, c, x[ 9], S12);
+    MD42FF(d, a, b, c, x[ 9], S12);
     // 11:
-    MD4_FF(c, d, a, b, x[10], S13);
+    MD42FF(c, d, a, b, x[10], S13);
     // 12:
-    MD4_FF(b, c, d, a, x[11], S14);
+    MD42FF(b, c, d, a, x[11], S14);
     // 13:
-    MD4_FF(a, b, c, d, x[12], S11);
+    MD42FF(a, b, c, d, x[12], S11);
     // 14:
-    MD4_FF(d, a, b, c, x[13], S12);
+    MD42FF(d, a, b, c, x[13], S12);
     // 15:
-    MD4_FF(c, d, a, b, x[14], S13);
+    MD42FF(c, d, a, b, x[14], S13);
     // 16:
-    MD4_FF(b, c, d, a, x[15], S14);
+    MD42FF(b, c, d, a, x[15], S14);
     /* Round 2 */
     // 17:
-    MD4_GG(a, b, c, d, x[ 0], S21);
+    MD42GG(a, b, c, d, x[ 0], S21);
     // 18:
-    MD4_GG(d, a, b, c, x[ 4], S22);
+    MD42GG(d, a, b, c, x[ 4], S22);
     // 19:
-    MD4_GG(c, d, a, b, x[ 8], S23);
+    MD42GG(c, d, a, b, x[ 8], S23);
     // 20:
-    MD4_GG(b, c, d, a, x[12], S24);
+    MD42GG(b, c, d, a, x[12], S24);
     // 21:
-    MD4_GG(a, b, c, d, x[ 1], S21);
+    MD42GG(a, b, c, d, x[ 1], S21);
     // 22:
-    MD4_GG(d, a, b, c, x[ 5], S22);
+    MD42GG(d, a, b, c, x[ 5], S22);
     // 23:
-    MD4_GG(c, d, a, b, x[ 9], S23);
+    MD42GG(c, d, a, b, x[ 9], S23);
     // 24:
-    MD4_GG(b, c, d, a, x[13], S24);
+    MD42GG(b, c, d, a, x[13], S24);
     // 25:
-    MD4_GG(a, b, c, d, x[ 2], S21);
+    MD42GG(a, b, c, d, x[ 2], S21);
     // 26:
-    MD4_GG(d, a, b, c, x[ 6], S22);
+    MD42GG(d, a, b, c, x[ 6], S22);
     // 27:
-    MD4_GG(c, d, a, b, x[10], S23);
+    MD42GG(c, d, a, b, x[10], S23);
     // 28:
-    MD4_GG(b, c, d, a, x[14], S24);
+    MD42GG(b, c, d, a, x[14], S24);
     // 29:
-    MD4_GG(a, b, c, d, x[ 3], S21);
+    MD42GG(a, b, c, d, x[ 3], S21);
     // 30:
-    MD4_GG(d, a, b, c, x[ 7], S22);
+    MD42GG(d, a, b, c, x[ 7], S22);
     // 31:
-    MD4_GG(c, d, a, b, x[11], S23);
+    MD42GG(c, d, a, b, x[11], S23);
     // 32:
-    MD4_GG(b, c, d, a, x[15], S24);
+    MD42GG(b, c, d, a, x[15], S24);
     /* Round 3 */
     // 33:
-    MD4_HH(a, b, c, d, x[ 0], S31);
+    MD42HH(a, b, c, d, x[ 0], S31);
     // 34:
-    MD4_HH(d, a, b, c, x[ 8], S32);
+    MD42HH(d, a, b, c, x[ 8], S32);
     // 35:
-    MD4_HH(c, d, a, b, x[ 4], S33);
+    MD42HH(c, d, a, b, x[ 4], S33);
     // 36:
-    MD4_HH(b, c, d, a, x[12], S34);
+    MD42HH(b, c, d, a, x[12], S34);
     // 37:
-    MD4_HH(a, b, c, d, x[ 2], S31);
+    MD42HH(a, b, c, d, x[ 2], S31);
     // 38:
-    MD4_HH(d, a, b, c, x[10], S32);
+    MD42HH(d, a, b, c, x[10], S32);
     // 39:
-    MD4_HH(c, d, a, b, x[ 6], S33);
+    MD42HH(c, d, a, b, x[ 6], S33);
     // 40:
-    MD4_HH(b, c, d, a, x[14], S34);
+    MD42HH(b, c, d, a, x[14], S34);
     // 41:
-    MD4_HH(a, b, c, d, x[ 1], S31);
+    MD42HH(a, b, c, d, x[ 1], S31);
     // 42:
-    MD4_HH(d, a, b, c, x[ 9], S32);
+    MD42HH(d, a, b, c, x[ 9], S32);
     // 43:
-    MD4_HH(c, d, a, b, x[ 5], S33);
+    MD42HH(c, d, a, b, x[ 5], S33);
     // 44:
-    MD4_HH(b, c, d, a, x[13], S34);
+    MD42HH(b, c, d, a, x[13], S34);
     // 45:
-    MD4_HH(a, b, c, d, x[ 3], S31);
+    MD42HH(a, b, c, d, x[ 3], S31);
     // 46:
-    MD4_HH(d, a, b, c, x[11], S32);
+    MD42HH(d, a, b, c, x[11], S32);
     // 47:
-    MD4_HH(c, d, a, b, x[ 7], S33);
+    MD42HH(c, d, a, b, x[ 7], S33);
     // 48:
-    MD4_HH(b, c, d, a, x[15], S34);
+    MD42HH(b, c, d, a, x[15], S34);
     Hash[0] += a;
     Hash[1] += b;
     Hash[2] += c;
@@ -650,7 +647,7 @@ static void MD4Transform(uint32 Hash[4], uint32 x[16])
 }
 
 // Adde by Tarod [Juanjo]
-void CAbstractFile:: SetFileName(char *NewName)
+void CAbstractFile::SetFileName(char *NewName)
 {
     if (m_pszFileName != NULL)
     {
@@ -671,91 +668,66 @@ void CAbstractFile:: SetFileName(char *NewName)
 
 //End by Tarod
 
-Packet *CKnownFile:: CreateSrcInfoPacket(CUpDownClient *forClient)
+Packet *CKnownFile::CreateSrcInfoPacket(CUpDownClient *forClient)
 {
-    MAP * pos = listof_sourcesKF -> next;
-    while (pos -> Key)
+    CTypedPtrList < CPtrList, CUpDownClient *> srclist;
+    //should we use "filehash"?:
+    theApp.uploadqueue->FindSourcesForFileById( &srclist, forClient->GetUploadFileID());
+    if (srclist.IsEmpty())
+    return 0;
+    CMemFile data;
+    uint16 nCount = 0;
+    data.Write(forClient->GetUploadFileID(), 16);
+    data.Write( &nCount, 2);
+    uint32 lastRequest = forClient->GetLastSrcReqTime();
+    //we are only taking 30 random sources since we can't be sure if they have parts we need
+    //this is hard coded because its a temp solution until next(?) version
+    srand(time(NULL));
+    for (int i = 0 ; i < 30 ; i++)
     {
-        pos = MapData_Remove(listof_sourcesKF -> next, pos);
-    }
-    theApp.uploadqueue -> FindSourcesForFileById(listof_sourcesKF, forClient -> GetUploadFileID());
-    if (listof_sourcesKF -> Data)
-    {
-        CMemFile data;
-        wxUint16 nCount = 0;
-        data.Write(forClient -> GetUploadFileID(), 16);
-        data.Write( & nCount, 2);
-        wxUint32 lastRequest = forClient -> GetLastSrcReqTime();
-        int i = rand() % listof_sourcesKF -> Data;
-        pos = listof_sourcesKF -> next;
-        while (i > 0)
+        int victim = ((rand() >> 7) % srclist.GetSize());
+        POSITION pos = srclist.FindIndex(victim);
+        CUpDownClient *cur_src = srclist.GetAt(pos);
+        if (!cur_src->HasLowID() &&cur_src != forClient)
         {
-            i--;
-            pos = pos -> next;
+            nCount++;
+            uint32 dwID = cur_src->GetUserID();
+            uint16 nPort = cur_src->GetUserPort();
+            uint32 dwServerIP = cur_src->GetServerIP();
+            uint16 nServerPort = cur_src->GetServerPort();
+            data.Write( &dwID, 4);
+            data.Write( &nPort, 2);
+            data.Write( &dwServerIP, 4);
+            data.Write( &nServerPort, 2);
+            if (forClient->GetSourceExchangeVersion() > 1)
+            data.Write(cur_src->GetUserHash(), 16);
         }
-        while (i < 30)
-        {
-            if (pos -> Key)
-            {
-                CUpDownClient * cur_src = (CUpDownClient *) pos -> Data;
-                if ((!cur_src -> HasLowID()) && (cur_src != forClient))
-                {
-                    nCount++;
-                    wxUint32 dwID = cur_src -> GetUserID();
-                    wxUint16 nPort = cur_src -> GetUserPort();
-                    wxUint32 dwServerIP = cur_src -> GetServerIP();
-                    wxUint16 nServerPort = cur_src -> GetServerPort();
-                    data.Write( & dwID, 4);
-                    data.Write( & nPort, 2);
-                    data.Write( & dwServerIP, 4);
-                    data.Write( & nServerPort, 2);
-                    if (forClient -> GetSourceExchangeVersion() > 1)
-                    {
-                        data.Write(cur_src -> GetUserHash(), 16);
-                    }
-                    ++i;
-                }
-                pos = MapData_Remove(listof_sourcesKF, pos);
-            }
-            else
-            {
-                i = 30;
-            }
-        }
-        if (nCount)
-        {
-            data.Seek(16);
-            data.Write( & nCount, 2);
-            Packet * result = new Packet( & data, OP_EMULEPROT);
-            result -> opcode = OP_ANSWERSOURCES;
-            if (nCount > 28)
-            {
-                result -> PackPacket();
-            }
-            return result;
-        }
-        else
-        {
-            return NULL;
-        }
-    }
-    else
-    {
-        return NULL;
+        srclist.RemoveAt(pos);
+        if (srclist.GetSize() == 0)
+        break;
     }
+    if (!nCount)
+    return 0;
+    data.Seek(16);
+    data.Write( &nCount, 2);
+    Packet *result = new Packet( &data, OP_EMULEPROT);
+    result->opcode = OP_ANSWERSOURCES;
+    if (nCount > 28)
+    result->PackPacket();
+    return result;
 }
 
 // Updates priority of file if autopriority is activated
-void CKnownFile:: UpdateAutoUpPriority(void)
+void CKnownFile::UpdateAutoUpPriority(void)
 {
-    if (!this -> IsAutoUpPriority())
+    if (!this->IsAutoUpPriority())
     return;
     if (GetQueuedCount() > 20)
     {
         if (GetUpPriority() != PR_LOW)
         {
             SetUpPriority(PR_LOW);
-            theApp.xmuledlg -> sharedfileswnd -> sharedfilesctrl -> UpdateItem(this);
+            theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
         }
         return;
     }
@@ -764,23 +736,23 @@ void CKnownFile:: UpdateAutoUpPriority(void)
         if (GetUpPriority() != PR_NORMAL)
         {
             SetUpPriority(PR_NORMAL);
-            theApp.xmuledlg -> sharedfileswnd -> sharedfilesctrl -> UpdateItem(this);
+            theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
         }
         return;
     }
     if (GetUpPriority() != PR_HIGH)
     {
         SetUpPriority(PR_HIGH);
-        theApp.xmuledlg -> sharedfileswnd -> sharedfilesctrl -> UpdateItem(this);
+        theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
     }
 }
 
 //For File Comment //
-void CKnownFile:: LoadComment()
+void CKnownFile::LoadComment()
 {
     char buffer[100];
-    char *fullpath = new char[strlen(theApp.glob_prefs -> GetAppDir()) + 13];
-    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs -> GetAppDir());
+    char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
+    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
     for (uint16 i = 0 ; i != 16 ; i++)
     sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
@@ -792,66 +764,53 @@ void CKnownFile:: LoadComment()
     delete[] fullpath;
 }
 
-void CKnownFile:: SetFileComment(CString strNewComment)
+void CKnownFile::SetFileComment(CString strNewComment)
 {
     char buffer[100];
-    char * fullpath = new char[strlen(theApp.glob_prefs -> GetAppDir()) + 13];
-    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs -> GetAppDir());
+    char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
+    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
     for (uint16 i = 0 ; i != 16 ; i++)
-    {
-        sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
-    }
+    sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
     CIni ini(fullpath, buffer);
     ini.WriteString("Comment", strNewComment);
     m_strComment = strNewComment;
     delete fullpath;
-    MAP * pos = listof_sourcesKF -> next;
-    while (pos -> Key)
+    CTypedPtrList < CPtrList, CUpDownClient *> srclist;
+    theApp.uploadqueue->FindSourcesForFileById( &srclist, this->GetFileHash());
+    for (POSITION pos = srclist.GetHeadPosition() ; pos != 0 ; srclist.GetNext(pos))
     {
-        pos = MapData_Remove(listof_sourcesKF -> next, pos);
-    }
-    theApp.uploadqueue -> FindSourcesForFileById( listof_sourcesKF, this -> GetFileHash());
-    pos = listof_sourcesKF -> next;
-    while (pos -> Key)
-    {
-        ((CUpDownClient*)pos->Data)->SetCommentDirty();
-	pos=pos->next;
+        CUpDownClient *cur_src = srclist.GetAt(pos);
+        cur_src->SetCommentDirty();
     }
 }
 
-void CKnownFile:: SetFileRate(int8 iNewRate)
+// For File rate
+void CKnownFile::SetFileRate(int8 iNewRate)
 {
     char buffer[100];
-    char * fullpath = new char[strlen(theApp.glob_prefs -> GetAppDir()) + 13];
-    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs -> GetAppDir());
+    char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
+    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
     for (uint16 i = 0 ; i != 16 ; i++)
-    {
-        sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
-    }
+    sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
     CIni ini(fullpath, buffer);
     ini.WriteInt("Rate", iNewRate);
     m_iRate = iNewRate;
     delete fullpath;
-    MAP * pos = listof_sourcesKF -> next;
-    while (pos -> Key)
+    CTypedPtrList < CPtrList, CUpDownClient *> srclist;
+    theApp.uploadqueue->FindSourcesForFileById( &srclist, this->GetFileHash());
+    for (POSITION pos = srclist.GetHeadPosition() ; pos != 0 ; srclist.GetNext(pos))
     {
-        pos = MapData_Remove(listof_sourcesKF -> next, pos);
-    }
-    theApp.uploadqueue -> FindSourcesForFileById( listof_sourcesKF, this -> GetFileHash());
-    pos = listof_sourcesKF -> next;
-    while (pos -> Key)
-    {
-        ((CUpDownClient*)pos->Data)->SetCommentDirty();
-	pos=pos->next;
+        CUpDownClient *cur_src = srclist.GetAt(pos);
+        cur_src->SetCommentDirty();
     }
 }
 
-void CKnownFile:: SetUpPriority(uint8 iNewUpPriority, bool m_bsave)
+void CKnownFile::SetUpPriority(uint8 iNewUpPriority, bool m_bsave)
 {
     m_iUpPriority = iNewUpPriority;
-    if (this -> IsPartFile() &&m_bsave)
-    ((CPartFile *) this) -> SavePartFile();
+    if (this->IsPartFile() &&m_bsave)
+    ((CPartFile *) this)->SavePartFile();
 }
 
