@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
 //
 
 #include "MuleListCtrl.h"
+#include "opcodes.h"                    // Needed for MP_LISTCOL_1
 #include "xmule.h"
 
 #include <wx/menu.h>
@@ -48,7 +49,7 @@ MLC_BLEND(GetBValue(A), GetBValue(B), X)) \
 
 //IMPLEMENT_DYNAMIC(CMuleListCtrl, wxODListCtrl)
 IMPLEMENT_DYNAMIC_CLASS(CMuleListCtrl, wxODListCtrl)
-CMuleListCtrl:: CMuleListCtrl()
+CMuleListCtrl::CMuleListCtrl()
 {
     m_bCustomDraw = false;
     m_iCurrentSortItem = - 1;
@@ -63,7 +64,7 @@ CMuleListCtrl:: CMuleListCtrl()
 #endif
 }
 
-CMuleListCtrl:: CMuleListCtrl(wxWindow *&parent, int id, const wxPoint &pos, wxSize siz, int flags)
+CMuleListCtrl::CMuleListCtrl(wxWindow *&parent, int id, const wxPoint &pos, wxSize siz, int flags)
 : wxODListCtrl(parent, id, pos, siz, flags)
 {
     m_bCustomDraw = false;
@@ -79,45 +80,45 @@ CMuleListCtrl:: CMuleListCtrl(wxWindow *&parent, int id, const wxPoint &pos, wxS
 #endif
 }
 
-CMuleListCtrl:: ~CMuleListCtrl()
+CMuleListCtrl::~CMuleListCtrl()
 {
     if (m_aColumns != NULL)
     delete[] m_aColumns;
 }
 
-void CMuleListCtrl:: SetNamxMule(LPCTSTR lpszName)
+void CMuleListCtrl::SetNamxMule(LPCTSTR lpszName)
 {
     m_Name = lpszName;
 }
 
 //new fix for old problem... normally Update(int) causes entire list to redraw
-BOOL CMuleListCtrl:: Update(int iItem)
+BOOL CMuleListCtrl::Update(int iItem)
 {
 #if 0
     RECT rcItem;
-    BOOL bResult = this -> GetItemRect(iItem, &rcItem, LVIR_BOUNDS);
+    BOOL bResult = this->GetItemRect(iItem, &rcItem, LVIR_BOUNDS);
     if (bResult)
     InvalidateRect( &rcItem, FALSE);
     return bResult;
 #endif
 }
 
-void CMuleListCtrl:: PreSubclassWindow()
+void CMuleListCtrl::PreSubclassWindow()
 {
 #if 0
     SetColors();
-    CListCtrl:: PreSubclassWindow();
+    CListCtrl::PreSubclassWindow();
     ModifyStyle(LVS_SINGLESEL |LVS_LIST |LVS_ICON |LVS_SMALLICON, LVS_REPORT |TVS_LINESATROOT |TVS_HASBUTTONS);
     SetExtendedStyle(LVS_EX_HEADERDRAGDROP);
 #endif
 }
 
 #if 0
-int CMuleListCtrl:: IndexToOrder(CHeaderCtrl *pHeader, int iIndex)
+int CMuleListCtrl::IndexToOrder(CHeaderCtrl *pHeader, int iIndex)
 {
-    int iCount = pHeader -> GetItemCount();
+    int iCount = pHeader->GetItemCount();
     int *piArray = new int[iCount];
-    Header_GetOrderArray(pHeader -> m_hWnd, iCount, piArray);
+    Header_GetOrderArray(pHeader->m_hWnd, iCount, piArray);
     for (int i = 0 ; i < iCount ; i++)
     {
         if (piArray[i] == iIndex)
@@ -132,11 +133,11 @@ int CMuleListCtrl:: IndexToOrder(CHeaderCtrl *pHeader, int iIndex)
 
 #endif
 
-void CMuleListCtrl:: HideColumn(int iColumn)
+void CMuleListCtrl::HideColumn(int iColumn)
 {
 #if 0
     CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-    int iCount = pHeaderCtrl -> GetItemCount();
+    int iCount = pHeaderCtrl->GetItemCount();
     if (iColumn < 1 || iColumn >= iCount || m_aColumns[iColumn].bHidden)
     return;
     //stop it from redrawing
@@ -144,13 +145,13 @@ void CMuleListCtrl:: HideColumn(int iColumn)
     //shrink width to 0
     HDITEM item;
     item.mask = HDI_WIDTH;
-    pHeaderCtrl -> GetItem(iColumn, &item);
+    pHeaderCtrl->GetItem(iColumn, &item);
     m_aColumns[iColumn].iWidth = item.cxy;
     item.cxy = 0;
-    pHeaderCtrl -> SetItem(iColumn, &item);
+    pHeaderCtrl->SetItem(iColumn, &item);
     //move to front of list
     INT *piArray = new INT[m_iColumnsTracked];
-    pHeaderCtrl -> GetOrderArray(piArray, m_iColumnsTracked);
+    pHeaderCtrl->GetOrderArray(piArray, m_iColumnsTracked);
     int iFrom = m_aColumns[iColumn].iLocation;
     for (int i = 0 ; i < m_iColumnsTracked ; i++)
     if (m_aColumns[i].iLocation > m_aColumns[iColumn].iLocation &&m_aColumns[i].bHidden)
@@ -158,7 +159,7 @@ void CMuleListCtrl:: HideColumn(int iColumn)
     for (int i = iFrom ; i > 0 ; i--)
     piArray[i] = piArray[i - 1];
     piArray[0] = iColumn;
-    pHeaderCtrl -> SetOrderArray(m_iColumnsTracked, piArray);
+    pHeaderCtrl->SetOrderArray(m_iColumnsTracked, piArray);
     delete[] piArray;
     //update entry
     m_aColumns[iColumn].bHidden = true;
@@ -168,32 +169,32 @@ void CMuleListCtrl:: HideColumn(int iColumn)
 #endif
 }
 
-void CMuleListCtrl:: ShowColumn(int iColumn)
+void CMuleListCtrl::ShowColumn(int iColumn)
 {
 #if 0
     CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-    int iCount = pHeaderCtrl -> GetItemCount();
+    int iCount = pHeaderCtrl->GetItemCount();
     if (iColumn < 1 || iColumn >= iCount || !m_aColumns[iColumn].bHidden)
     return;
     //stop it from redrawing
     SetRedraw(FALSE);
     //restore position in list
     INT *piArray = new INT[m_iColumnsTracked];
-    pHeaderCtrl -> GetOrderArray(piArray, m_iColumnsTracked);
+    pHeaderCtrl->GetOrderArray(piArray, m_iColumnsTracked);
     int iCurrent = IndexToOrder(pHeaderCtrl, iColumn);
     for ( ; iCurrent < IndexToOrder(pHeaderCtrl, 0) &&iCurrent < m_iColumnsTracked - 1 ; iCurrent++)
     piArray[iCurrent] = piArray[iCurrent + 1];
-    for ( ; m_aColumns[iColumn].iLocation > m_aColumns[pHeaderCtrl -> OrderToIndex(iCurrent + 1) ].iLocation &&
+    for ( ; m_aColumns[iColumn].iLocation > m_aColumns[pHeaderCtrl->OrderToIndex(iCurrent + 1) ].iLocation &&
     iCurrent < m_iColumnsTracked - 1 ; iCurrent++)
     piArray[iCurrent] = piArray[iCurrent + 1];
     piArray[iCurrent] = iColumn;
-    pHeaderCtrl -> SetOrderArray(m_iColumnsTracked, piArray);
+    pHeaderCtrl->SetOrderArray(m_iColumnsTracked, piArray);
     delete[] piArray;
     //and THEN restore original width
     HDITEM item;
     item.mask = HDI_WIDTH;
     item.cxy = m_aColumns[iColumn].iWidth;
-    pHeaderCtrl -> SetItem(iColumn, &item);
+    pHeaderCtrl->SetItem(iColumn, &item);
     //update entry
     m_aColumns[iColumn].bHidden = false;
     //redraw
@@ -203,7 +204,7 @@ void CMuleListCtrl:: ShowColumn(int iColumn)
 }
 
 #include "wx/msgdlg.h"
-void CMuleListCtrl:: SaveSettings(CPreferences:: Table tID)
+void CMuleListCtrl::SaveSettings(CPreferences::Table tID)
 {
     int colTrack = GetColumnCount();
     INT *piArray = new INT[colTrack];
@@ -212,7 +213,7 @@ void CMuleListCtrl:: SaveSettings(CPreferences:: Table tID)
         wxListItem mycol;
         GetColumn(i, mycol);
         //	  wxMessageBox(wxString::Format("%s - %i",mycol.GetText().c_str(), mycol.GetWidth()	));
-        theApp.glob_prefs -> SetColumnWidth(tID, i, mycol.GetWidth());
+        theApp.glob_prefs->SetColumnWidth(tID, i, mycol.GetWidth());
         //theApp.glob_prefs->SetColumnHidden(tID, i, IsColumnHidden(i));
         //piArray[i] = m_aColumns[i].iLocation;
     }
@@ -220,14 +221,14 @@ void CMuleListCtrl:: SaveSettings(CPreferences:: Table tID)
     delete[] piArray;
 }
 
-void CMuleListCtrl:: LoadSettings(CPreferences:: Table tID)
+void CMuleListCtrl::LoadSettings(CPreferences::Table tID)
 {
     //CHeaderCtrl* pHeaderCtrl = GetHeaderCtrl();
     int colTrack = GetColumnCount();
     INT *piArray = new INT[colTrack];
     for (int i = 0 ; i < colTrack ; i++)
     {
-        int iWidth = theApp.glob_prefs -> GetColumnWidth(tID, i);
+        int iWidth = theApp.glob_prefs->GetColumnWidth(tID, i);
         if (iWidth != DEFAULT_COL_SIZE)
         {
             SetColumnWidth(i, iWidth);
@@ -241,7 +242,7 @@ void CMuleListCtrl:: LoadSettings(CPreferences:: Table tID)
         }
         else
         {
-            int iOrder = theApp.glob_prefs -> GetColumnOrder(tID, i);
+            int iOrder = theApp.glob_prefs->GetColumnOrder(tID, i);
             if (iOrder == 0)
             piArray[i] = i;
             else
@@ -254,18 +255,18 @@ void CMuleListCtrl:: LoadSettings(CPreferences:: Table tID)
 #if 0
     for (int i = 1 ; i < m_iColumnsTracked ; i++)
     {
-        if (theApp.glob_prefs -> GetColumnHidden(tID, i))
+        if (theApp.glob_prefs->GetColumnHidden(tID, i))
         HideColumn(i);
     }
 #endif
 }
 
-void CMuleListCtrl:: SetColors()
+void CMuleListCtrl::SetColors()
 {
 #if 0
-    m_crWindow =:: GetSysColor(COLOR_WINDOW);
-    m_crWindowText =:: GetSysColor(COLOR_WINDOWTEXT);
-    COLORREF crHighlight =:: GetSysColor(COLOR_HIGHLIGHT);
+    m_crWindow =::GetSysColor(COLOR_WINDOW);
+    m_crWindowText =::GetSysColor(COLOR_WINDOWTEXT);
+    COLORREF crHighlight =::GetSysColor(COLOR_HIGHLIGHT);
     m_crFocusLine = crHighlight;
     m_crNoHighlight = MLC_RGBBLEND(crHighlight, m_crWindow, 8);
     m_crNoFocusLine = MLC_RGBBLEND(crHighlight, m_crWindow, 2);
@@ -273,16 +274,16 @@ void CMuleListCtrl:: SetColors()
 #endif
 }
 
-void CMuleListCtrl:: SetSortArrow(int iColumn, ArrowType atType)
+void CMuleListCtrl::SetSortArrow(int iColumn, ArrowType atType)
 {
     // integrated in listctrl..
     switch (atType)
     {
     case 263:
-        wxODListCtrl:: SetSortArrow(iColumn, (int) 1);
+        wxODListCtrl::SetSortArrow(iColumn, (int) 1);
         break;
     default:
-        wxODListCtrl:: SetSortArrow(iColumn, (int) 2);
+        wxODListCtrl::SetSortArrow(iColumn, (int) 2);
         break;
     }
 #if 0
@@ -292,18 +293,18 @@ void CMuleListCtrl:: SetSortArrow(int iColumn, ArrowType atType)
     //delete old image if column has changed
     if (iColumn != m_iCurrentSortItem)
     {
-        pHeaderCtrl -> GetItem(m_iCurrentSortItem, &headerItem);
+        pHeaderCtrl->GetItem(m_iCurrentSortItem, &headerItem);
         headerItem.fmt &= ~ (HDF_BITMAP | HDF_BITMAP_ON_RIGHT);
         if (headerItem.hbm != 0)
         {
             DeleteObject(headerItem.hbm);
             headerItem.hbm = 0;
         }
-        pHeaderCtrl -> SetItem(m_iCurrentSortItem, &headerItem);
+        pHeaderCtrl->SetItem(m_iCurrentSortItem, &headerItem);
         m_iCurrentSortItem = iColumn;
     }
     //place new arrow unless we were given an invalid column
-    if (iColumn >= 0 &&pHeaderCtrl -> GetItem(iColumn, &headerItem))
+    if (iColumn >= 0 &&pHeaderCtrl->GetItem(iColumn, &headerItem))
     {
         m_atSortArrow = atType;
         if (headerItem.hbm != 0)
@@ -315,14 +316,14 @@ void CMuleListCtrl:: SetSortArrow(int iColumn, ArrowType atType)
         headerItem.hbm = (HBITMAP) LoadImage(AfxGetInstanceHandle(),
         MAKEINTRESOURCE(m_atSortArrow), IMAGE_BITMAP, 0, 0,
         LR_LOADMAP3DCOLORS);
-        pHeaderCtrl -> SetItem(iColumn, &headerItem);
+        pHeaderCtrl->SetItem(iColumn, &headerItem);
     }
 #endif
 }
 
 #if 0
 //lower level than everything else so poorly overriden functions don't break us
-BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESULT *pResult)
+BOOL CMuleListCtrl::OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESULT *pResult)
 {
     //lets look for the important messages that are essential to handle
     switch (message)
@@ -330,7 +331,7 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
     case WM_NOTIFY:
         if (wParam == 0)
         {
-            if (((NMHDR *) lParam) -> code == NM_RCLICK)
+            if (((NMHDR *) lParam)->code == NM_RCLICK)
             {
                 //catch right click on headers and show column menu
                 POINT point;
@@ -340,7 +341,7 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
                 if (m_Name.GetLength() != 0)
                 tmColumnMenu.AddMenuTitle(m_Name);
                 CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-                int iCount = pHeaderCtrl -> GetItemCount();
+                int iCount = pHeaderCtrl->GetItemCount();
                 for (int iCurrent = 1 ; iCurrent < iCount ; iCurrent++)
                 {
                     HDITEM item;
@@ -348,7 +349,7 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
                     item.pszText = text;
                     item.mask = HDI_TEXT;
                     item.cchTextMax = 255;
-                    pHeaderCtrl -> GetItem(iCurrent, &item);
+                    pHeaderCtrl->GetItem(iCurrent, &item);
                     tmColumnMenu.AppendMenu(MF_STRING | m_aColumns[iCurrent].bHidden ? 0: MF_CHECKED,
                     MLC_MENU + iCurrent, item.pszText);
                 }
@@ -356,27 +357,27 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
                 tmColumnMenu.DestroyMenu();
                 return *pResult = TRUE;
             }
-            else if(((NMHDR *) lParam) -> code == HDN_BEGINTRACKA || ((NMHDR *) lParam) -> code == HDN_BEGINTRACKW)
+            else if(((NMHDR *) lParam)->code == HDN_BEGINTRACKA || ((NMHDR *) lParam)->code == HDN_BEGINTRACKW)
             {
                 //stop them from changeing the size of anything "before" first column
                 HD_NOTIFY *pHDN = (HD_NOTIFY *) lParam;
-                if (m_aColumns[pHDN -> iItem].bHidden)
+                if (m_aColumns[pHDN->iItem].bHidden)
                 return *pResult = TRUE;
             }
-            else if(((NMHDR *) lParam) -> code == HDN_ENDDRAG)
+            else if(((NMHDR *) lParam)->code == HDN_ENDDRAG)
             {
                 //stop them from moving first column
                 NMHEADER *pHeader = (NMHEADER *) lParam;
-                if (pHeader -> iItem != 0 &&pHeader -> pitem -> iOrder != 0)
+                if (pHeader->iItem != 0 &&pHeader->pitem->iOrder != 0)
                 {
-                    int iNewLoc = pHeader -> pitem -> iOrder - GetHiddenColumnCount();
+                    int iNewLoc = pHeader->pitem->iOrder - GetHiddenColumnCount();
                     if (iNewLoc > 0)
                     {
-                        if (m_aColumns[pHeader -> iItem].iLocation != iNewLoc)
+                        if (m_aColumns[pHeader->iItem].iLocation != iNewLoc)
                         {
-                            if (m_aColumns[pHeader -> iItem].iLocation > iNewLoc)
+                            if (m_aColumns[pHeader->iItem].iLocation > iNewLoc)
                             {
-                                int iMax = m_aColumns[pHeader -> iItem].iLocation;
+                                int iMax = m_aColumns[pHeader->iItem].iLocation;
                                 int iMin = iNewLoc;
                                 for (int i = 0 ; i < m_iColumnsTracked ; i++)
                                 {
@@ -384,9 +385,9 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
                                     m_aColumns[i].iLocation++;
                                 }
                             }
-                            else if(m_aColumns[pHeader -> iItem].iLocation < iNewLoc)
+                            else if(m_aColumns[pHeader->iItem].iLocation < iNewLoc)
                             {
-                                int iMin = m_aColumns[pHeader -> iItem].iLocation;
+                                int iMin = m_aColumns[pHeader->iItem].iLocation;
                                 int iMax = iNewLoc;
                                 for (int i = 0 ; i < m_iColumnsTracked ; i++)
                                 {
@@ -394,7 +395,7 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
                                     m_aColumns[i].iLocation--;
                                 }
                             }
-                            m_aColumns[pHeader -> iItem].iLocation = iNewLoc;
+                            m_aColumns[pHeader->iItem].iLocation = iNewLoc;
                             Invalidate(FALSE);
                             break;
                         }
@@ -408,7 +409,7 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
         if (wParam >= MLC_MENU)
         {
             CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-            int iCount = pHeaderCtrl -> GetItemCount();
+            int iCount = pHeaderCtrl->GetItemCount();
             int iToggle = wParam - MLC_MENU;
             if (iToggle >= iCount)
             break;
@@ -454,26 +455,26 @@ BOOL CMuleListCtrl:: OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESUL
         }
         break;
     }
-    return CListCtrl:: OnWndMsg(message, wParam, lParam, pResult);
+    return CListCtrl::OnWndMsg(message, wParam, lParam, pResult);
 }
 
 #endif
 
 #if 0
-BOOL CMuleListCtrl:: OnChildNotify(UINT message, WPARAM wParam, LPARAM lParam, LRESULT *pResult)
+BOOL CMuleListCtrl::OnChildNotify(UINT message, WPARAM wParam, LPARAM lParam, LRESULT *pResult)
 {
     if (message != WM_DRAWITEM)
     {
         //catch the prepaint and copy struct
-        if (message == WM_NOTIFY && ((NMHDR *) lParam) -> code == NM_CUSTOMDRAW &&
-        ((LPNMLVCUSTOMDRAW) lParam) -> nmcd.dwDrawStage == CDDS_ITEMPREPAINT)
+        if (message == WM_NOTIFY && ((NMHDR *) lParam)->code == NM_CUSTOMDRAW &&
+        ((LPNMLVCUSTOMDRAW) lParam)->nmcd.dwDrawStage == CDDS_ITEMPREPAINT)
         {
-            m_bCustomDraw = CListCtrl:: OnChildNotify(message, wParam, lParam, pResult);
+            m_bCustomDraw = CListCtrl::OnChildNotify(message, wParam, lParam, pResult);
             if (m_bCustomDraw)
             memcpy( &m_lvcd, (void *) lParam, sizeof(NMLVCUSTOMDRAW));
             return m_bCustomDraw;
         }
-        return CListCtrl:: OnChildNotify(message, wParam, lParam, pResult);
+        return CListCtrl::OnChildNotify(message, wParam, lParam, pResult);
     }
     // no return value expected:
     wxASSERT(pResult == NULL);
@@ -500,20 +501,20 @@ END_MESSAGE_MAP()
 // CMuleListCtrl message handlers
 
 #if 0
-void CMuleListCtrl:: DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
+void CMuleListCtrl::DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
 {
     //set up our ficker free drawing
-    CRect rcItem(lpDrawItemStruct -> rcItem);
-    CDC *oDC = CDC:: FromHandle(lpDrawItemStruct -> hDC);
-    oDC -> SetBkColor(m_crWindow);
+    CRect rcItem(lpDrawItemStruct->rcItem);
+    CDC *oDC = CDC::FromHandle(lpDrawItemStruct->hDC);
+    oDC->SetBkColor(m_crWindow);
     CMemDC pDC(oDC, &rcItem);
-    pDC -> SelectObject(GetFont());
+    pDC->SelectObject(GetFont());
     if (m_bCustomDraw)
-    pDC -> SetTextColor(m_lvcd.clrText);
+    pDC->SetTextColor(m_lvcd.clrText);
     else
-    pDC -> SetTextColor(m_crWindowText);
-    int iOffset = pDC -> GetTextExtent(_T(" "), 1) .cx *2;
-    int iItem = lpDrawItemStruct -> itemID;
+    pDC->SetTextColor(m_crWindowText);
+    int iOffset = pDC->GetTextExtent(_T(" "), 1) .cx *2;
+    int iItem = lpDrawItemStruct->itemID;
     CImageList *pImageList;
     CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
     //gets the item image and state info
@@ -548,19 +549,19 @@ void CMuleListCtrl:: DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
     {
         if (bCtrlFocused)
         {
-            pDC -> FillRect(rcHighlight, &CBrush(m_crHighlight));
-            pDC -> SetBkColor(m_crHighlight);
+            pDC->FillRect(rcHighlight, &CBrush(m_crHighlight));
+            pDC->SetBkColor(m_crHighlight);
         }
         else
         {
-            pDC -> FillRect(rcHighlight, &CBrush(m_crNoHighlight));
-            pDC -> SetBkColor(m_crNoHighlight);
+            pDC->FillRect(rcHighlight, &CBrush(m_crNoHighlight));
+            pDC->SetBkColor(m_crNoHighlight);
         }
     }
     else
     {
-        pDC -> FillRect(rcHighlight, &CBrush(m_crWindow));
-        pDC -> SetBkColor(GetBkColor());
+        pDC->FillRect(rcHighlight, &CBrush(m_crWindow));
+        pDC->SetBkColor(GetBkColor());
     }
     //update column
     rcCol.right = rcCol.left + GetColumnWidth(0);
@@ -571,31 +572,31 @@ void CMuleListCtrl:: DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
         pImageList = GetImageList(LVSIL_STATE);
         if (pImageList)
         {
-            COLORREF crOld = pImageList -> SetBkColor(CLR_NONE);
-            pImageList -> Draw(pDC, nImage, rcCol.TopLeft(), ILD_NORMAL);
-            pImageList -> SetBkColor(crOld);
+            COLORREF crOld = pImageList->SetBkColor(CLR_NONE);
+            pImageList->Draw(pDC, nImage, rcCol.TopLeft(), ILD_NORMAL);
+            pImageList->SetBkColor(crOld);
         }
     }
     //draw the item's icon
     pImageList = GetImageList(LVSIL_SMALL);
     if (pImageList)
     {
-        COLORREF crOld = pImageList -> SetBkColor(CLR_NONE);
-        pImageList -> Draw(pDC, lvi.iImage, rcIcon.TopLeft(), ILD_NORMAL);
-        pImageList -> SetBkColor(crOld);
+        COLORREF crOld = pImageList->SetBkColor(CLR_NONE);
+        pImageList->Draw(pDC, lvi.iImage, rcIcon.TopLeft(), ILD_NORMAL);
+        pImageList->SetBkColor(crOld);
     }
     //draw item label (column 0)
     rcLabel.left += iOffset / 2;
     rcLabel.right -= iOffset;
-    pDC -> DrawText(sLabel, - 1, rcLabel, MLC_DT_TEXT | DT_LEFT | DT_NOCLIP);
+    pDC->DrawText(sLabel, - 1, rcLabel, MLC_DT_TEXT | DT_LEFT | DT_NOCLIP);
     //draw labels for remaining columns
     LV_COLUMN lvc;
     lvc.mask = LVCF_FMT | LVCF_WIDTH;
     rcBounds.right = rcHighlight.right > rcBounds.right ? rcHighlight.right: rcBounds.right;
-    int iCount = pHeaderCtrl -> GetItemCount();
+    int iCount = pHeaderCtrl->GetItemCount();
     for (int iCurrent = 1 ; iCurrent < iCount ; iCurrent++)
     {
-        int iColumn = pHeaderCtrl -> OrderToIndex(iCurrent);
+        int iColumn = pHeaderCtrl->OrderToIndex(iCurrent);
         //don't draw column 0 again
         if (iColumn == 0)
         continue;
@@ -624,26 +625,26 @@ void CMuleListCtrl:: DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
         rcLabel = rcCol;
         rcLabel.left += iOffset;
         rcLabel.right -= iOffset;
-        pDC -> DrawText(sLabel, - 1, rcLabel, MLC_DT_TEXT | nJustify);
+        pDC->DrawText(sLabel, - 1, rcLabel, MLC_DT_TEXT | nJustify);
     }
     //draw focus rectangle if item has focus
     if ((lvi.state &LVIS_FOCUSED) && (bCtrlFocused || (lvi.state &LVIS_SELECTED)))
     {
         if (!bCtrlFocused || ! (lvi.state &LVIS_SELECTED))
-        pDC -> FrameRect(rcHighlight, &CBrush(m_crNoFocusLine));
+        pDC->FrameRect(rcHighlight, &CBrush(m_crNoFocusLine));
         else
-        pDC -> FrameRect(rcHighlight, &CBrush(m_crFocusLine));
+        pDC->FrameRect(rcHighlight, &CBrush(m_crFocusLine));
     }
 }
 
 #endif
 
 #if 0
-BOOL CMuleListCtrl:: OnEraseBkgnd(CDC *pDC)
+BOOL CMuleListCtrl::OnEraseBkgnd(CDC *pDC)
 {
     int itemCount = GetItemCount();
     if (!itemCount)
-    return CListCtrl:: OnEraseBkgnd(pDC);
+    return CListCtrl::OnEraseBkgnd(pDC);
     RECT clientRect;
     RECT itemRect;
     int topIndex = GetTopIndex();
@@ -653,21 +654,21 @@ BOOL CMuleListCtrl:: OnEraseBkgnd(CDC *pDC)
     GetClientRect( &clientRect);
     GetItemRect(topIndex, &itemRect, LVIR_BOUNDS);
     clientRect.bottom = itemRect.top;
-    pDC -> FillSolidRect( &clientRect, GetBkColor());
+    pDC->FillSolidRect( &clientRect, GetBkColor());
     //draw bottom portion if we have to
     if (topIndex + maxItems >= itemCount)
     {
         GetClientRect( &clientRect);
         GetItemRect(topIndex + drawnItems - 1, &itemRect, LVIR_BOUNDS);
         clientRect.top = itemRect.bottom;
-        pDC -> FillSolidRect( &clientRect, GetBkColor());
+        pDC->FillSolidRect( &clientRect, GetBkColor());
     }
     //draw right half if we need to
     if (itemRect.right < clientRect.right)
     {
         GetClientRect( &clientRect);
         clientRect.left = itemRect.right;
-        pDC -> FillSolidRect( &clientRect, GetBkColor());
+        pDC->FillSolidRect( &clientRect, GetBkColor());
     }
     return TRUE;
 }
@@ -675,10 +676,10 @@ BOOL CMuleListCtrl:: OnEraseBkgnd(CDC *pDC)
 #endif
 
 #if 0
-void CMuleListCtrl:: OnSysColorChange()
+void CMuleListCtrl::OnSysColorChange()
 {
     //adjust colors
-    CListCtrl:: OnSysColorChange();
+    CListCtrl::OnSysColorChange();
     SetColors();
     //redraw the up/down sort arrow (if it's there)
     if (m_iCurrentSortItem >= 0)
@@ -686,26 +687,26 @@ void CMuleListCtrl:: OnSysColorChange()
         CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
         HDITEM headerItem;
         headerItem.mask = HDI_FORMAT | HDI_BITMAP;
-        if (pHeaderCtrl -> GetItem(m_iCurrentSortItem, &headerItem) &&headerItem.hbm != 0)
+        if (pHeaderCtrl->GetItem(m_iCurrentSortItem, &headerItem) &&headerItem.hbm != 0)
         {
             DeleteObject(headerItem.hbm);
             headerItem.fmt |= HDF_BITMAP | HDF_BITMAP_ON_RIGHT;
             headerItem.hbm = (HBITMAP) LoadImage(AfxGetInstanceHandle(),
             MAKEINTRESOURCE(m_atSortArrow), IMAGE_BITMAP, 0, 0,
             LR_LOADMAP3DCOLORS);
-            pHeaderCtrl -> SetItem(m_iCurrentSortItem, &headerItem);
+            pHeaderCtrl->SetItem(m_iCurrentSortItem, &headerItem);
         }
     }
 }
 
 #endif
 #include "wx/msgdlg.h"
-bool CMuleListCtrl:: ProcessEvent(wxEvent &evt)
+bool CMuleListCtrl::ProcessEvent(wxEvent &evt)
 {
     if ((evt.GetEventType() == wxEVT_COMMAND_MENU_SELECTED) && (evt.GetId() >= MP_LISTCOL_1) && (evt.GetId() <= MP_LISTCOL_15))
     {
         int col = evt.GetId() - MP_LISTCOL_1;
-        if (wxODListCtrl:: GetColumnWidth(col) > m_col_minsize)
+        if (wxODListCtrl::GetColumnWidth(col) > m_col_minsize)
         {
             SetColumnWidth(col, 0);
         }
@@ -718,23 +719,23 @@ bool CMuleListCtrl:: ProcessEvent(wxEvent &evt)
     {
         wxMessageBox("You found an Easter Egg :-) 4/22/2003");
     }
-    return wxODListCtrl:: ProcessEvent(evt);
+    return wxODListCtrl::ProcessEvent(evt);
 }
 
-void CMuleListCtrl:: OnColumnRclick(wxListEvent &evt)
+void CMuleListCtrl::OnColumnRclick(wxListEvent &evt)
 {
     m_ColumnMenu = new wxMenu();
     wxListItem item;
     for (int a = 0 ; a < GetColumnCount() ; a++)
     {
         GetColumn(a, item);
-        m_ColumnMenu -> AppendCheckItem(a + MP_LISTCOL_1, item.GetText());
-        m_ColumnMenu -> Check(a + MP_LISTCOL_1, wxODListCtrl:: GetColumnWidth(a) > m_col_minsize ? true: false);
+        m_ColumnMenu->AppendCheckItem(a + MP_LISTCOL_1, item.GetText());
+        m_ColumnMenu->Check(a + MP_LISTCOL_1, wxODListCtrl::GetColumnWidth(a) > m_col_minsize ? true: false);
     }
     PopupMenu(m_ColumnMenu, evt.GetPoint());
 }
 
 BEGIN_EVENT_TABLE(CMuleListCtrl, wxODListCtrl)
-EVT_LIST_COL_RIGHT_CLICK( - 1, CMuleListCtrl:: OnColumnRclick)
+EVT_LIST_COL_RIGHT_CLICK( - 1, CMuleListCtrl::OnColumnRclick)
 END_EVENT_TABLE()
 
