@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -21,7 +21,7 @@
 // Purpose:     CMuleNotebook class
 // Author:      Robert Roebling
 // Modified by:
-// RCS-ID:      $Id: MuleNotebook.h,v 1.5.8.2 2004/04/30 21:13:18 fsch2010 Exp $
+// RCS-ID:      $Id: MuleNotebook.h,v 1.26 2004/08/15 04:04:15 HopeSeekr Exp $
 // Copyright:   (c) Julian Smart and Robert Roebling
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -33,6 +33,7 @@
 #pragma interface
 #endif
 
+#include "CMuleNotebookBase.h"          // Needed for CMuleNotebookBase
 //-----------------------------------------------------------------------------
 // internal class
 //-----------------------------------------------------------------------------
@@ -42,6 +43,7 @@ class wxGtkMuleNotebookPage;
 #include "wx/list.h"
 WX_DECLARE_LIST(wxGtkMuleNotebookPage, wxGtkMuleNotebookPagesList);
 
+#include "CMuleNotebookBase.h"          // Needed for CMuleNotebookBase
 //-----------------------------------------------------------------------------
 // CMuleNotebook
 //-----------------------------------------------------------------------------
