@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -17,24 +17,17 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// OScopeCtrl.h : header file
-//
-
 #ifndef __OScopeCtrl_H__
 #define __OScopeCtrl_H__
 
-#include "mfc.h"
-#include "wintypes.h"
+#include "mfc.h"                        // Needed for CString 
+#include "wintypes.h"                   // Needed for COLORREF
+
+#include <wx/control.h>                 // Needed for wxControl
+#include <wx/dcmemory.h>                // Needed for wxMemoryDC
+#include <wx/timer.h>                   // Needed for wxTimer
 
-#include <wx/control.h>
-#include <wx/dcmemory.h>
-#include <wx/bitmap.h>
-#include <wx/timer.h>
 #define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
-
-/////////////////////////////////////////////////////////////////////////////
-// COScopeCtrl window
-
 #define TIMER_OSCOPE 7641
 
 class COScopeCtrl : public wxControl
