@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#include "resource.h"                   // Needed for IDS_SELECT_TEMPDIR
 #	include "DirectoryTreeCtrl.h"
 #	include "otherfunctions.h"
 #	include "PPgDirectories.h"
@@ -72,39 +73,39 @@
 IMPLEMENT_DYNAMIC_CLASS(CPPgDirectories, wxPanel)
 
 //IMPLEMENT_DYNAMIC(CPPgDirectories, CPropertyPage)
-CPPgDirectories:: CPPgDirectories(wxWindow *parent)
-: wxPanel(parent, CPPgDirectories:: IDD)
+CPPgDirectories::CPPgDirectories(wxWindow *parent)
+: wxPanel(parent, CPPgDirectories::IDD)
 {
     wxNotebook *book = (wxNotebook *) parent;
-    wxPanel *page1 = wxXmlResource:: Get() -> LoadPanel(this, "DLG_PPG_DIRECTORIES");
-    book -> AddPage(this, _("Directories"));
-    SetSize(page1 -> GetSize() .GetWidth(), page1 -> GetSize() .GetHeight() + 40);
+    wxPanel *page1 = wxXmlResource::Get()->LoadPanel(this, "DLG_PPG_DIRECTORIES");
+    book->AddPage(this, _("Directories"));
+    SetSize(page1->GetSize() .GetWidth(), page1->GetSize() .GetHeight() + 40);
     // then replace the existing tree control with our own
     wxTreeCtrl *oldtree = GetDlgItem(IDC_SHARESELECTOR, wxTreeCtrl);
-    wxPoint pos = oldtree -> GetPosition();
-    wxSize siz = oldtree -> GetSize();
+    wxPoint pos = oldtree->GetPosition();
+    wxSize siz = oldtree->GetSize();
     // then replace it with our own
-    oldtree -> Destroy();
+    oldtree->Destroy();
     CDirectoryTreeCtrl *newtree = new CDirectoryTreeCtrl((wxWindow *) page1, XRCID("IDC_SHARESELECTOR"),
     pos, siz, wxTR_CHECKBOX |wxSUNKEN_BORDER |wxTR_DEFAULT_STYLE);
     m_ShareSelector = newtree;
     Localize();
 }
 
-CPPgDirectories:: ~CPPgDirectories()
+CPPgDirectories::~CPPgDirectories()
 {
 }
 
 BEGIN_EVENT_TABLE(CPPgDirectories, wxPanel)
-EVT_BUTTON(XRCID("IDC_SELTEMPDIR"), CPPgDirectories:: OnBnClickedSeltempdir)
-EVT_BUTTON(XRCID("IDC_SELINCDIR"), CPPgDirectories:: OnBnClickedSelincdir)
-EVT_BUTTON(XRCID("IDC_BROWSEV"), CPPgDirectories:: BrowseVideoplayer)
+EVT_BUTTON(XRCID("IDC_SELTEMPDIR"), CPPgDirectories::OnBnClickedSeltempdir)
+EVT_BUTTON(XRCID("IDC_SELINCDIR"), CPPgDirectories::OnBnClickedSelincdir)
+EVT_BUTTON(XRCID("IDC_BROWSEV"), CPPgDirectories::BrowseVideoplayer)
 END_EVENT_TABLE()
 
 #if 0
-void CPPgDirectories:: DoDataExchange(CDataExchange *pDX)
+void CPPgDirectories::DoDataExchange(CDataExchange *pDX)
 {
-    CPropertyPage:: DoDataExchange(pDX);
+    CPropertyPage::DoDataExchange(pDX);
     DDX_Control(pDX, IDC_SHARESELECTOR, m_ShareSelector);
 }
 
@@ -121,12 +122,12 @@ END_MESSAGE_MAP()
 
 // CPPgDirectories message handlers
 
-BOOL CPPgDirectories:: OnInitDialog()
+BOOL CPPgDirectories::OnInitDialog()
 {
-    CPropertyPage:: OnInitDialog();
+    CPropertyPage::OnInitDialog();
     m_ShareSelector.Init();
-    ((CEdit *) GetDlgItem(IDC_INCFILES)) -> SetLimitText(509);
-    ((CEdit *) GetDlgItem(IDC_TEMPFILES)) -> SetLimitText(509);
+    ((CEdit *) GetDlgItem(IDC_INCFILES))->SetLimitText(509);
+    ((CEdit *) GetDlgItem(IDC_TEMPFILES))->SetLimitText(509);
     LoadSettings();
     Localize();
     // return TRUE unless you set the focus to a control:
@@ -136,13 +137,13 @@ BOOL CPPgDirectories:: OnInitDialog()
 
 #endif
 
-void CPPgDirectories:: LoadSettings(void)
+void CPPgDirectories::LoadSettings(void)
 {
-    GetDlgItem(IDC_INCFILES, wxTextCtrl) -> SetValue(app_prefs -> prefs -> incomingdir);
-    GetDlgItem(IDC_TEMPFILES, wxTextCtrl) -> SetValue(app_prefs -> prefs -> tempdir);
-    m_ShareSelector -> SetSharedDirectories( &app_prefs -> shareddir_list);
-    GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl) -> SetValue(app_prefs -> prefs -> VideoPlayer);
-    if (app_prefs -> prefs -> moviePreviewBackup)
+    GetDlgItem(IDC_INCFILES, wxTextCtrl)->SetValue(app_prefs->prefs->incomingdir);
+    GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->SetValue(app_prefs->prefs->tempdir);
+    m_ShareSelector->SetSharedDirectories( &app_prefs->shareddir_list);
+    GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl)->SetValue(app_prefs->prefs->VideoPlayer);
+    if (app_prefs->prefs->moviePreviewBackup)
     CheckDlgButton(IDC_VIDEOBACKUP, 1);
     else
     CheckDlgButton(IDC_VIDEOBACKUP, 0);
@@ -151,7 +152,7 @@ void CPPgDirectories:: LoadSettings(void)
 #include <wx/dirdlg.h>
 #include <wx/filedlg.h>
 
-bool CPPgDirectories:: SelectDir(char *outdir, char *titletext)
+bool CPPgDirectories::SelectDir(char *outdir, char *titletext)
 {
     wxString str = wxDirSelector(titletext, "");
     if (str.IsEmpty())
@@ -173,99 +174,101 @@ bool CPPgDirectories:: SelectDir(char *outdir, char *titletext)
     done = SHGetPathFromIDList(pidl, outdir);
     LPMALLOC ppMalloc;
     if (SHGetMalloc( &ppMalloc) == NOERROR)
-    ppMalloc -> Free(pidl);
+    ppMalloc->Free(pidl);
     CoUninitialize();
     return done;
 #endif
 }
 
-void CPPgDirectories:: OnBnClickedSelincdir(wxEvent &e)
+void CPPgDirectories::OnBnClickedSelincdir(wxEvent &e)
 {
     char buffer[MAX_PATH];
     if (SelectDir(buffer, (char *)(GetResString(IDS_SELECT_INCOMINGDIR) .GetData())))
-    GetDlgItem(IDC_INCFILES, wxTextCtrl) -> SetValue(buffer);
+    GetDlgItem(IDC_INCFILES, wxTextCtrl)->SetValue(buffer);
 }
 
-void CPPgDirectories:: OnBnClickedSeltempdir(wxEvent &e)
+void CPPgDirectories::OnBnClickedSeltempdir(wxEvent &e)
 {
     char buffer[MAX_PATH];
     if (SelectDir(buffer, (char *)(GetResString(IDS_SELECT_TEMPDIR) .GetData())))
-    GetDlgItem(IDC_TEMPFILES, wxTextCtrl) -> SetValue(buffer);
+    {
+        GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->SetValue(buffer);
+    }
 }
 
-void CPPgDirectories:: BrowseVideoplayer(wxEvent &e)
+void CPPgDirectories::BrowseVideoplayer(wxEvent &e)
 {
 #if 0
     CFileDialog dlgFile(TRUE, "*.exe", NULL, OFN_FILEMUSTEXIST | OFN_NOREADONLYRETURN, "Executable (*.exe)|*.exe||");
-    if (dlgFile.DoModal() == IDOK) GetDlgItem(IDC_VIDEOPLAYER) -> SetWindowText(dlgFile.GetPathName());
+    if (dlgFile.DoModal() == IDOK) GetDlgItem(IDC_VIDEOPLAYER)->SetWindowText(dlgFile.GetPathName());
 #endif
     wxString str = wxFileSelector(_("Browse for videoplayer"), "", "", "", _("Executable (*)|*||"));
     if (!str.IsEmpty())
     {
-        GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl) -> SetValue(str);
+        GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl)->SetValue(str);
     }
 }
 
-BOOL CPPgDirectories:: OnApply()
+BOOL CPPgDirectories::OnApply()
 {
     wxString buffer;
     // Will be set true if Incoming directory changed:
     bool IncomingChanged = false;
     // Will be set true if Temp directory changed:
     bool TempChanged = false;
-    if (GetDlgItem(IDC_INCFILES, wxTextCtrl) -> GetValue() .Length())
+    if (GetDlgItem(IDC_INCFILES, wxTextCtrl)->GetValue() .Length())
     {
-        buffer = GetDlgItem(IDC_INCFILES, wxTextCtrl) -> GetValue();
-        if (strcmp(app_prefs -> prefs -> incomingdir, buffer.GetData()) != 0)
+        buffer = GetDlgItem(IDC_INCFILES, wxTextCtrl)->GetValue();
+        if (strcmp(app_prefs->prefs->incomingdir, buffer.GetData()) != 0)
         {
             IncomingChanged = true;
         }
-        strcpy(app_prefs -> prefs -> incomingdir, buffer.GetData());
+        strcpy(app_prefs->prefs->incomingdir, buffer.GetData());
     }
-    if (GetDlgItem(IDC_TEMPFILES, wxTextCtrl) -> GetValue() .Length())
+    if (GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->GetValue() .Length())
     {
-        buffer = GetDlgItem(IDC_TEMPFILES, wxTextCtrl) -> GetValue();
-        if (strcmp(app_prefs -> prefs -> tempdir, buffer.GetData()) != 0)
+        buffer = GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->GetValue();
+        if (strcmp(app_prefs->prefs->tempdir, buffer.GetData()) != 0)
         {
             TempChanged = true;
         }
-        strcpy(app_prefs -> prefs -> tempdir, buffer.GetData());
+        strcpy(app_prefs->prefs->tempdir, buffer.GetData());
     }
-    buffer = GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl) -> GetValue();
-    strcpy(app_prefs -> prefs -> VideoPlayer, buffer.GetData());
-    app_prefs -> prefs -> moviePreviewBackup = IsDlgButtonChecked(IDC_VIDEOBACKUP);
-    app_prefs -> shareddir_list.Clear();
-    m_ShareSelector -> GetSharedDirectories( &app_prefs -> shareddir_list);
-    if (IncomingChanged || TempChanged || m_ShareSelector -> HasChanged)
-    theApp.sharedfiles -> Reload(true, false);
+    buffer = GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl)->GetValue();
+    strcpy(app_prefs->prefs->VideoPlayer, buffer.GetData());
+    app_prefs->prefs->moviePreviewBackup = IsDlgButtonChecked(IDC_VIDEOBACKUP);
+    app_prefs->shareddir_list.Clear();
+    m_ShareSelector->GetSharedDirectories( &app_prefs->shareddir_list);
+    if (IncomingChanged || TempChanged || m_ShareSelector->HasChanged)
+    theApp.sharedfiles->Reload(true, false);
     //return CPropertyPage::OnApply();
     return TRUE;
 }
 
 #if 0
-BOOL CPPgDirectories:: OnCommand(WPARAM wParam, LPARAM lParam)
+BOOL CPPgDirectories::OnCommand(WPARAM wParam, LPARAM lParam)
 {
     //	if(wParam == USRMSG_ITEMSTATECHANGED)
     //		SetModified();
-    return CPropertyPage:: OnCommand(wParam, lParam);
+    return CPropertyPage::OnCommand(wParam, lParam);
 }
 
 #endif
 
-void CPPgDirectories:: Localize(void)
+void CPPgDirectories::Localize(void)
 {
     if (1)
     {
         //SetWindowText(GetResString(IDS_PW_DIR));
-        GetDlgItem(IDC_INCOMING_FRM, wxControl) -> SetLabel(GetResString(IDS_PW_INCOMING));
-        GetDlgItem(IDC_TEMP_FRM, wxControl) -> SetLabel(GetResString(IDS_PW_TEMP));
-        GetDlgItem(IDC_SELINCDIR, wxControl) -> SetLabel(GetResString(IDS_PW_BROWSE));
-        GetDlgItem(IDC_SELTEMPDIR, wxControl) -> SetLabel(GetResString(IDS_PW_BROWSE));
-        GetDlgItem(IDC_BROWSEV, wxControl) -> SetLabel(GetResString(IDS_PW_BROWSE));
-        GetDlgItem(IDC_SHARED_FRM, wxControl) -> SetLabel(GetResString(IDS_PW_SHARED));
-        GetDlgItem(IDC_STATICVIDEOPLAYER, wxControl) -> SetLabel(GetResString(IDS_PW_VIDEOPLAYER));
-        GetDlgItem(IDC_VIDEOBACKUP, wxControl) -> SetLabel(GetResString(IDS_VIDEOBACKUP));
-        GetDlgItem(IDC_STATIC_EMPTY, wxControl) -> SetLabel(GetResString(IDS_STATIC_EMPTY));
+        GetDlgItem(IDC_INCOMING_FRM, wxControl)->SetLabel(GetResString(IDS_PW_INCOMING));
+        GetDlgItem(IDC_TEMP_FRM, wxControl)->SetLabel(GetResString(IDS_PW_TEMP));
+        GetDlgItem(IDC_SELINCDIR, wxControl)->SetLabel(GetResString(IDS_PW_BROWSE));
+        GetDlgItem(IDC_SELTEMPDIR, wxControl)->SetLabel(GetResString(IDS_PW_BROWSE));
+        GetDlgItem(IDC_BROWSEV, wxControl)->SetLabel(GetResString(IDS_PW_BROWSE));
+        GetDlgItem(IDC_SHARED_FRM, wxControl)->SetLabel(GetResString(IDS_PW_SHARED));
+        GetDlgItem(IDC_STATICVIDEOPLAYER, wxControl)->SetLabel(GetResString(IDS_PW_VIDEOPLAYER));
+        GetDlgItem(IDC_VIDEOBACKUP, wxControl)->SetLabel(GetResString(IDS_VIDEOBACKUP));
+        GetDlgItem(IDC_STATIC_EMPTY, wxControl)->SetLabel(GetResString(IDS_STATIC_EMPTY));
         //GetDlgItem(IDC_INCLUDESUBDIRS)->SetWindowText(GetResString(IDS_PW_DIR_INCSUBDIR));
     }
 }
