@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -20,15 +20,11 @@
 #ifndef PPGGEN_H
 #define PPGGEN_H
 
-#include "Preferences.h"
-#include "resource.h"
-//#include "afxwin.h"
+#include "Preferences.h"                // Needed for CPreferences
+#include "wx/panel.h"                   // Needed for wxPanel
+#include "wx/combobox.h"                // Needed for wxComboBox
 
-// CPPgGeneral dialog
-#include "wx/panel.h"
-#include "wx/combobox.h"
-
-class CPPgGeneral : public wxPanel //CPropertyPage
+class CPPgGeneral : public wxPanel
 {
   //DECLARE_DYNAMIC(CPPgGeneral)
   DECLARE_DYNAMIC_CLASS(CPPgGeneral)
@@ -41,7 +37,11 @@ public:
 	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }
 
 // Dialog Data
-	enum { IDD = IDD_PPG_GENERAL };
+	enum
+        {
+            IDD_PPG_GENERAL,
+            IDD = IDD_PPG_GENERAL
+        };
 protected:
 	CPreferences *app_prefs;
 protected:
