@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 #	include "PPgNotify.h"
 #	include "Preferences.h"
 #	include "wintypes.h"
+#include "resource.h"                   // Needed for IDS_PW_TBN_USESOUND
 #	include "xmule.h"
 #endif
 
@@ -41,57 +42,57 @@
 //IMPLEMENT_DYNAMIC(CPPgNotify, CPropertyPage)
 IMPLEMENT_DYNAMIC_CLASS(CPPgNotify, wxPanel)
 
-CPPgNotify:: CPPgNotify(wxWindow *parent)
-: wxPanel(parent, CPPgNotify:: IDD)
+CPPgNotify::CPPgNotify(wxWindow *parent)
+: wxPanel(parent, CPPgNotify::IDD)
 {
     wxNotebook *book = (wxNotebook *) parent;
-    wxPanel *page1 = wxXmlResource:: Get() -> LoadPanel(this, "DLG_PPG_NOTIFY");
-    book -> AddPage(this, _("Notify"));
+    wxPanel *page1 = wxXmlResource::Get()->LoadPanel(this, "DLG_PPG_NOTIFY");
+    book->AddPage(this, _("Notify"));
     // looks stupid? it is :)
-    SetSize(page1 -> GetSize() .GetWidth(), page1 -> GetSize() .GetHeight() + 48);
-    page1 -> SetSize(GetSize());
+    SetSize(page1->GetSize() .GetWidth(), page1->GetSize() .GetHeight() + 48);
+    page1->SetSize(GetSize());
     LoadSettings();
     Localize();
 }
 
-CPPgNotify:: ~CPPgNotify()
+CPPgNotify::~CPPgNotify()
 {
 }
 
 #if 0
-void CPPgNotify:: DoDataExchange(CDataExchange *pDX)
+void CPPgNotify::DoDataExchange(CDataExchange *pDX)
 {
-    CPropertyPage:: DoDataExchange(pDX);
+    CPropertyPage::DoDataExchange(pDX);
 }
 
 #endif
 
-void CPPgNotify:: LoadSettings(void)
+void CPPgNotify::LoadSettings(void)
 {
 #if 0
     CEdit *editPtr;
     CButton *btnPTR;
     if (m_hWnd)
     {
-        if (app_prefs -> prefs -> useDownloadNotifier)
+        if (app_prefs->prefs->useDownloadNotifier)
         CheckDlgButton(IDC_CB_TBN_ONDOWNLOAD, BST_CHECKED);
-        if (app_prefs -> prefs -> useChatNotifier)
+        if (app_prefs->prefs->useChatNotifier)
         CheckDlgButton(IDC_CB_TBN_ONCHAT, BST_CHECKED);
-        if (app_prefs -> prefs -> useSoundInNotifier)
+        if (app_prefs->prefs->useSoundInNotifier)
         CheckDlgButton(IDC_CB_TBN_USESOUND, BST_CHECKED);
-        if (app_prefs -> prefs -> useLogNotifier)
+        if (app_prefs->prefs->useLogNotifier)
         CheckDlgButton(IDC_CB_TBN_ONLOG, BST_CHECKED);
-        if (app_prefs -> prefs -> notifierPopsEveryChatMsg)
+        if (app_prefs->prefs->notifierPopsEveryChatMsg)
         CheckDlgButton(IDC_CB_TBN_POP_ALWAYS, BST_CHECKED);
         btnPTR = (CButton *) GetDlgItem(IDC_CB_TBN_POP_ALWAYS);
-        btnPTR -> EnableWindow(IsDlgButtonChecked(IDC_CB_TBN_ONCHAT));
+        btnPTR->EnableWindow(IsDlgButtonChecked(IDC_CB_TBN_ONCHAT));
         editPtr = (CEdit *) GetDlgItem(IDC_EDIT_TBN_WAVFILE);
-        editPtr -> SetWindowText(LPCTSTR(app_prefs -> prefs -> notifierSoundFilePath));
+        editPtr->SetWindowText(LPCTSTR(app_prefs->prefs->notifierSoundFilePath));
     }
 #endif
 }
 
-wxString CPPgNotify:: DialogBrowseFile(wxString Filters, wxString DefaultFileName)
+wxString CPPgNotify::DialogBrowseFile(wxString Filters, wxString DefaultFileName)
 {
 #if 0
     CFileDialog myFileDialog(true, NULL, LPCTSTR(DefaultFileName),
@@ -102,25 +103,25 @@ wxString CPPgNotify:: DialogBrowseFile(wxString Filters, wxString DefaultFileNam
     return "";
 }
 
-void CPPgNotify:: Localize(void)
+void CPPgNotify::Localize(void)
 {
     if (1)
     {
         //SetWindowText(GetResString(IDS_PW_EKDEV_OPTIONS));
-        GetDlgItem(IDC_CB_TBN_USESOUND, wxControl) -> SetLabel(GetResString(IDS_PW_TBN_USESOUND));
-        GetDlgItem(IDC_BTN_BROWSE_WAV, wxControl) -> SetLabel(GetResString(IDS_PW_BROWSE));
-        GetDlgItem(IDC_CB_TBN_ONLOG, wxControl) -> SetLabel(GetResString(IDS_PW_TBN_ONLOG));
-        GetDlgItem(IDC_CB_TBN_ONCHAT, wxControl) -> SetLabel(GetResString(IDS_PW_TBN_ONCHAT));
-        GetDlgItem(IDC_CB_TBN_POP_ALWAYS, wxControl) -> SetLabel(GetResString(IDS_PW_TBN_POP_ALWAYS));
-        GetDlgItem(IDC_CB_TBN_ONNEWVERSION, wxControl) -> SetLabel(GetResString(IDS_CB_TBN_ONNEWVERSION));
-        GetDlgItem(IDC_CB_TBN_ONDOWNLOAD, wxControl) -> SetLabel(GetResString(IDS_PW_TBN_ONDOWNLOAD));
-        GetDlgItem(IDC_TASKBARNOTIFIER, wxControl) -> SetLabel(GetResString(IDS_PW_TASKBARNOTIFIER));
-        GetDlgItem(IDC_TBN_OPTIONS, wxControl) -> SetLabel(GetResString(IDS_PW_TBN_OPTIONS));
+        GetDlgItem(IDC_CB_TBN_USESOUND, wxControl)->SetLabel(GetResString(IDS_PW_TBN_USESOUND));
+        GetDlgItem(IDC_BTN_BROWSE_WAV, wxControl)->SetLabel(GetResString(IDS_PW_BROWSE));
+        GetDlgItem(IDC_CB_TBN_ONLOG, wxControl)->SetLabel(GetResString(IDS_PW_TBN_ONLOG));
+        GetDlgItem(IDC_CB_TBN_ONCHAT, wxControl)->SetLabel(GetResString(IDS_PW_TBN_ONCHAT));
+        GetDlgItem(IDC_CB_TBN_POP_ALWAYS, wxControl)->SetLabel(GetResString(IDS_PW_TBN_POP_ALWAYS));
+        GetDlgItem(IDC_CB_TBN_ONNEWVERSION, wxControl)->SetLabel(GetResString(IDS_CB_TBN_ONNEWVERSION));
+        GetDlgItem(IDC_CB_TBN_ONDOWNLOAD, wxControl)->SetLabel(GetResString(IDS_PW_TBN_ONDOWNLOAD));
+        GetDlgItem(IDC_TASKBARNOTIFIER, wxControl)->SetLabel(GetResString(IDS_PW_TASKBARNOTIFIER));
+        GetDlgItem(IDC_TBN_OPTIONS, wxControl)->SetLabel(GetResString(IDS_PW_TBN_OPTIONS));
     }
 }
 
 BEGIN_EVENT_TABLE(CPPgNotify, wxPanel)
-EVT_BUTTON(XRCID("IDC_BTN_BROWSE_WAV"), CPPgNotify:: OnBnClickedBtnBrowseWav)
+EVT_BUTTON(XRCID("IDC_BTN_BROWSE_WAV"), CPPgNotify::OnBnClickedBtnBrowseWav)
 END_EVENT_TABLE()
 
 #if 0
@@ -135,9 +136,9 @@ END_MESSAGE_MAP()
 
 // gestori di messaggi CPPgNotify
 
-BOOL CPPgNotify:: OnInitDialog()
+BOOL CPPgNotify::OnInitDialog()
 {
-    CPropertyPage:: OnInitDialog();
+    CPropertyPage::OnInitDialog();
     LoadSettings();
     Localize();
     // return TRUE unless you set the focus to a control:
@@ -147,18 +148,18 @@ BOOL CPPgNotify:: OnInitDialog()
 
 #endif
 
-BOOL CPPgNotify:: OnApply()
+BOOL CPPgNotify::OnApply()
 {
     wxTextCtrl *editPTR;
     wxString buffer;
-    app_prefs -> prefs -> useDownloadNotifier = IsDlgButtonChecked(IDC_CB_TBN_ONDOWNLOAD);
-    app_prefs -> prefs -> useChatNotifier = IsDlgButtonChecked(IDC_CB_TBN_ONCHAT);
-    app_prefs -> prefs -> useLogNotifier = IsDlgButtonChecked(IDC_CB_TBN_ONLOG);
-    app_prefs -> prefs -> useSoundInNotifier = IsDlgButtonChecked(IDC_CB_TBN_USESOUND);
-    app_prefs -> prefs -> notifierPopsEveryChatMsg = IsDlgButtonChecked(IDC_CB_TBN_POP_ALWAYS);
+    app_prefs->prefs->useDownloadNotifier = IsDlgButtonChecked(IDC_CB_TBN_ONDOWNLOAD);
+    app_prefs->prefs->useChatNotifier = IsDlgButtonChecked(IDC_CB_TBN_ONCHAT);
+    app_prefs->prefs->useLogNotifier = IsDlgButtonChecked(IDC_CB_TBN_ONLOG);
+    app_prefs->prefs->useSoundInNotifier = IsDlgButtonChecked(IDC_CB_TBN_USESOUND);
+    app_prefs->prefs->notifierPopsEveryChatMsg = IsDlgButtonChecked(IDC_CB_TBN_POP_ALWAYS);
     editPTR = GetDlgItem(IDC_EDIT_TBN_WAVFILE, wxTextCtrl);
-    buffer = editPTR -> GetValue();
-    sprintf(app_prefs -> prefs -> notifierSoundFilePath, "%s", buffer.GetData());
+    buffer = editPTR->GetValue();
+    sprintf(app_prefs->prefs->notifierSoundFilePath, "%s", buffer.GetData());
     //SaveConfiguration();
     //SetModified(FALSE);
     //return CPropertyPage::OnApply();
@@ -166,17 +167,17 @@ BOOL CPPgNotify:: OnApply()
 }
 
 #if 0
-void CPPgNotify:: OnBnClickedCbTbnOnchat()
+void CPPgNotify::OnBnClickedCbTbnOnchat()
 {
     CButton *btnPTR;
     btnPTR = (CButton *) GetDlgItem(IDC_CB_TBN_POP_ALWAYS);
-    btnPTR -> EnableWindow(IsDlgButtonChecked(IDC_CB_TBN_ONCHAT));
+    btnPTR->EnableWindow(IsDlgButtonChecked(IDC_CB_TBN_ONCHAT));
     SetModified();
 }
 
 #endif
 
-void CPPgNotify:: OnBnClickedBtnBrowseWav(wxEvent &evt)
+void CPPgNotify::OnBnClickedBtnBrowseWav(wxEvent &evt)
 {
     wxTextCtrl *editPTR;
     wxString buffer;
@@ -184,9 +185,9 @@ void CPPgNotify:: OnBnClickedBtnBrowseWav(wxEvent &evt)
     buffer =
     wxFileSelector(_("Browse wav"), "", "", "*.wav", _("File wav (*.wav)|*.wav||"));
     editPTR = (wxTextCtrl *) GetDlgItem(IDC_EDIT_TBN_WAVFILE, wxTextCtrl);
-    editPTR -> SetValue((buffer));
+    editPTR->SetValue((buffer));
     // Added by enkeyDEV:
-    sprintf(app_prefs -> prefs -> notifierSoundFilePath, "%s", buffer.GetData());
+    sprintf(app_prefs->prefs->notifierSoundFilePath, "%s", buffer.GetData());
     //SetModified();
 }
 
