@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -22,13 +22,9 @@
 
 class CPreferences;
 
-#include "resource.h"
+#include <wx/panel.h>                   // Needed for wxPanel
 
-#include <wx/panel.h>
-
-// finestra di dialogo CPPgNotify
-
-class CPPgNotify : public wxPanel // CPropertyPage
+class CPPgNotify : public wxPanel
 {
   //DECLARE_DYNAMIC(CPPgNotify)
   DECLARE_DYNAMIC_CLASS(CPPgNotify)
@@ -44,13 +40,17 @@ public:
 	void LoadSettings(void);
 
 // Dialog Data
-	enum { IDD = IDD_PPG_NOTIFY };
+	enum
+        {
+            IDD_PPG_NOTIFY,
+            IDD = IDD_PPG_NOTIFY
+        };
 
 protected:
 	CPreferences* app_prefs;
 protected:
 	//virtual void DoDataExchange(CDataExchange* pDX);    // Supporto DDX/DDV
-	wxString CPPgNotify::DialogBrowseFile(wxString Filters, wxString DefaultFileName="");
+	wxString DialogBrowseFile(wxString Filters, wxString DefaultFileName="");
 
 	//DECLARE_MESSAGE_MAP()
 	DECLARE_EVENT_TABLE()
