@@ -1,38 +1,31 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
-//
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifndef PARTFILE_H
 #define PARTFILE_H
 
-#include "wintypes.h"
-#include "KnownFile.h"
-#include "types.h"
-#include "NewFunctions.h"
-#include "opcodes.h"
-#include "BarShader.h"
-#include "ED2KLink.h"
-#include "wx/dc.h"
-#include "wx/dcmemory.h"
-#include "wx/treectrl.h"
-#include "otherfunctions.h"
+#include "KnownFile.h"                  // Needed for CKnownFile
+#include "otherfunctions.h"             // Needed for GetTickCount
+#include "otherstructs.h"               // Needed for Requested_Block_Struct
+#include "types.h"                      // Needed for uint32
 
 #define	PS_READY			0
 #define	PS_EMPTY			1
@@ -119,8 +112,8 @@ public:
 	bool 	IsText();
 	
 	
-	CString CPartFile::getPartfileStatus(); //<<--9/21/02
-	sint32	CPartFile::getTimeRemaining(); //<<--9/21/02
+	CString getPartfileStatus(); //<<--9/21/02
+	sint32	getTimeRemaining(); //<<--9/21/02
 	time_t	lastseencomplete;
 	int		getPartfileStatusRang();
         CString GetDownloadFileInfo();
@@ -288,8 +281,9 @@ public:
           }
 
       private:
-	  MAP * listof_downloadingSources;
 
+          /* downloading sources list */
+          CTypedPtrList<CPtrList, CUpDownClient*> m_downloadingSourcesList;
 
           /* A4AF Auto attribute */
           bool m_IsA4AFAuto;
