@@ -1,22 +1,38 @@
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 #ifndef PREFERDLG_H
 #define PREFERDLG_H
 
-#include "PPgGeneral.h"
-#include "PPgConnection.h"
-#include "PPgServer.h"
-#include "PPgDirectories.h"
-#include "PPgFiles.h"
-#include "PPgStats.h"
-#include "PPgNotify.h"
-#include "PPgIrc.h"
-#include "PPgTweaks.h"
-#include "PPgSourcesDropping.h"
-#include "PPgGuiTweaks.h"
-#include "otherfunctions.h"
+#include <wx/dialog.h>                  // Needed for wxDialog
+#include "PPgGeneral.h"                 // Needed for CPPgGeneral
+#include "PPgConnection.h"              // Needed for CPPgConnection
+#include "PPgServer.h"                  // Needed for CPPgServer
+#include "PPgDirectories.h"             // Needed for CPPgDirectories
+#include "PPgFiles.h"                   // Needed for CPPgFiles
+#include "PPgStats.h"                   // Needed for CPPgStats
+#include "PPgNotify.h"                  // Needed for CPPgNotify
+#include "PPgTweaks.h"                  // Needed for CPPgTweaks
+#include "PPgSourcesDropping.h"         // Needed for CPPgSourcesDropping
+#include "PPgGuiTweaks.h"               // Needed for CPPgGuiTweaks
 
-// CPreferencesDlg
-
-class CPreferencesDlg : public wxDialog //CPropertySheet
+class CPreferencesDlg : public wxDialog
 {
   //DECLARE_DYNAMIC(CPreferencesDlg)
   DECLARE_DYNAMIC_CLASS(CPreferencesDlg)
@@ -39,7 +55,6 @@ public:
 	CPPgFiles*		m_wndFiles;
 	CPPgStats*		m_wndStats;
 	CPPgNotify*		m_wndNotify;
-	CPPgIRC*			m_wndIRC;
 	CPPgTweaks*		m_wndTweaks;
 	CPPgSourcesDropping*    m_wndSourcesDropping;  // Sources Dropping window
 	CPPgGuiTweaks*          m_wndGuiTweaks; // GUI Tweaks window
