@@ -1,5 +1,7 @@
 // This file is a part of the xMule Project.
 //
+// Copyright (c) 2004 Franz Schneider (sf -at- fsch -dot- net / http://www.xmule.ws/)
+//
 // This file was a part of eMule
 // Copyright (c) 2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
@@ -16,27 +18,19 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-//
 
 #ifndef SEARCHDLG_H
 #define SEARCHDLG_H
 
-#include <wx/defs.h>		// Needed before any other wx/*.h
-#include <wx/panel.h>		// Needed for wxPanel
-#include <wx/combobox.h>	// Needed for wxComboBox
-#include <wx/imaglist.h>	// Needed for wxImageList
-#include <wx/timer.h>		// Needed for wxTimer and wxTimerEvent
-#include <wx/statbmp.h>		// Needed for wxStaticBitmap
-#include <wx/listbase.h>	// Needed for wxListEvent
-#include <wx/gauge.h>		// Needed for wxGauge
-#include <wx/notebook.h>	// Needed for wxNotebookEvent
-
-#include "resource.h"		// Needed for IDD_SEARCH
-
+#include <wx/panel.h>                   // Needed for wxPanel
+#include <wx/combobox.h>                // Needed for wxComboBox
+#include <wx/imaglist.h>                // Needed for wxImageList
+#include <wx/timer.h>                   // Needed for wxTimer and wxTimerEvent
+#include <wx/statbmp.h>                 // Needed for wxStaticBitmap
+#include <wx/listbase.h>                // Needed for wxListEvent
 
 class Packet;
 
-// CSearchDlg dialog
 class CSearchDlg : public wxPanel {
     DECLARE_DYNAMIC_CLASS(CSearchDlg)
     public:
@@ -51,7 +45,9 @@ class CSearchDlg : public wxPanel {
     void CreateNewTab(wxString searchString,wxUint32 nSearchID);
     void SearchEnd(char *packet,wxUint32 packetsize,wxUint32 nServerIP,wxUint16 nServerPort);
     void UpdateCatChoice();
-    enum {
+    enum 
+    {
+        IDD_SEARCH,
         IDD = IDD_SEARCH 
     };
     // public member variables
@@ -99,7 +95,7 @@ private:
     void ShowSearchResults();
     wxString CreateWebQuery();
     // private member variables
-    int srtab_deep, srtab_lock, srtab_refresh;
+    int srtab_deep,srtab_lock;
     int smaskhighest,smaskcurrent;
     wxComboBox typebox;
     wxComboBox Stypebox;
@@ -114,7 +110,7 @@ private:
 
 // ESearchType
 enum ESearchType {
-    //NOTE: The numbers are *equal* to the entries in the comboxbox -> TODO: use item data
+    //NOTE: The numbers are *equal* to the entries in the comboxbox->TODO: use item data
     SearchTypeServer = 0,
     SearchTypeGlobal,
     SearchTypeJigleSOAP,
