@@ -1,32 +1,30 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif // HAVE_CONFIG_H
+#include "config.h"
 
 // Test if we have _GNU_SOURCE before the next step will mess up
 // setting __USE_GNU
 // (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
-#include "wx/setup.h"
+#include <wx/setup.h>
 
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
@@ -34,24 +32,24 @@
 #include <sys/param.h>
 #endif
 
-#ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "DownloadQueue.h"
-#	include "HTTPDownloadDlg.h"
-#	include "SafeFile.h"
-#	include "ServerList.h"
-#	include "ServerWnd.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#endif
+#include "ServerList.h"                     // Needed for this Interface's Prototype
+#include "ldaemon.h"                        // Needed for LDAEMON_H
+#include "ListenSocket.h"                   // Needed for TooManySockets
+#include "otherfunctions.h"                 // Needed for GetTickCount
+#include "PartFile.h"                       // Needed for SRV_PR_HIGH
+#include "DownloadQueue.h"
+#include "HTTPDownloadDlg.h"
+#include "SafeFile.h"
+#include "ServerWnd.h"
+#include "xmule.h"
+#include "xmuleDlg.h"
 
 #include <wx/msgdlg.h>
 
 #include <wx/listimpl.cpp>
 //WX_DEFINE_LIST(CServerListList);
 
-CServerList:: CServerList(CPreferences *in_prefs):
+CServerList::CServerList(CPreferences *in_prefs):
 list(wxKEY_NONE)
 {
     servercount = 0;
@@ -63,40 +61,40 @@ list(wxKEY_NONE)
     //udp_timer = 0;
     udp_timer.SetOwner(theApp.xmuledlg, 4322);
     delservercount = 0;
-    m_nLastSaved =:: GetTickCount();
+    m_nLastSaved =::GetTickCount();
 }
 
-void CServerList:: AutoUpdate()
+void CServerList::AutoUpdate()
 {
-    if (app_prefs -> adresses_list.IsEmpty())
+    if (app_prefs->adresses_list.IsEmpty())
     {
         wxMessageBox(GetResString(IDS_ERR_EMPTYADRESSESDAT), GetResString(IDS_ERR_EMPTYADRESSESDAT_TITLE), wxICON_ERROR |wxCENTRE |wxOK);
         return;
     }
     bool bDownloaded = false;
     CString servermetdownload;
-    //	CString servermetbackup;
+    //  CString servermetbackup;
     CString servermet;
     CString strURLToDownload;
-    servermetdownload.Format("%sserver_met.download", app_prefs -> GetAppDir());
-    servermet.Format("%sserver.met", app_prefs -> GetAppDir());
+    servermetdownload.Format("%sserver_met.download", app_prefs->GetAppDir());
+    servermet.Format("%sserver.met", app_prefs->GetAppDir());
     BackupFile(servermet, ".old");
     wxRemoveFile(servermetdownload);
-    POSITION Pos = app_prefs -> adresses_list.GetHeadPosition();
+    POSITION Pos = app_prefs->adresses_list.GetHeadPosition();
     while ((!bDownloaded) && (Pos != NULL))
     {
         CHTTPDownloadDlg *dlgDownload;
-        strURLToDownload = app_prefs -> adresses_list.GetNext(Pos);
+        strURLToDownload = app_prefs->adresses_list.GetNext(Pos);
         //dlgDownload.m_sURLToDownload = strURLToDownload.GetBuffer();
         //dlgDownload.m_sFileToDownloadInto = servermetdownload;
         dlgDownload = new CHTTPDownloadDlg(theApp.xmuledlg, wxString(strURLToDownload.GetData()), wxString(servermetdownload.GetData()));
-        if (dlgDownload -> ShowModal() == 0)
+        if (dlgDownload->ShowModal() == 0)
         {
             bDownloaded = true;
         }
         else
         {
-            theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_ERR_FAILEDDOWNLOADMET), strURLToDownload.GetBuffer());
+            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FAILEDDOWNLOADMET), strURLToDownload.GetBuffer());
         }
         delete dlgDownload;
     }
@@ -112,56 +110,56 @@ void CServerList:: AutoUpdate()
     }
 }
 
-bool CServerList:: Init()
+bool CServerList::Init()
 {
     // auto update the list by using an url
-    if (app_prefs -> AutoServerlist())
+    if (app_prefs->AutoServerlist())
     AutoUpdate();
     // Load Metfile
     CString strPath;
 #if defined(__DEBUG__)
     printf("*** reading servers\n");
 #endif
-    strPath.Format("%sserver.met", app_prefs -> GetAppDir());
+    strPath.Format("%sserver.met", app_prefs->GetAppDir());
     bool bRes = AddServermetToList(strPath, false);
-    if (theApp.glob_prefs -> AutoServerlist())
+    if (theApp.glob_prefs->AutoServerlist())
     {
-        strPath.Format("%sserver.met", app_prefs -> GetAppDir());
+        strPath.Format("%sserver.met", app_prefs->GetAppDir());
         bool bRes2 = AddServermetToList(strPath);
         if (!bRes &&bRes2)
         bRes = true;
     }
     // insert static servers from textfile
-    strPath.Format("%sstaticservers.dat", app_prefs -> GetAppDir());
+    strPath.Format("%sstaticservers.dat", app_prefs->GetAppDir());
     AddServersFromTextFile(strPath);
     return bRes;
 }
 
-bool CServerList:: AddServermetToList(CString strFile, bool merge)
+bool CServerList::AddServermetToList(CString strFile, bool merge)
 {
     if (!merge)
     {
-        theApp.xmuledlg -> serverwnd -> serverlistctrl -> DeleteAllItems();
-        this -> RemoveAllServers();
+        theApp.xmuledlg->serverwnd->serverlistctrl->DeleteAllItems();
+        this->RemoveAllServers();
     }
     CSafeFile servermet;
     //  /*try*/{
     if (!wxFileExists(strFile))
     {
-        theApp.xmuledlg -> AddLogLine(false, _("Failed to load server.met!"));
+        theApp.xmuledlg->AddLogLine(false, _("Failed to load server.met!"));
         return false;
     }
-    if (!servermet.Open(strFile, CFile:: read))
+    if (!servermet.Open(strFile.c_str(), CFile::read))
     {
         //CFile::modeRead|CFile::osSequentialScan)){
-        theApp.xmuledlg -> AddLogLine(false, _("Failed to load server.met!"));
+        theApp.xmuledlg->AddLogLine(false, _("Failed to load server.met!"));
         return false;
     }
     if ((1 != servermet.Read( &version, 1)) ||
     (version != 0xE0 &&version != MET_HEADER))
     {
         servermet.Close();
-        theApp.xmuledlg -> AddLogLine(false, GetResString(IDS_ERR_BADSERVERMETVERSION), version);
+        theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_BADSERVERMETVERSION), version);
         return false;
     }
     try
@@ -171,7 +169,7 @@ bool CServerList:: AddServermetToList(CString strFile, bool merge)
         throw CInvalidPacket();
         ServerMet_Struct sbuffer;
         uint32 iAddCount = 0;
-        theApp.xmuledlg -> serverwnd -> serverlistctrl -> Freeze();
+        theApp.xmuledlg->serverwnd->serverlistctrl->Freeze();
         for (uint32 j = 0 ; j < fservercount ; j++)
         {
             // get server
@@ -180,24 +178,24 @@ bool CServerList:: AddServermetToList(CString strFile, bool merge)
             CServer *newserver = new CServer( &sbuffer);
             //add tags
             for (uint32 i = 0 ; i < sbuffer.tagcount ; i++)
-            newserver -> AddTagFromFile( &servermet);
+            newserver->AddTagFromFile( &servermet);
             // set listname for server
-            if (!newserver -> GetListName())
+            if (!newserver->GetListName())
             {
-                char *listname = new char[strlen(newserver -> GetAddress()) + 8];
-                sprintf(listname, "Server %s", newserver -> GetAddress());
-                newserver -> SetListName(listname);
+                char *listname = new char[strlen(newserver->GetAddress()) + 8];
+                sprintf(listname, "Server %s", newserver->GetAddress());
+                newserver->SetListName(listname);
                 delete listname;
             }
-            if (!theApp.xmuledlg -> serverwnd -> serverlistctrl -> AddServer(newserver, true))
+            if (!theApp.xmuledlg->serverwnd->serverlistctrl->AddServer(newserver, true))
             {
-                CServer *update = theApp.serverlist -> GetServerByAddress(newserver -> GetAddress(), newserver -> GetPort());
+                CServer *update = theApp.serverlist->GetServerByAddress(newserver->GetAddress(), newserver->GetPort());
                 if (update)
                 {
-                    update -> SetListName(newserver -> GetListName());
-                    if (newserver -> GetDescription())
-                    update -> SetDescription(newserver -> GetDescription());
-                    theApp.xmuledlg -> serverwnd -> serverlistctrl -> RefreshServer(update);
+                    update->SetListName(newserver->GetListName());
+                    if (newserver->GetDescription())
+                    update->SetDescription(newserver->GetDescription());
+                    theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(update);
                 }
                 delete newserver;
             }
@@ -209,15 +207,15 @@ bool CServerList:: AddServermetToList(CString strFile, bool merge)
                 theApp.Yield();
             }
         }
-        theApp.xmuledlg -> serverwnd -> serverlistctrl -> Thaw();
+        theApp.xmuledlg->serverwnd->serverlistctrl->Thaw();
         if (!merge)
-        theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_SERVERSFOUND), fservercount);
+        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_SERVERSFOUND), fservercount);
         else
-        theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_SERVERSADDED), iAddCount, fservercount - iAddCount);
+        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_SERVERSADDED), iAddCount, fservercount - iAddCount);
     }
     catch(CInvalidPacket)
     {
-        theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_ERR_BADSERVERLIST));
+        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_BADSERVERLIST));
         servermet.Close();
         return false;
     }
@@ -225,31 +223,31 @@ bool CServerList:: AddServermetToList(CString strFile, bool merge)
 #if 0
     catch(CFileException *error)
     {
-        if (error -> m_cause == CFileException:: endOfFile)
-        theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_ERR_BADSERVERLIST));
+        if (error->m_cause == CFileException::endOfFile)
+        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_BADSERVERLIST));
         else
         {
             char buffer[150];
-            error -> GetErrorMessage(buffer, 150);
-            theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_ERR_FILEERROR_SERVERMET), buffer);
+            error->GetErrorMessage(buffer, 150);
+            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FILEERROR_SERVERMET), buffer);
         }
         //memleak fix:
-        error -> Delete();
+        error->Delete();
     }
 #endif
     return true;
 }
 
-bool CServerList:: AddServer(CServer *in_server)
+bool CServerList::AddServer(CServer *in_server)
 {
-    if (theApp.glob_prefs -> FilterBadIPs())
+    if (theApp.glob_prefs->FilterBadIPs())
     if (!IsGoodServerIP(in_server))
     return false;
-    CServer *test_server = GetServerByAddress(in_server -> GetAddress(), in_server -> GetPort());
+    CServer *test_server = GetServerByAddress(in_server->GetAddress(), in_server->GetPort());
     if (test_server)
     {
-        test_server -> ResetFailedCount();
-        theApp.xmuledlg -> serverwnd -> serverlistctrl -> RefreshServer(test_server);
+        test_server->ResetFailedCount();
+        theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(test_server);
         return false;
     }
     //AddTail(in_server);:
@@ -257,37 +255,37 @@ bool CServerList:: AddServer(CServer *in_server)
     return true;
 }
 
-void CServerList:: ServerStats()
+void CServerList::ServerStats()
 {
-    if (theApp.serverconnect -> IsConnected() &&list.GetCount() > 0)
+    if (theApp.serverconnect->IsConnected() &&list.GetCount() > 0)
     {
         CServer *ping_server = GetNextStatServer();
         CServer *test = ping_server;
         if (!ping_server)
         return;
-        while (ping_server -> GetLastPinged() != 0 && (:: GetTickCount() - ping_server -> GetLastPinged()) < UDPSERVSTATREASKTIME)
+        while (ping_server->GetLastPinged() != 0 && (::GetTickCount() - ping_server->GetLastPinged()) < UDPSERVSTATREASKTIME)
         {
-            ping_server = this -> GetNextStatServer();
+            ping_server = this->GetNextStatServer();
             if (ping_server == test)
             return;
         }
-        if (ping_server -> GetFailedCount() >= theApp.glob_prefs -> GetDeadserverRetries() &&theApp.glob_prefs -> DeadServer())
+        if (ping_server->GetFailedCount() >= theApp.glob_prefs->GetDeadserverRetries() &&theApp.glob_prefs->DeadServer())
         {
-            theApp.xmuledlg -> serverwnd -> serverlistctrl -> RemoveServer(ping_server);
+            theApp.xmuledlg->serverwnd->serverlistctrl->RemoveServer(ping_server);
             return;
         }
         Packet *packet = new Packet(OP_GLOBSERVSTATREQ, 4);
         srand((unsigned) time(NULL));
         uint32 time = 0x55AA0000 + (uint16) rand();
-        ping_server -> SetChallenge(time);
-        memcpy(packet -> pBuffer, &time, 4);
-        ping_server -> SetLastPinged(:: GetTickCount());
-        ping_server -> AddFailedCount();
-        theApp.xmuledlg -> serverwnd -> serverlistctrl -> RefreshServer(ping_server);
+        ping_server->SetChallenge(time);
+        memcpy(packet->pBuffer, &time, 4);
+        ping_server->SetLastPinged(::GetTickCount());
+        ping_server->AddFailedCount();
+        theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(ping_server);
 #if defined(__DEBUG__)
-//	printf("CServerList:: ServerStats --> OP_GLOBSERVSTATREQ size=%d\n",packet->size);
+//  printf("CServerList::ServerStats --> OP_GLOBSERVSTATREQ size=%d\n",packet->size);
 #endif
-        theApp.serverconnect -> SendUDPPacket(packet, ping_server, true);
+        theApp.serverconnect->SendUDPPacket(packet, ping_server, true);
     }
 }
 
@@ -300,14 +298,14 @@ void CServerList:: ServerStats()
  2.1.*  - Kry
     */
 
-bool CServerList:: IsGoodServerIP(CServer *in_server)
+bool CServerList::IsGoodServerIP(CServer *in_server)
 {
-    if (in_server -> HasDynIP())
+    if (in_server->HasDynIP())
     return true;
     char *pch;
 #if !defined(__DEBUG__)
     char ipx[24];
-    sprintf(ipx, "%s", in_server -> GetFullIP());
+    sprintf(ipx, "%s", in_server->GetFullIP());
     // Determine first and second number if the given IP
     pch = strtok(ipx, ".");
     wxString first = pch;
@@ -318,12 +316,12 @@ bool CServerList:: IsGoodServerIP(CServer *in_server)
     if (first == "192" &&secondI == 168) return false;
     if (first == "2" &&secondI == 1) return false;
     if (first == "0" || first == "10" || first == "127"
-    || in_server -> GetPort() == 0) return false;
+    || in_server->GetPort() == 0) return false;
 #endif
     return true;
 }
 
-void CServerList:: RemoveServer(CServer *out_server)
+void CServerList::RemoveServer(CServer *out_server)
 {
     for (POSITION pos = list.GetHeadPosition() ; pos != NULL ;)
     {
@@ -331,8 +329,8 @@ void CServerList:: RemoveServer(CServer *out_server)
         CServer *test_server = list.GetNext(pos);
         if (test_server == out_server)
         {
-            if (theApp.downloadqueue -> cur_udpserver == out_server)
-            theApp.downloadqueue -> cur_udpserver = 0;
+            if (theApp.downloadqueue->cur_udpserver == out_server)
+            theApp.downloadqueue->cur_udpserver = 0;
             list.RemoveAt(pos2);
             delservercount++;
             delete test_server;
@@ -341,7 +339,7 @@ void CServerList:: RemoveServer(CServer *out_server)
     }
 }
 
-void CServerList:: RemoveAllServers()
+void CServerList::RemoveAllServers()
 {
     for (POSITION pos = list.GetHeadPosition() ; pos != NULL ; pos = list.GetHeadPosition())
     {
@@ -351,7 +349,7 @@ void CServerList:: RemoveAllServers()
     }
 }
 
-void CServerList:: GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32 &file, uint32 &tuser, uint32 &tfile, float &occ)
+void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32 &file, uint32 &tuser, uint32 &tfile, float &occ)
 {
     total = list.GetCount();
     failed = 0;
@@ -366,28 +364,28 @@ void CServerList:: GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
         curr = (CServer *) list.GetAt(pos);
-        if (curr -> GetFailedCount())
+        if (curr->GetFailedCount())
         {
             failed++;
         }
         else
         {
-            user += curr -> GetUsers();
-            file += curr -> GetFiles();
+            user += curr->GetUsers();
+            file += curr->GetFiles();
         }
-        tuser += curr -> GetUsers();
-        tfile += curr -> GetFiles();
-        if (curr -> GetMaxUsers())
+        tuser += curr->GetUsers();
+        tfile += curr->GetFiles();
+        if (curr->GetMaxUsers())
         {
             // total users on servers with known maximum:
-            tuserk += curr -> GetUsers();
-            maxusers += curr -> GetMaxUsers();
+            tuserk += curr->GetUsers();
+            maxusers += curr->GetMaxUsers();
         }
     }
     if (maxusers > 0) occ = (float)(tuserk *100) /maxusers;
 }
 
-void CServerList:: GetUserFileStatus(uint32 &user, uint32 &file)
+void CServerList::GetUserFileStatus(uint32 &user, uint32 &file)
 {
     user = 0;
     file = 0;
@@ -395,15 +393,15 @@ void CServerList:: GetUserFileStatus(uint32 &user, uint32 &file)
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
         curr = (CServer *) list.GetAt(pos);
-        if (!curr -> GetFailedCount())
+        if (!curr->GetFailedCount())
         {
-            user += curr -> GetUsers();
-            file += curr -> GetFiles();
+            user += curr->GetUsers();
+            file += curr->GetFiles();
         }
     }
 }
 
-CServerList:: ~CServerList()
+CServerList::~CServerList()
 {
     SaveServermetToFile();
     for (POSITION pos = list.GetHeadPosition() ; pos != NULL ; pos = list.GetHeadPosition())
@@ -426,13 +424,13 @@ CServerList:: ~CServerList()
 #  endif
 #endif
 
-void CServerList:: AddServersFromTextFile(CString strFilename, bool isstaticserver)
+void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserver)
 {
     wxString strLine;
     //CStdioFile f;
     //wxFFile f;
     //if (!f.Open(strFilename, CFile::modeRead | CFile::typeText))
-    if (!wxFileName:: FileExists(strFilename))
+    if (!wxFileName::FileExists(strFilename))
     {
         // no file. do nothing.
         return;
@@ -493,22 +491,26 @@ void CServerList:: AddServersFromTextFile(CString strFilename, bool isstaticserv
         strName.Replace("\r", "");
         strName.Replace("\n", "");
         // create server object and add it to the list
+        if (theApp.daemon == true)
+        {
+            theApp.lda->Print (strName + wxString(" - ") + strPort, LD_SERVER);
+        }
         CServer *nsrv = new CServer(atoi(strPort), (char *) strHost.GetData());
-        nsrv -> SetListName((char *) strName.GetData());
-        nsrv -> SetIsStaticMember(true);
+        nsrv->SetListName((char *) strName.GetData());
+        nsrv->SetIsStaticMember(true);
         // Barry - Was always high
-        nsrv -> SetPreference(priority);
-        if (!theApp.xmuledlg -> serverwnd -> serverlistctrl -> AddServer(nsrv, true))
+        nsrv->SetPreference(priority);
+        if (!theApp.xmuledlg->serverwnd->serverlistctrl->AddServer(nsrv, true))
         {
             delete nsrv;
             CServer *srvexisting = GetServerByAddress((char *) strHost.GetData(), atoi(strPort));
             if (srvexisting)
             {
-                srvexisting -> SetListName((char *) strName.GetData());
-                srvexisting -> SetIsStaticMember(true);
+                srvexisting->SetListName((char *) strName.GetData());
+                srvexisting->SetIsStaticMember(true);
                 // Barry - Was always high
-                srvexisting -> SetPreference(priority);
-                if (theApp.xmuledlg -> serverwnd) theApp.xmuledlg -> serverwnd -> serverlistctrl -> RefreshServer(srvexisting);
+                srvexisting->SetPreference(priority);
+                if (theApp.xmuledlg->serverwnd) theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(srvexisting);
             }
         }
     }
@@ -516,7 +518,7 @@ void CServerList:: AddServersFromTextFile(CString strFilename, bool isstaticserv
     //printf("todo. addserversfromtextfile needs work\n");
 }
 
-void CServerList:: MoveServerDown(CServer *aServer)
+void CServerList::MoveServerDown(CServer *aServer)
 {
     POSITION pos1, pos2;
     uint16 i = 0;
@@ -536,7 +538,7 @@ void CServerList:: MoveServerDown(CServer *aServer)
     }
 }
 
-void CServerList:: Sort()
+void CServerList::Sort()
 {
     POSITION pos1, pos2;
     uint16 i = 0;
@@ -544,12 +546,12 @@ void CServerList:: Sort()
     {
         list.GetNext(pos1);
         CServer *cur_server = list.GetAt(pos2);
-        if (cur_server -> GetPreferences() == PR_HIGH)
+        if (cur_server->GetPreferences() == PR_HIGH)
         {
             list.AddHead(cur_server);
             list.RemoveAt(pos2);
         }
-        else if(cur_server -> GetPreferences() == PR_LOW)
+        else if(cur_server->GetPreferences() == PR_LOW)
         {
             list.AddTail(cur_server);
             list.RemoveAt(pos2);
@@ -560,7 +562,7 @@ void CServerList:: Sort()
     }
 }
 
-CServer *CServerList:: GetNextServer()
+CServer *CServerList::GetNextServer()
 {
     CServer *nextserver = 0;
     uint32 i = 0;
@@ -580,13 +582,13 @@ CServer *CServerList:: GetNextServer()
         i++;
         // TODO: Add more option to filter bad server like min ping, min users etc
         //if (nextserver->preferences = ?)
-        //	nextserver = 0;
-        //if (serverpos == list.GetCount()) return 0;//			serverpos = 0;
+        //  nextserver = 0;
+        //if (serverpos == list.GetCount()) return 0;//         serverpos = 0;
     }
     return nextserver;
 }
 
-CServer *CServerList:: GetNextSearchServer()
+CServer *CServerList::GetNextSearchServer()
 {
     CServer *nextserver = 0;
     uint32 i = 0;
@@ -608,7 +610,7 @@ CServer *CServerList:: GetNextSearchServer()
     return nextserver;
 }
 
-CServer *CServerList:: GetNextStatServer()
+CServer *CServerList::GetNextStatServer()
 {
     CServer *nextserver = 0;
     uint32 i = 0;
@@ -630,7 +632,7 @@ CServer *CServerList:: GetNextStatServer()
     return nextserver;
 }
 
-bool CServerList:: BroadCastPacket(Packet *packet)
+bool CServerList::BroadCastPacket(Packet *packet)
 {
     // unused atm . but might be useful later
     if (udp_timer.IsRunning())
@@ -642,9 +644,9 @@ bool CServerList:: BroadCastPacket(Packet *packet)
     return true;
 }
 
-void CServerList:: SendNextPacket()
+void CServerList::SendNextPacket()
 {
-    if (theApp.listensocket -> TooManySockets())
+    if (theApp.listensocket->TooManySockets())
     {
         //KillTimer(0,udp_timer);
         udp_timer.Stop();
@@ -654,11 +656,11 @@ void CServerList:: SendNextPacket()
     if (broadcastpos != 0)
     {
         CServer *cur_server = list.GetAt(broadcastpos);
-        if (cur_server != theApp.serverconnect -> GetCurrentServer())
+        if (cur_server != theApp.serverconnect->GetCurrentServer())
 #if defined(__DEBUG__)
-	printf("CServerList:: ServerStats --> %02 size=%d\n",broadcastpacket->opcode,broadcastpacket->size);
+    printf("CServerList::ServerStats --> %02 size=%d\n",broadcastpacket->opcode,broadcastpacket->size);
 #endif
-        theApp.serverconnect -> SendUDPPacket(broadcastpacket, cur_server, false);
+        theApp.serverconnect->SendUDPPacket(broadcastpacket, cur_server, false);
         list.GetNext(broadcastpos);
     }
     else
@@ -669,7 +671,7 @@ void CServerList:: SendNextPacket()
     }
 }
 
-void CServerList:: CancelUDPBroadcast()
+void CServerList::CancelUDPBroadcast()
 {
     if (udp_timer.IsRunning())
     {
@@ -681,14 +683,14 @@ void CServerList:: CancelUDPBroadcast()
 }
 
 #if 0
-void CALLBACK CServerList:: UDPTimerProc(HWND hwnd, UINT uMsg, UINT_PTR idEvent, DWORD dwTime)
+void CALLBACK CServerList::UDPTimerProc(HWND hwnd, UINT uMsg, UINT_PTR idEvent, DWORD dwTime)
 {
-    theApp.serverlist -> SendNextPacket();
+    theApp.serverlist->SendNextPacket();
 }
 
 #endif
 
-CServer *CServerList:: GetNextServer(CServer *lastserver)
+CServer *CServerList::GetNextServer(CServer *lastserver)
 {
     if (list.IsEmpty())
     return 0;
@@ -705,52 +707,52 @@ CServer *CServerList:: GetNextServer(CServer *lastserver)
     return list.GetAt(pos);
 }
 
-CServer *CServerList:: GetServerByIP(wxUint32 nIP)
+CServer *CServerList::GetServerByIP(wxUint32 nIP)
 {
     POSITION pos = list.GetHeadPosition();
     while (pos)
     {
         CServer *s = list.GetNext(pos);
-        if (s -> GetIP() == nIP) return s;
+        if (s->GetIP() == nIP) return s;
     }
     return NULL;
 }
 
-CServer *CServerList:: GetServerByIP(wxUint32 nIP, wxUint16 nPort)
+CServer *CServerList::GetServerByIP(wxUint32 nIP, wxUint16 nPort)
 {
     POSITION pos = list.GetHeadPosition();
     while (pos)
     {
         CServer *s = list.GetNext(pos);
-        if (s -> GetIP() == nIP &&s -> GetPort() == nPort) return s;
+        if (s->GetIP() == nIP &&s->GetPort() == nPort) return s;
     }
     return NULL;
 }
 
-CServer *CServerList:: GetServerByAddress(char *address, uint16 port)
+CServer *CServerList::GetServerByAddress(char *address, uint16 port)
 {
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
         // i_a: small speed optimization:
         CServer *s = list.GetAt(pos);
-        if (port == s -> GetPort() && !strcmp(s -> GetAddress(), address))
+        if (port == s->GetPort() && !strcmp(s->GetAddress(), address))
         return s;
     }
     return NULL;
 }
 
-bool CServerList:: SaveServermetToFile()
+bool CServerList::SaveServermetToFile()
 {
     // oops.. don't save ALL the time :):
-    m_nLastSaved =:: GetTickCount();
-    char *newservermet = new char[strlen(app_prefs -> GetAppDir()) + MAX_PATH];
-    sprintf(newservermet, "%sserver.met.new", app_prefs -> GetAppDir());
-    //	theApp.xmuledlg->AddLogLine( false, "%s", newservermet );
+    m_nLastSaved =::GetTickCount();
+    char *newservermet = new char[strlen(app_prefs->GetAppDir()) + MAX_PATH];
+    sprintf(newservermet, "%sserver.met.new", app_prefs->GetAppDir());
+    //  theApp.xmuledlg->AddLogLine( false, "%s", newservermet );
     {
         FILE *servermet = fopen(newservermet, "wb");
         if (!servermet)
         {
-            theApp.xmuledlg -> AddLogLine(false, GetResString(IDS_ERR_SAVESERVERMET));
+            theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_SAVESERVERMET));
             //mf:
             delete[] newservermet;
             return false;
@@ -763,61 +765,61 @@ bool CServerList:: SaveServermetToFile()
         CServer *nextserver;
         for (uint32 j = 0 ; j != fservercount ; j++)
         {
-            nextserver = this -> GetServerAt(j);
-            sbuffer.ip = nextserver -> GetIP();
-            sbuffer.port = nextserver -> GetPort();
+            nextserver = this->GetServerAt(j);
+            sbuffer.ip = nextserver->GetIP();
+            sbuffer.port = nextserver->GetPort();
             uint16 tagcount = 11;
-            if (nextserver -> GetListName())
+            if (nextserver->GetListName())
             tagcount++;
-            if (nextserver -> GetDynIP())
+            if (nextserver->GetDynIP())
             tagcount++;
-            if (nextserver -> GetDescription())
+            if (nextserver->GetDescription())
             tagcount++;
             sbuffer.tagcount = tagcount;
             fwrite( &sbuffer, 1, sizeof(sbuffer), servermet);
-            if (nextserver -> GetListName())
+            if (nextserver->GetListName())
             {
-                CTag servername(ST_SERVERNAME, nextserver -> GetListName());
+                CTag servername(ST_SERVERNAME, nextserver->GetListName());
                 servername.WriteTagToFile(servermet);
             }
-            if (nextserver -> GetDynIP())
+            if (nextserver->GetDynIP())
             {
-                CTag serverdynip(ST_DYNIP, nextserver -> GetDynIP());
+                CTag serverdynip(ST_DYNIP, nextserver->GetDynIP());
                 serverdynip.WriteTagToFile(servermet);
             }
-            if (nextserver -> GetDescription())
+            if (nextserver->GetDescription())
             {
-                CTag serverdesc(ST_DESCRIPTION, nextserver -> GetDescription());
+                CTag serverdesc(ST_DESCRIPTION, nextserver->GetDescription());
                 serverdesc.WriteTagToFile(servermet);
             }
-            CTag serverfail(ST_FAIL, nextserver -> GetFailedCount());
+            CTag serverfail(ST_FAIL, nextserver->GetFailedCount());
             serverfail.WriteTagToFile(servermet);
-            CTag serverpref(ST_PREFERENCE, nextserver -> GetPreferences());
+            CTag serverpref(ST_PREFERENCE, nextserver->GetPreferences());
             serverpref.WriteTagToFile(servermet);
-            CTag serveruser("users", nextserver -> GetUsers());
+            CTag serveruser("users", nextserver->GetUsers());
             serveruser.WriteTagToFile(servermet);
-            CTag serverfiles("files", nextserver -> GetFiles());
+            CTag serverfiles("files", nextserver->GetFiles());
             serverfiles.WriteTagToFile(servermet);
-            CTag serverping(ST_PING, nextserver -> GetPing());
+            CTag serverping(ST_PING, nextserver->GetPing());
             serverping.WriteTagToFile(servermet);
-            CTag serverlastp(ST_LASTPING, nextserver -> GetLastPinged());
+            CTag serverlastp(ST_LASTPING, nextserver->GetLastPinged());
             serverlastp.WriteTagToFile(servermet);
-            CTag servermaxusers(ST_MAXUSERS, nextserver -> GetMaxUsers());
+            CTag servermaxusers(ST_MAXUSERS, nextserver->GetMaxUsers());
             servermaxusers.WriteTagToFile(servermet);
-            CTag softfiles(ST_SOFTFILES, nextserver -> GetSoftFiles());
+            CTag softfiles(ST_SOFTFILES, nextserver->GetSoftFiles());
             softfiles.WriteTagToFile(servermet);
-            CTag hardfiles(ST_HARDFILES, nextserver -> GetHardFiles());
+            CTag hardfiles(ST_HARDFILES, nextserver->GetHardFiles());
             hardfiles.WriteTagToFile(servermet);
-            CTag version(ST_VERSION, (char *) nextserver -> GetVersion() .c_str());
+            CTag version(ST_VERSION, (char *) nextserver->GetVersion() .c_str());
             version.WriteTagToFile(servermet);
-            CTag tagUDPFlags(ST_UDPFLAGS, nextserver -> GetUDPFlags());
+            CTag tagUDPFlags(ST_UDPFLAGS, nextserver->GetUDPFlags());
             tagUDPFlags.WriteTagToFile(servermet);
         }
         fclose(servermet);
-        char *curservermet = new char[strlen(app_prefs -> GetAppDir()) + 20];
-        char *oldservermet = new char[strlen(app_prefs -> GetAppDir()) + 20];
-        sprintf(curservermet, "%sserver.met", app_prefs -> GetAppDir());
-        sprintf(oldservermet, "%sserver_met.old", app_prefs -> GetAppDir());
+        char *curservermet = new char[strlen(app_prefs->GetAppDir()) + 20];
+        char *oldservermet = new char[strlen(app_prefs->GetAppDir()) + 20];
+        sprintf(curservermet, "%sserver.met", app_prefs->GetAppDir());
+        sprintf(oldservermet, "%sserver_met.old", app_prefs->GetAppDir());
         wxRemoveFile(oldservermet);
         wxRenameFile(curservermet, oldservermet);
         wxRenameFile(newservermet, curservermet);
@@ -828,10 +830,10 @@ bool CServerList:: SaveServermetToFile()
     catch(CFileException *error)
     {
         OUTPUT_DEBUG_TRACE();
-        theApp.xmuledlg -> AddLogLine(false, GetResString(IDS_ERR_SAVESERVERMET2));
+        theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_SAVESERVERMET2));
         //mf:
         delete[] newservermet;
-        error -> Delete();
+        error->Delete();
         return false;
     }
 #endif
@@ -839,9 +841,10 @@ bool CServerList:: SaveServermetToFile()
     return true;
 }
 
-void CServerList:: Process()
+void CServerList::Process()
 {
-    if (:: GetTickCount() - m_nLastSaved > 180000)
-    this -> SaveServermetToFile();
+    if (::GetTickCount() - m_nLastSaved > 180000)
+    this->SaveServermetToFile();
 }
 
+
