@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -51,12 +51,9 @@ typedef struct SPC_NMHDR
 	int delta;
 } SPC_NMHDR;
 
-#include "wx/window.h"
-#include "wx/stattext.h"
-
-/* mit vittua!!! */
-
-
+#include "wintypes.h"                   // Needed for BOOL
+#include <wx/window.h>                  // Needed for wxWindow
+#include <wx/stattext.h>                // Needed for wxStaticText
 
 class CSplitterControl : public wxStaticText
 {
