@@ -1,37 +1,59 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright(C)2002 Tiku & Patrizio Bassi aka Hetfield <hetfield@email.it>
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#	include "SysTray.h"
 #	include "Preferences.h"
 #	include "SharedFileList.h"
-#	include "SysTray.h"
 #	include "UploadQueue.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
 #endif
 
+#include <net/if.h>                     // Needed for ifreq
+#include <netinet/in.h>                 // Needed for sockaddr_in
 #include <libintl.h>
 #include "pixmaps/mule_Tr_grey.ico.xpm"
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
+#include <gdk/gdkx.h>
+#include <glib.h>
+#include <X11/Xatom.h>
+
+#include <locale.h>
+#include <config.h>
+#include <sys/ioctl.h>
+
+#include <arpa/inet.h>
+#include <netdb.h>
+
+#include <unistd.h>
+#include "eggtrayicon.h"
+
+#ifdef __WXMAC__
+#	include <sys/types.h>
+#	include <sys/socket.h>
+#endif
 
 #ifndef __SYSTRAY_DISABLED__
 
@@ -57,10 +79,10 @@ gchar *getIP()
     memset( &ifr, 0, sizeof ifr);
     sfd = socket(AF_INET, SOCK_STREAM, 0);
     strcpy(ifr.ifr_name, "ppp0");
-    sin -> sin_family = AF_INET;
+    sin->sin_family = AF_INET;
     if (0 == ioctl(sfd, SIOCGIFADDR, &ifr))
     {
-        ip = inet_ntoa(sin -> sin_addr);
+        ip = inet_ntoa(sin->sin_addr);
         return ip;
     }
     else
@@ -68,12 +90,12 @@ gchar *getIP()
         printf("Not connected at network with ppp0 direct connection\n");
         do
         {
-            interface = "eth" + wxString:: Format("%d", index);
+            interface = "eth" + wxString::Format("%d", index);
             strcpy(ifr.ifr_name, interface);
-            sin -> sin_family = AF_INET;
+            sin->sin_family = AF_INET;
             if (ioctl(sfd, SIOCGIFADDR, &ifr) == 0)
             {
-                ip = inet_ntoa(sin -> sin_addr);
+                ip = inet_ntoa(sin->sin_addr);
                 index++;
             }
             else
@@ -91,16 +113,16 @@ gchar *getIP()
 // Same check of the connection tab.
 void speed_check()
 {
-    if (theApp.glob_prefs -> GetMaxGraphDownloadRate() < theApp.glob_prefs -> GetMaxDownload())
-    theApp.glob_prefs -> SetDownloadlimit(UNLIMITED);
-    if (theApp.glob_prefs -> GetMaxGraphUploadRate() < theApp.glob_prefs -> GetMaxUpload())
-    theApp.glob_prefs -> SetUploadlimit(UNLIMITED);
-    if (theApp.glob_prefs -> GetMaxUpload() != UNLIMITED)
+    if (theApp.glob_prefs->GetMaxGraphDownloadRate() < theApp.glob_prefs->GetMaxDownload())
+    theApp.glob_prefs->SetDownloadlimit(UNLIMITED);
+    if (theApp.glob_prefs->GetMaxGraphUploadRate() < theApp.glob_prefs->GetMaxUpload())
+    theApp.glob_prefs->SetUploadlimit(UNLIMITED);
+    if (theApp.glob_prefs->GetMaxUpload() != UNLIMITED)
     {
-        if (theApp.glob_prefs -> GetMaxUpload() < 4 && (theApp.glob_prefs -> GetMaxUpload() *3 < theApp.glob_prefs -> GetMaxDownload()))
-        theApp.glob_prefs -> SetDownloadlimit((theApp.glob_prefs -> GetMaxUpload() *3));
-        if (theApp.glob_prefs -> GetMaxUpload() < 10 && (theApp.glob_prefs -> GetMaxUpload() *4 < theApp.glob_prefs -> GetMaxDownload()))
-        theApp.glob_prefs -> SetDownloadlimit((theApp.glob_prefs -> GetMaxUpload() *4));
+        if (theApp.glob_prefs->GetMaxUpload() < 4 && (theApp.glob_prefs->GetMaxUpload() *3 < theApp.glob_prefs->GetMaxDownload()))
+        theApp.glob_prefs->SetDownloadlimit((theApp.glob_prefs->GetMaxUpload() *3));
+        if (theApp.glob_prefs->GetMaxUpload() < 10 && (theApp.glob_prefs->GetMaxUpload() *4 < theApp.glob_prefs->GetMaxDownload()))
+        theApp.glob_prefs->SetDownloadlimit((theApp.glob_prefs->GetMaxUpload() *4));
     }
 }
 
@@ -108,74 +130,74 @@ void speed_check()
 void close_xmule()
 {
     wxCloseEvent SendCloseEvent;
-    theApp.xmuledlg -> OnClose(SendCloseEvent);
+    theApp.xmuledlg->OnClose(SendCloseEvent);
 }
 
 // Hides xMule
 void hide_xmule()
 {
-    if (theApp.xmuledlg -> IsShown())
+    if (theApp.xmuledlg->IsShown())
     {
-        theApp.xmuledlg -> Show(FALSE);
+        theApp.xmuledlg->Show(FALSE);
     }
 }
 
 // Shows xMule
 void show_xmule()
 {
-    if (!theApp.xmuledlg -> IsShown())
+    if (!theApp.xmuledlg->IsShown())
     {
-        theApp.xmuledlg -> Show(TRUE);
+        theApp.xmuledlg->Show(TRUE);
     }
 }
 
 // Shows or hides xMule...double click automatic selection
 void showgui()
 {
-    if (theApp.xmuledlg -> IsShown())
+    if (theApp.xmuledlg->IsShown())
     {
-        theApp.xmuledlg -> Iconize(TRUE);
-        theApp.xmuledlg -> Show(FALSE);
+        theApp.xmuledlg->Iconize(TRUE);
+        theApp.xmuledlg->Show(FALSE);
     }
     else
     {
-        theApp.xmuledlg -> Show(TRUE);
+        theApp.xmuledlg->Show(TRUE);
     }
 }
 
 // Set download and upload speed to max
 void set_all_max()
 {
-    theApp.glob_prefs -> SetUploadlimit(theApp.glob_prefs -> GetMaxGraphUploadRate());
-    theApp.glob_prefs -> SetDownloadlimit(theApp.glob_prefs -> GetMaxGraphDownloadRate());
+    theApp.glob_prefs->SetUploadlimit(theApp.glob_prefs->GetMaxGraphUploadRate());
+    theApp.glob_prefs->SetDownloadlimit(theApp.glob_prefs->GetMaxGraphDownloadRate());
 }
 
 // Set download and upload speed to min
 void set_all_min()
 {
-    theApp.glob_prefs -> SetUploadlimit(2);
-    theApp.glob_prefs -> SetDownloadlimit(2);
+    theApp.glob_prefs->SetUploadlimit(2);
+    theApp.glob_prefs->SetDownloadlimit(2);
     speed_check();
 }
 
 // Connect to a server
 void connect_any_server()
 {
-    if (theApp.serverconnect -> IsConnected())
+    if (theApp.serverconnect->IsConnected())
     {
-        theApp.serverconnect -> Disconnect();
+        theApp.serverconnect->Disconnect();
     }
-    theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_CONNECTING));
-    theApp.serverconnect -> ConnectToAnyServer();
-    theApp.xmuledlg -> ShowConnectionState(false);
+    theApp.xmuledlg->AddLogLine(true, GetResString(IDS_CONNECTING));
+    theApp.serverconnect->ConnectToAnyServer();
+    theApp.xmuledlg->ShowConnectionState(false);
 }
 
 // Disconnect
 void disconnect()
 {
-    if (theApp.serverconnect -> IsConnected())
+    if (theApp.serverconnect->IsConnected())
     {
-        theApp.serverconnect -> Disconnect();
+        theApp.serverconnect->Disconnect();
     }
     else
     {
@@ -190,11 +212,11 @@ void set_dl_speed(GtkWidget *widget, GdkEventButton *event, gpointer data)
     temp = atoi(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
     if (temp == 0)
     {
-        theApp.glob_prefs -> SetDownloadlimit(UNLIMITED);
+        theApp.glob_prefs->SetDownloadlimit(UNLIMITED);
     }
     else
     {
-        theApp.glob_prefs -> SetDownloadlimit(temp);
+        theApp.glob_prefs->SetDownloadlimit(temp);
     }
     speed_check();
 }
@@ -206,11 +228,11 @@ void set_up_speed(GtkWidget *widget, GdkEventButton *event, gpointer data)
     temp = atoi(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
     if (temp == 0)
     {
-        theApp.glob_prefs -> SetUploadlimit(UNLIMITED);
+        theApp.glob_prefs->SetUploadlimit(UNLIMITED);
     }
     else
     {
-        theApp.glob_prefs -> SetUploadlimit(temp);
+        theApp.glob_prefs->SetUploadlimit(temp);
     }
     speed_check();
 }
@@ -227,10 +249,10 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     uint16 max_dl_speed, max_up_speed;
     uint16 actual_dl_speed, actual_up_speed;
     speed_check();
-    actual_up_speed = theApp.glob_prefs -> GetMaxUpload();
-    actual_dl_speed = theApp.glob_prefs -> GetMaxDownload();
-    max_up_speed = theApp.glob_prefs -> GetMaxGraphUploadRate();
-    max_dl_speed = theApp.glob_prefs -> GetMaxGraphDownloadRate();
+    actual_up_speed = theApp.glob_prefs->GetMaxUpload();
+    actual_dl_speed = theApp.glob_prefs->GetMaxDownload();
+    max_up_speed = theApp.glob_prefs->GetMaxGraphUploadRate();
+    max_dl_speed = theApp.glob_prefs->GetMaxGraphDownloadRate();
     // What will be shown, very nice!
     if (actual_dl_speed == UNLIMITED || actual_dl_speed == 0)
     {
@@ -262,19 +284,19 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     // Info menu
     info_menu = gtk_menu_new();
     gtk_menu_set_title(GTK_MENU(info_menu), "xMule TrayMenu Info");
-    if (theApp.glob_prefs -> GetUserNick() != NULL)
+    if (theApp.glob_prefs->GetUserNick() != NULL)
     {
-        info_item = gtk_menu_item_new_with_label(wxString("Nick: ") + theApp.glob_prefs -> GetUserNick());
+        info_item = gtk_menu_item_new_with_label(wxString("Nick: ") + theApp.glob_prefs->GetUserNick());
     }
     else
     {
         info_item = gtk_menu_item_new_with_label("Nick: Not Ready");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> GetUserHash())
+    if (theApp.glob_prefs->GetUserHash())
     {
         CString hash;
-        hash = EncodeBase16((const unsigned char *) theApp.glob_prefs -> GetUserHash(), 16);
+        hash = EncodeBase16((const unsigned char *) theApp.glob_prefs->GetUserHash(), 16);
         info_item = gtk_menu_item_new_with_label(wxString("Hash: ") + hash.GetBuffer());
     }
     else
@@ -282,9 +304,9 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
         info_item = gtk_menu_item_new_with_label("Hash: Not Ready");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.serverconnect -> IsConnected())
+    if (theApp.serverconnect->IsConnected())
     {
-        info_item = gtk_menu_item_new_with_label(wxString("ClientID: ") + wxString:: Format("%.0f", (float) theApp.serverconnect -> GetClientID()));
+        info_item = gtk_menu_item_new_with_label(wxString("ClientID: ") + wxString::Format("%.0f", (float) theApp.serverconnect->GetClientID()));
     }
     else
     {
@@ -294,9 +316,9 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     tempstring = getIP();
     info_item = gtk_menu_item_new_with_label(wxString("IP: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> GetPort())
+    if (theApp.glob_prefs->GetPort())
     {
-        tempstring = g_strdup_printf("%d", theApp.glob_prefs -> GetPort());
+        tempstring = g_strdup_printf("%d", theApp.glob_prefs->GetPort());
         info_item = gtk_menu_item_new_with_label(wxString("TCP Port: ") + tempstring);
     }
     else
@@ -304,9 +326,9 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
         info_item = gtk_menu_item_new_with_label("TCP Port: Not Ready");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> GetUDPPort())
+    if (theApp.glob_prefs->GetUDPPort())
     {
-        tempstring = g_strdup_printf("%d", theApp.glob_prefs -> GetUDPPort());
+        tempstring = g_strdup_printf("%d", theApp.glob_prefs->GetUDPPort());
         info_item = gtk_menu_item_new_with_label(wxString("UDP Port: ") + tempstring);
     }
     else
@@ -314,7 +336,7 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
         info_item = gtk_menu_item_new_with_label("UDP Port: Not Ready");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> IsOnlineSignatureEnabled())
+    if (theApp.glob_prefs->IsOnlineSignatureEnabled())
     {
         info_item = gtk_menu_item_new_with_label("Online Signature: Enabled");
     }
@@ -335,12 +357,12 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
         info_item = gtk_menu_item_new_with_label("Uptime: None");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.serverconnect -> GetCurrentServer() != NULL)
+    if (theApp.serverconnect->GetCurrentServer() != NULL)
     {
-        info_item = gtk_menu_item_new_with_label(wxString("ServerName: ") + theApp.serverconnect -> GetCurrentServer() -> GetListName());
+        info_item = gtk_menu_item_new_with_label(wxString("ServerName: ") + theApp.serverconnect->GetCurrentServer()->GetListName());
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-        tempstring = g_strdup_printf("%d", theApp.serverconnect -> GetCurrentServer() -> GetPort());
-        info_item = gtk_menu_item_new_with_label(wxString("ServerIP: ") + theApp.serverconnect -> GetCurrentServer() -> GetFullIP() + wxString(" : ") + tempstring);
+        tempstring = g_strdup_printf("%d", theApp.serverconnect->GetCurrentServer()->GetPort());
+        info_item = gtk_menu_item_new_with_label(wxString("ServerIP: ") + theApp.serverconnect->GetCurrentServer()->GetFullIP() + wxString(" : ") + tempstring);
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     }
     else
@@ -350,16 +372,16 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
         info_item = gtk_menu_item_new_with_label("ServerIP: Not Connected");
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     }
-    tempstring = g_strdup_printf("%d", theApp.sharedfiles -> GetCount());
+    tempstring = g_strdup_printf("%d", theApp.sharedfiles->listof_SharedFiles->Data);
     info_item = gtk_menu_item_new_with_label(wxString("Shared Files: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    tempstring = g_strdup_printf("%d", theApp.uploadqueue -> GetWaitingUserCount());
+    tempstring = g_strdup_printf("%d", theApp.uploadqueue->GetWaitingUserCount());
     info_item = gtk_menu_item_new_with_label(wxString("Queued Clients: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionReceivedBytes + theApp.glob_prefs -> GetTotalDownloaded()) / 1073741824));
+    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionReceivedBytes + theApp.glob_prefs->GetTotalDownloaded()) / 1073741824));
     info_item = gtk_menu_item_new_with_label(wxString("Total DL: ") + tempstring + wxString("  GB"));
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionSentBytes + theApp.glob_prefs -> GetTotalUploaded()) / 1073741824));
+    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionSentBytes + theApp.glob_prefs->GetTotalUploaded()) / 1073741824));
     info_item = gtk_menu_item_new_with_label(wxString("Total UP: ") + tempstring + wxString("  GB"));
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     // Main menu
@@ -517,20 +539,20 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     // gtk_signal_connect(GTK_OBJECT(info_menu), "leave_notify_event", GTK_SIGNAL_FUNC(gtk_widget_destroy), &info_menu);
     // Finalization
     gtk_widget_show_all(status_menu);
-    gtk_menu_popup(GTK_MENU(status_menu), NULL, NULL, NULL, NULL, event -> button, event -> time);
+    gtk_menu_popup(GTK_MENU(status_menu), NULL, NULL, NULL, NULL, event->button, event->time);
     return TRUE;
 }
 
 static gboolean tray_clicked(GtkWidget *event_box, GdkEventButton *event, gpointer data)
 {
     // Mouse wheel or middle click + left double click
-    if ((event -> button == 1 &&event -> type == GDK_2BUTTON_PRESS) || event -> button == 2)
+    if ((event->button == 1 &&event->type == GDK_2BUTTON_PRESS) || event->button == 2)
     {
         showgui();
         return true;
     }
     // Mouse right click
-    if (event -> button == 3)
+    if (event->button == 3)
     {
         return tray_menu(event_box, event, data);
     }
@@ -538,7 +560,7 @@ static gboolean tray_clicked(GtkWidget *event_box, GdkEventButton *event, gpoint
 
 #endif
 
-CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
+CSysTray::CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
 {
 #ifndef __SYSTRAY_DISABLED__
     static GtkWidget *eventbox;
@@ -552,7 +574,7 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
     m_pColors = NULL;
     parent = _parent;
     desktopMode = _desktopMode;
-    if (desktopMode == 4)
+    if (desktopMode == 3)
     {
         // Not wanted, so don't show it.
         return;
@@ -562,7 +584,7 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
     textdomain(PACKAGE);
     bool use_legacy = false;
     // Case 2 and 3 are KDE/other legacy system
-    if (desktopMode == 2 || desktopMode == 3)
+    if (desktopMode == 1 || desktopMode == 2)
     {
         use_legacy = true;
     }
@@ -588,7 +610,7 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
     // Set image
     GdkBitmap *mask = NULL;
     GdkPixmap *
-    img = gdk_pixmap_create_from_xpm_d(status_docklet -> window, &mask, NULL, mule_Tr_grey_ico);
+    img = gdk_pixmap_create_from_xpm_d(status_docklet->window, &mask, NULL, mule_Tr_grey_ico);
     status_image = gtk_pixmap_new(img, mask);
     eventbox = gtk_event_box_new();
     gtk_widget_show(eventbox);
@@ -611,10 +633,10 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
 #endif
 }
 
-void CSysTray:: setupProperties()
+void CSysTray::setupProperties()
 {
 #ifndef __SYSTRAY_DISABLED__
-    GdkWindow *window = status_docklet -> window;
+    GdkWindow *window = status_docklet->window;
     glong data[1];
     GdkAtom kwm_dockwindow_atom;
     GdkAtom kde_net_system_tray_window_for_atom;
@@ -630,7 +652,7 @@ void CSysTray:: setupProperties()
 #endif
 }
 
-void CSysTray:: Show(const wxChar *caption, int nMsgType, DWORD dwTimeToShow, DWORD dwTimeToStay, DWORD dwTimeTOHide)
+void CSysTray::Show(const wxChar *caption, int nMsgType, DWORD dwTimeToShow, DWORD dwTimeToStay, DWORD dwTimeTOHide)
 {
 #ifndef __SYSTRAY_DISABLED__
     if (desktopMode == 4)
@@ -645,7 +667,7 @@ void CSysTray:: Show(const wxChar *caption, int nMsgType, DWORD dwTimeToShow, DW
 #endif
 }
 
-void CSysTray:: TraySetToolTip(char *data)
+void CSysTray::TraySetToolTip(char *data)
 {
 #ifndef __SYSTRAY_DISABLED__
     if (desktopMode == 4)
@@ -661,7 +683,7 @@ void CSysTray:: TraySetToolTip(char *data)
 }
 
 // It the nLevel is greater than the values defined in m_pLimits the last value in the array is used
-COLORREF CSysTray:: GetMeterColor(int nLevel)
+COLORREF CSysTray::GetMeterColor(int nLevel)
 {
 #ifndef __SYSTRAY_DISABLED__
     for (int i = 0 ; i < m_nEntries ; i++)
@@ -677,7 +699,7 @@ COLORREF CSysTray:: GetMeterColor(int nLevel)
     return m_pColors[m_nEntries - 1];
 }
 
-void CSysTray:: DrawIconMeter(GdkPixmap *pix, GdkBitmap *mask, int nLevel, int nPos)
+void CSysTray::DrawIconMeter(GdkPixmap *pix, GdkBitmap *mask, int nLevel, int nPos)
 {
 #ifndef __SYSTRAY_DISABLED__
     GdkGC *gc = gdk_gc_new(pix);
@@ -699,7 +721,7 @@ void CSysTray:: DrawIconMeter(GdkPixmap *pix, GdkBitmap *mask, int nLevel, int n
 #endif
 }
 
-void CSysTray:: drawMeters(GdkPixmap *pix, GdkBitmap *mask, int *pBarData)
+void CSysTray::drawMeters(GdkPixmap *pix, GdkBitmap *mask, int *pBarData)
 {
 #ifndef __SYSTRAY_DISABLED__
     if (pBarData == NULL)
@@ -713,7 +735,7 @@ void CSysTray:: drawMeters(GdkPixmap *pix, GdkBitmap *mask, int *pBarData)
 #endif
 }
 
-void CSysTray:: TraySetIcon(char **data, bool what, int *pVals)
+void CSysTray::TraySetIcon(char **data, bool what, int *pVals)
 {
 #ifndef __SYSTRAY_DISABLED__
     if (desktopMode == 4)
@@ -729,10 +751,10 @@ void CSysTray:: TraySetIcon(char **data, bool what, int *pVals)
     GdkPixmap *newpix, *newbit;
     /* Set new picture */
     gtk_pixmap_get(GTK_PIXMAP(status_image), &oldpix, &oldbit);
-    newpix = gdk_pixmap_create_from_xpm_d(status_docklet -> window, &newbit, NULL, data);
+    newpix = gdk_pixmap_create_from_xpm_d(status_docklet->window, &newbit, NULL, data);
     /* Create pixmap for meters */
-    GdkPixmap *meterpix = gdk_pixmap_new(status_docklet -> window, 22, 22, - 1);
-    GdkBitmap *meterbit = gdk_pixmap_new(status_docklet -> window, 22, 22, 1);
+    GdkPixmap *meterpix = gdk_pixmap_new(status_docklet->window, 22, 22, - 1);
+    GdkBitmap *meterbit = gdk_pixmap_new(status_docklet->window, 22, 22, 1);
     /* Draw meters */
     drawMeters(meterpix, meterbit, pVals);
     /* Then draw meters onto main pix */
@@ -757,7 +779,7 @@ void CSysTray:: TraySetIcon(char **data, bool what, int *pVals)
 #endif
 }
 
-bool CSysTray:: SetColorLevels(int *pLimits, COLORREF *pColors, int nEntries)
+bool CSysTray::SetColorLevels(int *pLimits, COLORREF *pColors, int nEntries)
 {
 #ifndef __SYSTRAY_DISABLED__
     // Free allocated memory
