@@ -1,43 +1,36 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
-//
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifndef _TRANSFERWND_H
 #define _TRANSFERWND_H
 
-#include "UploadListCtrl.h"
-#include "DownloadListCtrl.h"
-//#include "ResizableLib/ResizableDialog.h"
-#include "SplitterControl.h"
-#include "QueueListCtrl.h"
+#include "UploadListCtrl.h"             // Needed for CUploadListCtrl
+#include "DownloadListCtrl.h"           // Needed for CDownloadListCtrl
+#include "SplitterControl.h"            // Needed for CSplitterControl
+#include "QueueListCtrl.h"              // Needed for CQueueListCtrl
+#include <wx/notebook.h>                // Needed for wxNotebookEvent
+#include <wx/listctrl.h>                // Needed for wxListCtrl
 
-#include <wx/panel.h>
-#include <wx/tooltip.h>
-#include <wx/notebook.h>
-
-// CTransferWnd dialog
-
-#include <wx/listctrl.h>
 class CMuleNotebook;
-class CTransferWnd : public wxPanel //CResizableDialog
+class CTransferWnd : public wxPanel
 {
   //DECLARE_DYNAMIC(CTransferWnd)
   DECLARE_DYNAMIC_CLASS(CTransferWnd)
@@ -50,7 +43,7 @@ public:
 	void	Localize();
 	BOOL	OnInitDialog();
 // Dialog Data
-	enum { IDD = IDD_TRANSFER };
+	enum { IDD };
 	CUploadListCtrl*		uploadlistctrl;
 	CDownloadListCtrl*	downloadlistctrl;
 	CQueueListCtrl*		queuelistctrl;
