@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -20,12 +20,10 @@
 #ifndef WIZARD_H
 #define WIZARD_H
 
-#include "resource.h"
+#include <wx/dialog.h>                  // Needed for wxDialog
+#include <wx/listctrl.h>                // Needed for wxListCtrl
 
-#include <wx/dialog.h>
-#include <wx/listctrl.h>
-
-// Wizard dialog
+#include "Preferences.h"                // Needed for CPreferences
 
 class Wizard : public wxDialog
 {
@@ -41,7 +39,7 @@ public:
 	int m_iTotalDownload;
 
 // Dialog Data
-	enum { IDD = IDD_WIZARD };
+	enum { IDD };
 protected:
 	CPreferences* app_prefs;
 protected:
