@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -22,15 +22,12 @@
 //////////////////////////////////////////////////////////////////////
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#include "wintypes.h"
-#include "ini2.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/string.h>
-#include <wx/window.h>
-#include <wx/config.h>
+#include "ini2.h"                           // Needed for this Interface's Prototype
+
+#include <wx/config.h>                      // Needed for wxConfigBase
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -51,7 +48,7 @@ static char THIS_FILE[] = __FILE__;
 // to avoid storing in the windows-directory
     /*static*/
 
-    void CIni:: AddModulPath(wxString &strFileName, BOOL bModulPath /*= TRUE*/
+    void CIni::AddModulPath(wxString &strFileName, BOOL bModulPath /*= TRUE*/
 
 )
 {
@@ -91,7 +88,7 @@ static char THIS_FILE[] = __FILE__;
 
     /*static*/
 
-wxString CIni:: GetDefaultSection()
+wxString CIni::GetDefaultSection()
 {
     return wxString("eMule");
     //   return AfxGetAppName();
@@ -99,7 +96,7 @@ wxString CIni:: GetDefaultSection()
 
     /*static*/
 
-    wxString CIni:: GetDefaultIniFile(BOOL bModulPath /*= TRUE*/
+    wxString CIni::GetDefaultIniFile(BOOL bModulPath /*= TRUE*/
 
 )
 {
@@ -141,22 +138,19 @@ wxString CIni:: GetDefaultSection()
 // Konstruktion/Destruktion
 //////////////////////////////////////////////////////////////////////
 // Creates/Use file : "Drive:\ApplPath\ApplName.ini"
-    CIni:: CIni(BOOL bModulPath /*= TRUE*/
-
-):
-m_bModulPath(bModulPath)
+CIni::CIni(BOOL bModulPath)
 {
+    m_bModulPath = bModulPath;
     m_strFileName = GetDefaultIniFile(m_bModulPath);
     m_strSection = GetDefaultSection();
 }
 
-    CIni:: CIni(CIni const &Ini, BOOL bModulPath /*= TRUE*/
-
-):
-m_strFileName(Ini.m_strFileName),
-m_strSection(Ini.m_strSection),
-m_bModulPath(Ini.m_bModulPath)
+CIni::CIni(CIni const &Ini, BOOL bModulPath)
 {
+    m_strSection = Ini.m_strSection;
+    m_strFileName = Ini.m_strFileName;
+    m_bModulPath = Ini.m_bModulPath;
+   
     if (m_strFileName.IsEmpty())
     m_strFileName = GetDefaultIniFile(m_bModulPath);
     AddModulPath(m_strFileName, m_bModulPath);
@@ -164,7 +158,7 @@ m_bModulPath(Ini.m_bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-    CIni:: CIni(wxString const &strFileName, BOOL bModulPath /*= TRUE*/
+    CIni::CIni(wxString const &strFileName, BOOL bModulPath /*= TRUE*/
 
 ):
 m_strFileName(strFileName),
@@ -176,7 +170,7 @@ m_bModulPath(bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-    CIni:: CIni(wxString const &strFileName, wxString const &strSection, BOOL bModulPath /*= TRUE*/
+    CIni::CIni(wxString const &strFileName, wxString const &strSection, BOOL bModulPath /*= TRUE*/
 
 ):
 m_strFileName(strFileName),
@@ -190,30 +184,30 @@ m_bModulPath(bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-CIni:: ~CIni()
+CIni::~CIni()
 {
 }
 
 //////////////////////////////////////////////////////////////////////
 // Zugriff auf Quelle/Ziel von IO-Operationen
 //////////////////////////////////////////////////////////////////////
-void CIni:: SetFileName(wxString const &strFileName)
+void CIni::SetFileName(wxString const &strFileName)
 {
     m_strFileName = strFileName;
     AddModulPath(m_strFileName);
 }
 
-void CIni:: SetSection(wxString const &strSection)
+void CIni::SetSection(wxString const &strSection)
 {
     m_strSection = strSection;
 }
 
-wxString const &CIni:: GetFileName() const
+wxString const &CIni::GetFileName() const
 {
     return m_strFileName;
 }
 
-wxString const &CIni:: GetSection() const
+wxString const &CIni::GetSection() const
 {
     return m_strSection;
 }
@@ -222,7 +216,7 @@ wxString const &CIni:: GetSection() const
 //
 //////////////////////////////////////////////////////////////////////
 
-    void CIni:: Init(LPCSTR strFileName, LPCSTR strSection/* = NULL*/
+    void CIni::Init(LPCSTR strFileName, LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -232,7 +226,7 @@ wxString const &CIni:: GetSection() const
     m_strFileName = strFileName;
 }
 
-    wxString CIni:: GetString(wxString strEntry, LPCSTR strDefault/*=NULL*/
+    wxString CIni::GetString(wxString strEntry, LPCSTR strDefault/*=NULL*/
 
     , LPCSTR strSection/* = NULL*/
 
@@ -244,7 +238,7 @@ wxString const &CIni:: GetSection() const
     return wxString(GetLPCSTR(strEntry, strSection, strDefault));
 }
 
-    double CIni:: GetDouble(wxString strEntry, double fDefault/* = 0.0*/
+    double CIni::GetDouble(wxString strEntry, double fDefault/* = 0.0*/
 
     , LPCSTR strSection/* = NULL*/
 
@@ -252,12 +246,12 @@ wxString const &CIni:: GetSection() const
 {
     wxString strDefault;
     //strDefault.Format("%g",fDefault);
-    strDefault = wxString:: Format("%g", fDefault);
+    strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return atof(m_chBuffer);
 }
 
-    float CIni:: GetFloat(wxString strEntry, float fDefault/* = 0.0*/
+    float CIni::GetFloat(wxString strEntry, float fDefault/* = 0.0*/
 
     , LPCSTR strSection/* = NULL*/
 
@@ -265,12 +259,12 @@ wxString const &CIni:: GetSection() const
 {
     wxString strDefault;
     //strDefault.Format("%g",fDefault);
-    strDefault = wxString:: Format("%g", fDefault);
+    strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(float) atof(m_chBuffer);
 }
 
-    int CIni:: GetInt(wxString strEntry, int nDefault/* = 0*/
+    int CIni::GetInt(wxString strEntry, int nDefault/* = 0*/
 
     , LPCSTR strSection/* = NULL*/
 
@@ -278,12 +272,12 @@ wxString const &CIni:: GetSection() const
 {
     wxString strDefault;
     //strDefault.Format("%d",nDefault);
-    strDefault = wxString:: Format("%d", nDefault);
+    strDefault = wxString::Format("%d", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault.GetData());
     return atoi(m_chBuffer);
 }
 
-    WORD CIni:: GetWORD(wxString strEntry, WORD nDefault/* = 0*/
+    WORD CIni::GetWORD(wxString strEntry, WORD nDefault/* = 0*/
 
     , LPCSTR strSection/* = NULL*/
 
@@ -291,12 +285,12 @@ wxString const &CIni:: GetSection() const
 {
     wxString strDefault;
     //strDefault.Format("%u",nDefault);
-    strDefault = wxString:: Format("%u", nDefault);
+    strDefault = wxString::Format("%u", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(WORD) atoi(m_chBuffer);
 }
 
-    BOOL CIni:: GetBool(wxString strEntry, BOOL bDefault/* = FALSE*/
+    BOOL CIni::GetBool(wxString strEntry, BOOL bDefault/* = FALSE*/
 
     , LPCSTR strSection/* = NULL*/
 
@@ -304,23 +298,23 @@ wxString const &CIni:: GetSection() const
 {
     wxString strDefault;
     //strDefault.Format("%d",bDefault);
-    strDefault = wxString:: Format("%d", bDefault);
+    strDefault = wxString::Format("%d", bDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(atoi(m_chBuffer) != 0);
 }
 
-wxPoint CIni:: GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
+wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
 {
     wxPoint ptReturn = ptDefault;
     wxString strDefault;
-    strDefault = wxString:: Format("(%d,%d)", ptDefault.x, ptDefault.y);
+    strDefault = wxString::Format("(%d,%d)", ptDefault.x, ptDefault.y);
     //strDefault.Format("(%d,%d)",ptDefault.x, ptDefault.y);
     wxString strPoint = GetString(strEntry, (char *) strDefault.GetData());
     sscanf(strPoint, "(%d,%d)", &ptReturn.x, &ptReturn.y);
     return ptReturn;
 }
 
-wxRect CIni:: GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
+wxRect CIni::GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
 {
 #if 0
     wxRect rectReturn = rectDefault;
@@ -339,7 +333,7 @@ wxRect CIni:: GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
     return wxRect(0, 0, 0, 0);
 }
 
-COLORREF CIni:: GetColRef(wxString strEntry, COLORREF crDefault, LPCSTR strSection)
+COLORREF CIni::GetColRef(wxString strEntry, COLORREF crDefault, LPCSTR strSection)
 {
     int temp[3] =
     {
@@ -348,7 +342,7 @@ COLORREF CIni:: GetColRef(wxString strEntry, COLORREF crDefault, LPCSTR strSecti
         GetBValue(crDefault)
         };
     wxString strDefault;
-    strDefault = wxString:: Format("RGB(%hd,%hd,%hd)", temp[0], temp[1], temp[2]);
+    strDefault = wxString::Format("RGB(%hd,%hd,%hd)", temp[0], temp[1], temp[2]);
     wxString strColRef = GetString(strEntry, (char *) strDefault.GetData());
     sscanf(strColRef, "RGB(%d,%d,%d)", temp, temp + 1, temp + 2);
     return RGB(temp[0], temp[1], temp[2]);
@@ -358,12 +352,12 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
 {
     char buffer[512];
     sprintf(buffer, "%s/%s", sec, entry);
-    wxConfigBase *cb = wxConfigBase:: Get(TRUE);
-    cb -> Write(buffer, jottae);
-    cb -> Flush();
+    wxConfigBase *cb = wxConfigBase::Get(TRUE);
+    cb->Write(buffer, jottae);
+    cb->Flush();
 }
 
-    void CIni:: WriteString(wxString strEntry, wxString str, LPCSTR strSection/* = NULL*/
+    void CIni::WriteString(wxString strEntry, wxString str, LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -372,71 +366,71 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, str, m_strFileName);
 }
 
-    void CIni:: WriteDouble(wxString strEntry, double f, LPCSTR strSection/*= NULL*/
+    void CIni::WriteDouble(wxString strEntry, double f, LPCSTR strSection/*= NULL*/
 
 )
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%g", f);
+    strBuffer = wxString::Format("%g", f);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteFloat(wxString strEntry, float f, LPCSTR strSection/* = NULL*/
+    void CIni::WriteFloat(wxString strEntry, float f, LPCSTR strSection/* = NULL*/
 
 )
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%g", f);
+    strBuffer = wxString::Format("%g", f);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteInt(wxString strEntry, int n, LPCSTR strSection/* = NULL*/
+    void CIni::WriteInt(wxString strEntry, int n, LPCSTR strSection/* = NULL*/
 
 )
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%d", n);
+    strBuffer = wxString::Format("%d", n);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteWORD(wxString strEntry, WORD n, LPCSTR strSection/* = NULL*/
+    void CIni::WriteWORD(wxString strEntry, WORD n, LPCSTR strSection/* = NULL*/
 
 )
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%u", n);
+    strBuffer = wxString::Format("%u", n);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteBool(wxString strEntry, BOOL b, LPCSTR strSection/* = NULL*/
+    void CIni::WriteBool(wxString strEntry, BOOL b, LPCSTR strSection/* = NULL*/
 
 )
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%d", b);
+    strBuffer = wxString::Format("%d", b);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-void CIni:: WritePoint(wxString strEntry, wxPoint pt, LPCSTR strSection)
+void CIni::WritePoint(wxString strEntry, wxPoint pt, LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("(%d,%d)", pt.x, pt.y);
+    strBuffer = wxString::Format("(%d,%d)", pt.x, pt.y);
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-void CIni:: WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
+void CIni::WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
@@ -445,24 +439,24 @@ void CIni:: WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-void CIni:: WriteColRef(wxString strEntry, COLORREF cr, LPCSTR strSection)
+void CIni::WriteColRef(wxString strEntry, COLORREF cr, LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("RGB(%d,%d,%d)", GetRValue(cr), GetGValue(cr), GetBValue(cr));
+    strBuffer = wxString::Format("RGB(%d,%d,%d)", GetRValue(cr), GetGValue(cr), GetBValue(cr));
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-wxChar *CIni:: GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxChar *strDefault)
+wxChar *CIni::GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxChar *strDefault)
 {
-    wxConfigBase *cb = wxConfigBase:: Get(TRUE);
+    wxConfigBase *cb = wxConfigBase::Get(TRUE);
     char buffer[512];
     if (strSection)
     m_strSection = wxString(strSection);
     sprintf(buffer, "%s/%s", m_strSection.GetData(), strEntry.GetData());
-    wxString stringu = cb -> Read(wxString(buffer), wxString(strDefault));
-    cb -> Flush();
+    wxString stringu = cb->Read(wxString(buffer), wxString(strDefault));
+    cb->Flush();
     memcpy(m_chBuffer, stringu.GetData(), stringu.Length() + 1);
     return m_chBuffer;
 #if 0
@@ -479,7 +473,7 @@ wxChar *CIni:: GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxCh
 #endif
 }
 
-void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault)
+void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault)
 {
     if (bGet)
     str = GetString(strEntry, strDefault/*=NULL*/
@@ -490,7 +484,7 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetDouble(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDouble(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , double fDefault/* = 0.0*/
 
@@ -505,7 +499,7 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetFloat(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetFloat(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , float fDefault/* = 0.0*/
 
@@ -520,7 +514,7 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetInt(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetInt(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , int nDefault/* = 0*/
 
@@ -535,7 +529,7 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetDWORD(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDWORD(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , DWORD nDefault/* = 0*/
 
@@ -550,7 +544,7 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetBool(BOOL bGet, BOOL &b, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetBool(BOOL bGet, BOOL &b, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , BOOL bDefault/* = FALSE*/
 
@@ -565,7 +559,7 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-void CIni:: SerGetPoint(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection, wxPoint ptDefault)
+void CIni::SerGetPoint(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection, wxPoint ptDefault)
 {
     if (bGet)
     pt = GetPoint(strEntry, ptDefault, strSection);
@@ -573,7 +567,7 @@ void CIni:: SerGetPoint(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSec
     WritePoint(strEntry, pt, strSection);
 }
 
-void CIni:: SerGetRect(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection, wxRect rectDefault)
+void CIni::SerGetRect(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection, wxRect rectDefault)
 {
     if (bGet)
     rect = GetRect(strEntry, rectDefault, strSection);
@@ -581,7 +575,7 @@ void CIni:: SerGetRect(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSec
     WriteRect(strEntry, rect, strSection);
 }
 
-void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSection, COLORREF crDefault)
+void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSection, COLORREF crDefault)
 {
     if (bGet)
     cr = GetColRef(strEntry, crDefault, strSection);
@@ -591,7 +585,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
 
 // berladene Methoden //////////////////////////////////////////////////////////////////////////////////////////////////77
 // Einfache Typen /////////////////////////////////////////////////////////////////////////////////////////////////////////
-    void CIni:: SerGet(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , LPCSTR strDefault/*= NULL*/
 
@@ -600,7 +594,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     SerGetString(bGet, str, strEntry, strSection, strDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , double fDefault/* = 0.0*/
 
@@ -609,7 +603,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     SerGetDouble(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , float fDefault/* = 0.0*/
 
@@ -618,7 +612,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     SerGetFloat(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
@@ -627,7 +621,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     SerGetInt(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, short &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, short &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
@@ -638,7 +632,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     n = nTemp;
 }
 
-    void CIni:: SerGet(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , DWORD nDefault/* = 0*/
 
@@ -647,7 +641,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     SerGetDWORD(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, WORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, WORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , DWORD nDefault/* = 0*/
 
@@ -659,7 +653,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
 }
 
 //	void		SerGet(	BOOL bGet,BOOL		& b,	wxString strEntry,	LPCSTR strSection = NULL,	BOOL bDefault = FALSE);
-    void CIni:: SerGet(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , wxPoint ptDefault/* = wxPoint(0,0)*/
 
@@ -668,7 +662,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     SerGetPoint(bGet, pt, strEntry, strSection, ptDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , wxRect rectDefault/* = wxRect(0,0,0,0)*/
 
@@ -682,7 +676,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
 // berladene Methoden ////////////////////////////////////////////////////////////////////////////////////////////
 // ARRAYS /////////////////////////////////////////////////////////////////////////////////////////////////////////
 // Entries werden durch Unterstrich + Index ergenzt////////////////////////////////////////////////////////////////
-    void CIni:: SerGet(BOOL bGet, wxString *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, wxString *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , LPCSTR Default/*=NULL*/
 
@@ -716,7 +710,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, double *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, double *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , double Default/* = 0.0*/
 
@@ -742,10 +736,10 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
         else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%g", ar[0]);
+            strBuffer = wxString::Format("%g", ar[0]);
             for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%g", ar[i]);
+                strTemp = wxString::Format("%g", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -755,7 +749,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, float *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, float *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , float Default/* = 0.0*/
 
@@ -781,10 +775,10 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
         else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%g", ar[0]);
+            strBuffer = wxString::Format("%g", ar[0]);
             for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%g", ar[i]);
+                strTemp = wxString::Format("%g", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -794,7 +788,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, int *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, int *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
@@ -820,10 +814,10 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
         else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
+            strBuffer = wxString::Format("%d", ar[0]);
             for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -833,7 +827,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, unsigned char *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, unsigned char *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , unsigned char Default/* = 0*/
 
@@ -859,10 +853,10 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
         else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
+            strBuffer = wxString::Format("%d", ar[0]);
             for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -872,7 +866,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, short *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, short *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
@@ -898,10 +892,10 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
         else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
+            strBuffer = wxString::Format("%d", ar[0]);
             for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -911,7 +905,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, DWORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, DWORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , DWORD Default/* = 0*/
 
@@ -937,10 +931,10 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
         else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
+            strBuffer = wxString::Format("%d", ar[0]);
             for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -950,7 +944,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, WORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, WORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , DWORD Default/* = 0*/
 
@@ -976,10 +970,10 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
         else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
+            strBuffer = wxString::Format("%d", ar[0]);
             for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //				strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -989,7 +983,7 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, wxPoint *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, wxPoint *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , wxPoint Default/* = wxPoint(0,0)*/
 
@@ -998,13 +992,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     wxString strBuffer;
     for (int i = 0 ; i < nCount ; i++)
     {
-        strBuffer = wxString:: Format("_%i", i);
+        strBuffer = wxString::Format("_%i", i);
         strBuffer = strEntry + strBuffer;
         SerGet(bGet, ar[i], strBuffer, strSection, Default);
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, wxRect *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(BOOL bGet, wxRect *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , wxRect Default/* = wxRect(0,0,0,0)*/
 
@@ -1013,13 +1007,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     wxString strBuffer;
     for (int i = 0 ; i < nCount ; i++)
     {
-        strBuffer = wxString:: Format("_%i", i);
+        strBuffer = wxString::Format("_%i", i);
         strBuffer = strEntry + strBuffer;
         SerGet(bGet, ar[i], strBuffer, strSection, Default);
     }
 }
 
-int CIni:: Parse(wxString &strIn, int nOffset, wxString &strOut)
+int CIni::Parse(wxString &strIn, int nOffset, wxString &strOut)
 {
     strOut.Clear();
     int nLength = strIn.Length();
@@ -1052,7 +1046,7 @@ void GetPrivateProfileString(const wxChar *a0, const wxChar *a, const wxChar *b,
 //////////////////////////////////////////////////////////////////////
 // statische Methoden
 //////////////////////////////////////////////////////////////////////
-wxString CIni:: Read(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strDefault)
+wxString CIni::Read(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strDefault)
 {
     wxString strReturn;
     GetPrivateProfileString(strSection,
@@ -1066,7 +1060,7 @@ wxString CIni:: Read(wxString const &strFileName, wxString const &strSection, wx
     return strReturn;
 }
 
-void CIni:: Write(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strValue)
+void CIni::Write(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strValue)
 {
     WritePrivateProfileString(strSection,
     strEntry,
