@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project
 // Copyright (C)2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -22,28 +22,19 @@
 // wrappers for required MFC classes
 // makes life a bit less annoying
 
-#include <wx/list.h>
-#include <wx/hashmap.h>
-#include <wx/dynarray.h>
-#include <wx/listimpl.cpp>
-#include <map>
+#include <wx/list.h>                    // Needed for WX_DECLARE_LIST
+#include <wx/hashmap.h>                 // Needed for WX_DECLARE_HASH_MAP
+#include <wx/dynarray.h>                // Needed for WX_DEFINE_ARRAY
 
 WX_DEFINE_ARRAY(void *, VoidArray);
-
 WX_DECLARE_LIST(void, VoidList);
-
-// da map
 WX_DECLARE_HASH_MAP(unsigned int, void *, wxIntegerHash, wxIntegerEqual, VoidHash);
 
-//typedef VoidList::Node* POSITION;
-
 typedef struct
 {
-    VoidHash:: iterator it;
-    VoidList:: Node *node;
-}
-
-_POSITION;
+    VoidHash::iterator it;
+    VoidList::Node *node;
+} _POSITION;
 
 typedef _POSITION *POSITION;
 
@@ -74,8 +65,8 @@ class CList: public wxObject
     MYNODE *newNode(ARG_TYPE data)
     {
         MYNODE *n = new MYNODE;
-        n -> prev = n -> next = NULL;
-        n -> data = data;
+        n->prev = n->next = NULL;
+        n->data = data;
         return n;
     }
     public:
@@ -84,7 +75,7 @@ class CList: public wxObject
         internalList = NULL;
         tail = NULL;
         count = 0;
-        };
+    }
     // hmm.. you really want to DELETE the list too!
     ~CList()
     {
@@ -113,59 +104,59 @@ class CList: public wxObject
     {
         if (internalList)
         {
-            return internalList -> data;
+            return internalList->data;
         }
         else
         {
             printf("1DO NOT CALL WITH EMPTY LIST\n");
             exit(1);
         }
-        };
+    }
     TYPE GetHead() const
     {
         if (internalList)
         {
-            return internalList -> data;
+            return internalList->data;
         }
         else
         {
             return(TYPE) 0;
         }
-        };
+    }
     TYPE &GetTail()
     {
         if (tail)
         {
-            return tail -> data;
+            return tail->data;
         }
         else
         {
             printf("DONT CALL WITH EMPTY LIST\n");
             exit(1);
         }
-        };
+    }
     TYPE GetTail() const
     {
         if (tail)
         {
-            return tail -> data;
+            return tail->data;
         }
         else
         {
             return(TYPE) 0;
         }
-        };
+    }
     TYPE RemoveHead()
     {
         if (internalList)
         {
             MYNODE *old = internalList;
-            TYPE oldvalue = old -> data;
+            TYPE oldvalue = old->data;
             // advance head
-            internalList = internalList -> next;
+            internalList = internalList->next;
             // if not null, then there are still items in the list
             if (internalList)
-            internalList -> prev = NULL;
+            internalList->prev = NULL;
             // and this is the head
             else
             tail = NULL;
@@ -176,18 +167,18 @@ class CList: public wxObject
         }
         // otherwise we are iterating on a empty list..
         return(TYPE) 0;
-        };
+    }
     TYPE RemoveTail()
     {
         if (tail)
         {
             MYNODE *old = tail;
-            TYPE olddata = tail -> data;
+            TYPE olddata = tail->data;
             // move tail to previous node
-            tail = tail -> prev;
+            tail = tail->prev;
             // is there list anymore?
             if (tail)
-            tail -> next = NULL;
+            tail->next = NULL;
             // yes. this is the tail
             else
             internalList = NULL;
@@ -198,66 +189,66 @@ class CList: public wxObject
         }
         // iterating on an empty list
         return(TYPE) 0;
-        };
+    }
     POSITION AddHead(ARG_TYPE uusi)
     {
         MYNODE *newnode = newNode(uusi);
         // we are adding to head!
-        newnode -> next = internalList;
+        newnode->next = internalList;
         if (internalList)
-        internalList -> prev = newnode;
+        internalList->prev = newnode;
         else
         tail = newnode;
         internalList = newnode;
         count++;
         // return position to head
         return(POSITION) internalList;
-        };
+    }
     POSITION AddTail(ARG_TYPE uusi)
     {
         MYNODE *newnode = newNode(uusi);
         // and to the tail
-        newnode -> prev = tail;
+        newnode->prev = tail;
         if (tail)
-        tail -> next = newnode;
+        tail->next = newnode;
         else
         internalList = newnode;
         tail = newnode;
         count++;
         return(POSITION) tail;
-        };
+    }
     POSITION Append(ARG_TYPE uusi)
     {
         // addtail
         return AddTail(uusi);
-        };
+    }
     void RemoveAll()
     {
         MYNODE *first = internalList;
         while (first)
         {
-            MYNODE *n = first -> next;
+            MYNODE *n = first->next;
             freeNode(first);
             first = n;
         }
         internalList = tail = NULL;
         count = 0;
-        };
+    }
     POSITION GetHeadPosition() const
     {
         return(POSITION) internalList;
-        };
+    }
     POSITION GetTailPosition() const
     {
         return(POSITION) tail;
-        };
+    }
     TYPE &GetNext(POSITION &pos)
     {
         MYNODE *n = (MYNODE *) pos;
         if (n)
         {
-            TYPE &data = n -> data;
-            n = n -> next;
+            TYPE &data = n->data;
+            n = n->next;
             pos = (POSITION) n;
             return data;
         }
@@ -266,14 +257,14 @@ class CList: public wxObject
             printf("2DO NOT CALL WITH EMPTY LIST!\n");
             exit(1);
         }
-        };
+    }
     TYPE GetNext(POSITION &pos) const
     {
         MYNODE *n = (MYNODE *) pos;
         if (n)
         {
-            TYPE data = n -> data;
-            n = n -> next;
+            TYPE data = n->data;
+            n = n->next;
             pos = (POSITION) n;
             return data;
         }
@@ -281,14 +272,14 @@ class CList: public wxObject
         {
             return(TYPE) 0;
         }
-        };
+    }
     TYPE &GetPrev(POSITION &pos)
     {
         MYNODE *n = (MYNODE *) pos;
         if (n)
         {
-            TYPE &data = n -> data;
-            n = n -> prev;
+            TYPE &data = n->data;
+            n = n->prev;
             pos = (POSITION) n;
             return data;
         }
@@ -297,14 +288,14 @@ class CList: public wxObject
             printf("3DO NOT CALL WITH EMPTY LIST\n");
             exit(1);
         }
-        };
+    }
     TYPE GetPrev(POSITION &pos) const
     {
         MYNODE *n = (MYNODE *) pos;
         if (n)
         {
-            TYPE data = n -> data;
-            n = n -> prev;
+            TYPE data = n->data;
+            n = n->prev;
             pos = (POSITION) n;
             return data;
         }
@@ -312,29 +303,29 @@ class CList: public wxObject
         {
             return(TYPE) 0;
         }
-        };
+    }
     TYPE &GetAt(POSITION pos)
     {
         MYNODE *n = (MYNODE *) pos;
         if (n)
         {
-            return n -> data;
+            return n->data;
         }
         else
         {
             printf("4DO NOT CALL WITH EMPTY LIST\n");
             exit(1);
         }
-        };
+    }
     TYPE GetAt(POSITION pos) const
     {
         MYNODE *n = (MYNODE *) pos;
         if (n)
         {
-            return n -> data;
+            return n->data;
         }
         return(TYPE) 0;
-        };
+    }
     void RemoveAt(POSITION pos)
     {
         MYNODE *n = (MYNODE *) pos;
@@ -344,46 +335,46 @@ class CList: public wxObject
             if (internalList == n)
             {
                 // yes
-                internalList = n -> next;
+                internalList = n->next;
             }
             else
             {
                 // no
-                n -> prev -> next = n -> next;
+                n->prev->next = n->next;
             }
             // is it tail too?
             if (tail == n)
             {
                 // yes
-                tail = n -> prev;
+                tail = n->prev;
             }
             else
             {
                 // no
-                n -> next -> prev = n -> prev;
+                n->next->prev = n->prev;
             }
             freeNode(n);
             count--;
         }
-        };
+    }
     void InsertAfter(POSITION pos, ARG_TYPE data)
     {
         MYNODE *n = (MYNODE *) pos;
         if (n)
         {
             MYNODE *newnode = newNode(data);
-            newnode -> prev = n;
-            newnode -> next = n -> next;
-            if (n -> next)
+            newnode->prev = n;
+            newnode->next = n->next;
+            if (n->next)
             {
-                n -> next -> prev = newnode;
+                n->next->prev = newnode;
             }
             else
             {
                 // it's tail
                 tail = newnode;
             }
-            n -> next = newnode;
+            n->next = newnode;
             // increase count here. not after addtail()
             count++;
         }
@@ -392,21 +383,21 @@ class CList: public wxObject
             // just append
             pos = AddTail(data);
         }
-        };
+    }
     POSITION Find(ARG_TYPE searchValue, POSITION startAfter = NULL) const
     {
         MYNODE *n = internalList;
-        if (startAfter) n = ((MYNODE *) startAfter) -> next;
+        if (startAfter) n = ((MYNODE *) startAfter)->next;
         while (n)
         {
-            if (n -> data == searchValue)
+            if (n->data == searchValue)
             {
                 return(POSITION) n;
             }
-            n = n -> next;
+            n = n->next;
         }
         return(POSITION) 0;
-        };
+    }
     POSITION FindIndex(int nIndex) const
     {
         MYNODE *n = internalList;
@@ -414,7 +405,7 @@ class CList: public wxObject
         {
             if (n)
             {
-                n = n -> next;
+                n = n->next;
             }
             else
             {
@@ -423,7 +414,7 @@ class CList: public wxObject
             }
         }
         return(POSITION) n;
-        };
+    }
 };
 
 class CPtrList;
@@ -434,8 +425,7 @@ class CTypedPtrList: public CList < TYPE, TYPE >
 {
     public:
     CTypedPtrList(int nBlockSize = 0)
-    {
-        };
+    { }
 };
 
 #include <stdarg.h>
@@ -444,49 +434,39 @@ class CString: public wxString
 {
     public:
     CString(): wxString()
-    {
-        };
-    CString(wxChar *ptr)
+    { }
+    CString(const wxString& ptr)
     : wxString(ptr)
-    {
-        };
-    CString(const wxChar *ptr)
-    : wxString(ptr)
-    {
-        };
+    { }
+
+    CString(const wxChar* ptr)
+    : wxString(ptr, *wxConvCurrent)
+    { }
+
     const char *GetBuffer()
     {
         return(const char *) GetData();
-        };
+    }
     int GetLength() const
     {
         return Length();
-        };
+    }
     void Format(const wxChar *pszFormat, ...)
     {
         va_list argptr;
         va_start(argptr, pszFormat);
         PrintfV(pszFormat, argptr);
         va_end(argptr);
-        };
-    int Find(CString what) const
-    {
-        return wxString:: Find(what);
-        };
-    CString Mid(int from, int len)
-    {
-        return CString(wxString:: Mid(from, len) .GetData());
-        };
-    CString &operator = (wxString &src)
-    {
-        if (this != &src)
-        {
-            Clear();
-            Append(src.GetData());
-        }
-        return *this;
     }
-    CString &operator = (wxString src)
+    int Find(const CString& what) const
+    {
+        return wxString::Find(what);
+    }
+    CString Mid(const int& from, const int& len)
+    {
+        return CString(wxString::Mid(from, len));
+    }
+    CString &operator = (const wxString& src)
     {
         if (this != &src)
         {
@@ -509,29 +489,28 @@ class CStringList: public stringList
 {
     public:
     CStringList(int nblocks = 0)
-    {
-        };
+    { }
     POSITION GetHeadPosition()
     {
         return(POSITION) GetFirst();
-        };
+    }
     CString GetNext(POSITION &pos)
     {
-        stringList:: Node *nod = (stringList:: Node *) pos;
-        CString retval = * (nod -> GetData());
-        nod = nod -> GetNext();
+        stringList::Node *nod = (stringList::Node *) pos;
+        CString retval = * (nod->GetData());
+        nod = nod->GetNext();
         pos = (POSITION) nod;
         return retval;
-        };
+    }
     CString GetAt(POSITION pos)
     {
-        stringList:: Node *nod = (stringList:: Node *) pos;
-        return * (nod -> GetData());
+        stringList::Node *nod = (stringList::Node *) pos;
+        return * (nod->GetData());
     }
 };
 
 // default hasher
-template < class ARG_KEY >
+template <class ARG_KEY>
 unsigned int HashKey(ARG_KEY key)
 {
     return((unsigned int)(void *)(unsigned long) key);
@@ -544,8 +523,7 @@ class CMap: public wxObject
     VoidHash internalHash;
     public:
     CMap(int blocks = 0)
-    {
-        };
+    { }
     ~CMap()
     {
         internalHash.clear();
@@ -560,32 +538,32 @@ class CMap: public wxObject
     }
     bool Lookup(ARG_KEY key, VALUE &value)
     {
-        VoidHash:: iterator it = internalHash.find(HashKey(key));
+        VoidHash::iterator it = internalHash.find(HashKey(key));
         if (it != internalHash.end())
         {
-            value = (VALUE)((unsigned long) it -> second);
+            value = (VALUE)((unsigned long) it->second);
             return true;
         }
         else return false;
-        };
+    }
     void SetAt(ARG_KEY key, ARG_VALUE newValue)
     {
         internalHash[HashKey(key) ] = (void *)((unsigned long) newValue);
-        };
+    }
     VALUE &operator[] (ARG_KEY key)
     {
         return(VALUE &) internalHash[HashKey(key) ];
-        };
+    }
     bool RemoveKey(ARG_KEY key)
     {
         int x = internalHash.erase(HashKey(key));
         if (x) return true;
         else return false;
-        };
+    }
     void RemoveAll()
     {
         internalHash.clear();
-        };
+    }
     POSITION GetStartPosition() /*const*/
     {
         if (internalHash.empty())
@@ -597,11 +575,11 @@ class CMap: public wxObject
             positioner.it = internalHash.begin();
             return(POSITION) &positioner;
         }
-        };
+    }
     void GetNextAssoc(POSITION &nextPos, VALUE &val)
     {
-        VoidHash:: iterator it = nextPos -> it;
-        val = (VALUE) it -> second;
+        VoidHash::iterator it = nextPos->it;
+        val = (VALUE) it->second;
         it++;
         if (it != internalHash.end())
         {
@@ -615,9 +593,9 @@ class CMap: public wxObject
     }
     void GetNextAssoc(POSITION &nextPos, KEY &key, VALUE &val)
     {
-        VoidHash:: iterator it = nextPos -> it;
-        key = (KEY) it -> first;
-        val = (VALUE) it -> second;
+        VoidHash::iterator it = nextPos->it;
+        key = (KEY) it->first;
+        val = (VALUE) it->second;
         it++;
         if (it != internalHash.end())
         {
@@ -628,18 +606,18 @@ class CMap: public wxObject
         {
             nextPos = 0;
         }
-        };
+    }
     unsigned int GetHashTableSize() const
     {
         return 1024;
-        };
+    }
     void InitHashTable(unsigned int size, bool allocnow = true)
     {
         // nothing here
     }
     ;
     private:
-    VoidHash:: const_iterator myit;
+    VoidHash::const_iterator myit;
     _POSITION positioner;
 };
 
@@ -650,8 +628,7 @@ class CArray: public wxObject
     VoidArray intArr;
     public:
     CArray()
-    {
-        };
+    { }
     ~CArray()
     {
         intArr.Empty();
@@ -659,48 +636,48 @@ class CArray: public wxObject
     int GetSize() const
     {
         return intArr.GetCount();
-        };
+    }
     int GetCount() const
     {
         return intArr.GetCount();
-        };
+    }
     int GetUpperBound() const
     {
         return intArr.GetCount() + 1;
-        };
+    }
     void SetSize(int newsiz, int growby = - 1)
     {
         intArr.Alloc(newsiz);
-        };
+    }
     bool IsEmpty() const
     {
         return intArr.IsEmpty();
-        };
+    }
     void RemoveAll()
     {
         intArr.Empty();
-        };
+    }
     void RemoveAt(int nIndex)
     {
         intArr.RemoveAt(nIndex);
-        };
+    }
     TYPE GetAt(int nIndex) const
     {
         return(TYPE) intArr.Item(nIndex);
-        };
+    }
     void SetAt(int nIndex, ARG_TYPE newElem)
     {
         intArr[nIndex] = (void *) newElem;
-        };
+    }
     TYPE &ElementAt(int nIndex)
     {
         return(TYPE &) intArr.Item(nIndex);
-        };
+    }
     int Add(ARG_TYPE newElem)
     {
         intArr.Add((void *)((unsigned long) newElem));
         return 0;
-        };
+    }
     void InsertAt(int nIndex, ARG_TYPE newElem)
     {
         intArr.Insert((void *) newElem, nIndex, 1);
@@ -708,11 +685,11 @@ class CArray: public wxObject
     TYPE operator[] (int nIndex) const
     {
         return(TYPE) intArr[nIndex];
-        };
+    }
     TYPE &operator[] (int nIndex)
     {
         return(TYPE &) intArr[nIndex];
-        };
+    }
 };
 
 #endif
