@@ -1,23 +1,23 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
 #	include "xmule-headers.h"
@@ -31,27 +31,26 @@
 #	include "xmule.h"
 #endif
 
+#include <map>                              // Needed for std::map
+
 #include <wx/utils.h>
 #include <wx/file.h>                    // Needed for wxFile
 
-#include "strings.en"
-
 #define itemsof(x) (sizeof(x)/sizeof(x[0]))
 
-CString GetResString(UINT uStringID)
+wxString GetResString(unsigned int uStringID)
 {
-#if 0
-    return GetResString(uStringID, theApp.glob_prefs -> GetLanguageID());
-#endif  // WTF is this ? PLK
-    int i;
-    for (i = 0 ; i < itemsof(_resStrings) ; i++)
+    static std::map<unsigned int, wxString> msgs;
+
+    if (msgs.empty())
     {
-        if (_resStrings[i].id == uStringID)
+#include "strings.en"
+        for (unsigned int a = 0; a < itemsof(_resStrings); ++a)
         {
-            return CString(wxGetTranslation(_resStrings[i].resstr));
-        }
+            msgs[_resStrings[a].id] = wxString(_resStrings[a].resstr, *wxConvCurrent);
+        }        
     }
-    return "This String is Needen ";
+    return msgs[uStringID];
 }
 
 // Base chars for encode an decode functions
@@ -172,7 +171,7 @@ CString CastItoXBytes(uint64 count)
     {
         buffer.Format("%.2f %s", (float) count/1048576, GetResString(IDS_MBYTES) .GetData());
     }
-    else if(count < 1099511627776LL)
+    else if (count < 1099511627776LL)
     {
         buffer.Format("%.2f %s", (float) count/1073741824, GetResString(IDS_GBYTES) .GetData());
     }
@@ -192,19 +191,19 @@ CString CastItoIShort(uint64 count)
     }
     else if(count < 1000000)
     {
-        output.Format("%.0f%s", (float) count/1000, GetResString(IDS_KILO) .GetBuffer());
+        output.Format("%.0f%s", (float) count/1000, GetResString(IDS_KILO) .GetData());
     }
     else if(count < 1000000000)
     {
-        output.Format("%.2f%s", (float) count/1000000, GetResString(IDS_MEGA) .GetBuffer());
+        output.Format("%.2f%s", (float) count/1000000, GetResString(IDS_MEGA) .GetData());
     }
     else if(count < 1000000000000LL)
     {
-        output.Format("%.2f%s", (float) count/1000000000LL, GetResString(IDS_GIGA) .GetBuffer());
+        output.Format("%.2f%s", (float) count/1000000000LL, GetResString(IDS_GIGA) .GetData());
     }
     else if(count < 1000000000000000LL)
     {
-        output.Format("%.2f%s", (float) count/1000000000000LL, GetResString(IDS_TERRA) .GetBuffer());
+        output.Format("%.2f%s", (float) count/1000000000000LL, GetResString(IDS_TERRA) .GetData());
     }
     return output;
 }
@@ -471,7 +470,7 @@ wxString GetFiletypeByName(wxString infile)
     return GetResString(IDS_SEARCH_ANY);
 }
 
-CString MakeStringEscaped(CString in)
+wxString MakeStringEscaped(wxString in)
 {
     in.Replace("&", "&&");
     return in;
@@ -488,7 +487,7 @@ bool Ask4RegFix(bool checkOnly)
     char modbuffer[490];
     char regbuffer[520];
     regkey.QueryStringValue(0, rbuffer, &maxsize);
-    :: GetModuleFileName(0, modbuffer, 490);
+    ::GetModuleFileName(0, modbuffer, 490);
     sprintf(regbuffer, "\"%s\" \"%%1\"", modbuffer);
     if (strcmp(rbuffer, regbuffer))
     {
@@ -507,6 +506,7 @@ bool Ask4RegFix(bool checkOnly)
     regkey.Close();
     return false;
 #endif
+    return true;
 }
 
 int GetMaxConnections()
@@ -711,7 +711,7 @@ void UpdateURLMenu(CMenu &menu, int &counter)
     CString name, url, sbuffer;
     char buffer[1024];
     int lenBuf = 1024;
-    FILE *readFile = fopen(CString(theApp.glob_prefs -> GetAppDir()) + "webservices.dat", "r");
+    FILE *readFile = fopen(CString(theApp.glob_prefs->GetAppDir()) + "webservices.dat", "r");
     if (readFile != NULL)
     {
         while (!feof(readFile))
@@ -739,15 +739,15 @@ void RunURL(CAbstractFile *file, CString urlpattern)
 {
 #if 0
     // Convert hash to hexadecimal text and add it to the URL
-    urlpattern.Replace("#hashid", EncodeBase16(file -> GetFileHash(), 16));
+    urlpattern.Replace("#hashid", EncodeBase16(file->GetFileHash(), 16));
     // Add file size to the URL
     CString temp;
-    temp.Format("%u", file -> GetFileSize());
+    temp.Format("%u", file->GetFileSize());
     urlpattern.Replace("#filesize", temp);
     // add filename to the url
-    urlpattern.Replace("#filename", URLEncode(file -> GetFileName()));
+    urlpattern.Replace("#filename", URLEncode(file->GetFileName()));
     // Open URL
-    ShellExecute(NULL, NULL, urlpattern, NULL, theApp.glob_prefs -> GetAppDir(), SW_SHOWDEFAULT);
+    ShellExecute(NULL, NULL, urlpattern, NULL, theApp.glob_prefs->GetAppDir(), SW_SHOWDEFAULT);
 #endif
 }
 
@@ -771,7 +771,7 @@ CString GetCatTitle(int catid)
     case 13: return GetResString(IDS_SEARCH_PICS);
     case 14: return GetResString(IDS_TEXT);
     }
-    return "?";
+    return CString("?");
 }
 
 bool CheckShowItemInGivenCat(CPartFile *file, int inCategory)
@@ -779,78 +779,78 @@ bool CheckShowItemInGivenCat(CPartFile *file, int inCategory)
     // easy normal cases
     bool IsInCat;
     bool IsNotFiltered = true;
-    IsInCat = ((inCategory == 0) || (inCategory > 0 &&inCategory == file -> GetCategory()));
-    if (theApp.glob_prefs -> GetAllcatType() > 0)
-    switch (theApp.glob_prefs -> GetAllcatType())
+    IsInCat = ((inCategory == 0) || (inCategory > 0 &&inCategory == file->GetCategory()));
+    if (theApp.glob_prefs->GetAllcatType() > 0)
+    switch (theApp.glob_prefs->GetAllcatType())
     {
     case 1:
         {
-            IsNotFiltered = ((file -> GetCategory() == 0) || (inCategory > 0));
+            IsNotFiltered = ((file->GetCategory() == 0) || (inCategory > 0));
             break;
         }
     case 2:
         {
-            IsNotFiltered = (file -> IsPartFile());
+            IsNotFiltered = (file->IsPartFile());
             break;
         }
     case 3:
         {
-            IsNotFiltered = (!file -> IsPartFile());
+            IsNotFiltered = (!file->IsPartFile());
             break;
         }
     case 4:
         {
-            IsNotFiltered = ((file -> GetStatus() == PS_READY || file -> GetStatus() == PS_EMPTY) &&file -> GetTransferingSrcCount() == 0);
+            IsNotFiltered = ((file->GetStatus() == PS_READY || file->GetStatus() == PS_EMPTY) &&file->GetTransferingSrcCount() == 0);
             break;
         }
     case 5:
         {
-            IsNotFiltered = ((file -> GetStatus() == PS_READY || file -> GetStatus() == PS_EMPTY) &&file -> GetTransferingSrcCount() > 0);
+            IsNotFiltered = ((file->GetStatus() == PS_READY || file->GetStatus() == PS_EMPTY) &&file->GetTransferingSrcCount() > 0);
             break;
         }
     case 6:
         {
-            IsNotFiltered = (file -> GetStatus() == PS_ERROR);
+            IsNotFiltered = (file->GetStatus() == PS_ERROR);
             break;
         }
     case 7:
         {
-            IsNotFiltered = ((file -> GetStatus() == PS_PAUSED) && (!file -> IsStopped()));
+            IsNotFiltered = ((file->GetStatus() == PS_PAUSED) && (!file->IsStopped()));
             break;
         }
     case 8:
         {
-            IsNotFiltered = file -> IsStopped();
+            IsNotFiltered = file->IsStopped();
             break;
         }
     case 9:
         {
-            IsNotFiltered = file -> IsMovie();
+            IsNotFiltered = file->IsMovie();
             break;
         }
     case 10:
         {
-            IsNotFiltered = file -> IsSound();
+            IsNotFiltered = file->IsSound();
             break;
         }
     case 11:
         {
-            IsNotFiltered = file -> IsArchive();
+            IsNotFiltered = file->IsArchive();
             break;
         }
     case 12:
         {
-            IsNotFiltered = file -> IsCDImage();
+            IsNotFiltered = file->IsCDImage();
             break;
         }
     case 13:
         {
-            IsNotFiltered = file -> IsImage();
+            IsNotFiltered = file->IsImage();
             break;
         }
     case 14:
         {
-            IsNotFiltered = file -> IsText();
+            IsNotFiltered = file->IsText();
             break;
         }
     }
@@ -912,12 +912,12 @@ bool BackupFile(const wxString &filename, const wxString &appendix)
 // It's primary purpose is to ignore chmod()s on FAT32 partitions
 bool SafeCopyFile(const wxString &file1, const wxString &file2)
 {
-    wxFile fileIn(file1, wxFile:: read);
+    wxFile fileIn(file1, wxFile::read);
     if (!fileIn.IsOpened())
     {
         //		return FALSE;// for copying it the file could be open too!!
     }
-    wxFile fileOut(file2, wxFile:: write);
+    wxFile fileOut(file2, wxFile::write);
     char buf[4096];
     size_t count;
     while (true)
