@@ -1,33 +1,31 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
-//
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifndef OTHERFUNS_H
 #define OTHERFUNS_H
 
-#include "mfc.h"
-#include "types.h"
-#include "wintypes.h"
-
-#include <math.h>
-#include <sys/time.h>
+#include "mfc.h"                        // Needed for CString
+#include "types.h"                      // Needed for uint64
+#include "wintypes.h"                   // Needed for WORD
+#include <sys/time.h>                   // Needed for gettimeofday
 
 #define ROUND(x) (floor((float)x+0.5f))
 
@@ -38,15 +36,12 @@
 #define _WINVER_2K_		0x0005
 #define _WINVER_XP_		0x0105
 
-#include <wx/string.h>
-
 CString CastItoXBytes(uint64 count);
 CString CastItoIShort(uint64 number);
 CString CastSecondsToHM(sint32 seconds); //<<--9/21/02
 CString LeadingZero(uint32 units);
 void ShellOpenFile(CString name); //<<--9/21/02
-CString GetResString(UINT uStringID);//<<--10/01/02
-CString GetResString(UINT uStringID,WORD languageID);
+wxString GetResString(unsigned int uStringID);//<<--10/01/02
 void MakeFoldername(char* path);
 
 void URLDecode(wxString& result, const char* buff);// Make a malloc'd decoded strnig from an URL encoded string (with escaped spaces '%20' and  the like
@@ -58,7 +53,7 @@ bool Ask4RegFix(bool checkOnly, bool dontAsk = false); // Barry - Allow forced u
 void BackupReg(void); // Barry - Store previous values
 void RevertReg(void); // Barry - Restore previous values
 int GetMaxConnections();
-CString MakeStringEscaped(CString in);
+wxString MakeStringEscaped(wxString in);
 //void RunURL(CAbstractFile* file,CString urlpattern);
 void HexDump(const void *buffer, unsigned long buflen);
 bool BackupFile(const wxString& filename, const wxString& appendix);
