@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -59,15 +59,11 @@
 #define IDS_HTTPDOWNLOAD_BYTESPERSECOND 128
 #define IDR_MAINFRAME                   129
 #define IDS_HTTPDOWNLOAD_KILOBYTESPERSECOND 129
-#define IDD_TRANSFER                    130
 #define IDS_HTTPDOWNLOAD_OK_TO_OVERWRITE 130
-#define IDD_SERVER                      131
 #define IDS_HTTPDOWNLOAD_FAIL_FILE_OPEN 131
 #define IDS_HTTPDOWNLOAD_ABORTING_TRANSFER 132
 #define IDD_TRANSFER1                   133
-#define IDD_FILES                       133
 #define IDS_MAIN_READY                  133
-#define IDD_SEARCH                      134
 #define IDD_SEARCHDLG                   134
 #define IDS_MAIN_SOCKETERROR            134
 #define IDS_MAIN_BTN_DISCONNECT         135
@@ -105,7 +101,6 @@
 #define IDS_ERR_FILEOPEN                152
 #define IDD_HTTPDOWNLOAD                153
 #define IDS_ERR_REHASH                  153
-#define IDD_CHAT                        154
 #define IDS_ERR_PART_FNF                154
 #define IDS_ERR_OPENMETFILE             155
 #define IDR_HTTPDOWNLOAD_ANIMATION      156
@@ -119,7 +114,6 @@
 #define IDS_ICHWORKED                   160
 #define IDI_CONNECTEDHIGH               161
 #define IDS_ERR_OUTOFSPACE              161
-#define IDD_SOURCEDETAILWND             162
 #define IDS_ERR_WRITEERROR              162
 #define IDI_COMPPROT                    163
 #define IDS_ERR_COMPLETIONFAILED        163
@@ -270,15 +264,10 @@
 #define IDS_SHAREDFILES                 288
 #define IDS_PRIOVERYLOW                 289
 #define IDS_PRIORELEASE                 290
-#define IDD_PPG_CONNECTION              290
 #define IDS_FSTATUS_LOCKED              291
-#define IDD_PPG_DIRECTORIES             291
 #define IDS_FSTATUS_FRIENDSONLY         292
-#define IDD_PPG_FILES                   292
 #define IDS_FSTATUS_PUBLIC              293
-#define IDD_PPG_GENERAL                 293
 #define IDS_PRIOHIGHEST                 294
-#define IDD_PPG_SERVER                  294
 #define IDS_ERR_NOPRIMCHANGE            295
 #define IDS_HIDDEN                      296
 #define IDS_FSTAT_TRANSFER              297
@@ -605,7 +594,6 @@
 #define IDS_STREE                       595
 #define IDD_STATSSETUP                  596
 #define IDS_STATSSETUPINFO              596
-#define IDD_PPG_STATS                   596
 #define IDS_HARDLIMIT                   597
 #define IDS_COL_MORECOLORS              598
 #define IDS_KBYTESEC                    599
@@ -746,9 +734,7 @@
 #define IDS_WIZARD_ENTERBELOW           719
 #define IDI_PREF_TWEAK                  719
 #define IDS_STATS_MAXAVGDL              720
-#define IDD_COMMENT                     720
 #define IDS_STATS_MAXDL                 721
-#define IDD_COMMENTLST                  721
 #define IDS_PW_FASTSRVCON               722
 #define IDS_SOURCELINKFAILED            723
 #define IDI_CLOSE                       723
@@ -1323,7 +1309,6 @@
 //#define IDC_S1                          2112
 //#define IDC_S3                          2113
 //#define IDC_S2                          2114
-#define IDD_STATISTICS                  2115
 #define IDC_STATIC7                     2115
 //#define IDC_C0_2                        2115
 #define IDC_STATIC_S0                   2116
@@ -1516,16 +1501,13 @@
 #define IDC_SEEMYSHARE_FRM              2254
 #define IDC_MESSAGES_LBL                2255
 #define IDC_SETUPBUTTON                 2256
-#define IDD_PPG_NOTIFY                  2256
 #define IDC_SLIDERINFO3                 2257
 #define IDC_EDIT_TBN_WAVFILE            2257
-#define IDD_PPG_IRC                     2257
 #define IDC_GRAPHS                      2258
 #define IDC_CB_TBN_ONLOG                2258
 #define IDD_WIZARD                      2258
 #define IDC_STREE                       2259
 #define IDC_CB_TBN_POP_ALWAYS           2259
-#define IDD_PPG_TWEAKS                  2259
 #define IDC_KBS1                        2260
 #define IDD_ADDFRIEND                   2260
 #define IDC_KBS2                        2261
@@ -1719,7 +1701,6 @@
 #define IDI_ICON8                       2425
 #define IDI_PREF_DISPLAY                2426
 #define IDD_PPG_DISPLAY                 2427
-#define IDD_CAT                         2428
 #define IDR_TASKBAR                     2429
 #define IDI_PREF_SECURITY               2430
 #define IDD_PPG_SECURITY                2431
@@ -1756,8 +1737,6 @@
 
 #define ID_SOKETTI 7772
   
-#define IDD_PPG_SOURCES_DROPPING 12743
-#define IDD_PPG_GUI_TWEAKS 12744
 #define IDC_ENABLE_AUTO_NNS 12745
 #define IDC_AUTO_NNS_TIMER_TEXT 12746
 #define IDC_AUTO_NNS_TIMER 12747
@@ -1796,3 +1775,4 @@
 #define _APS_NEXT_SYMED_VALUE           106
 #endif
 #endif
+
