@@ -1,36 +1,31 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 // Client to Server communication
 
 #ifndef _SOCKETS_H
 #define _SOCKETS_H
 
-#include "wintypes.h"
-#include "types.h"
-#include "server.h"
-#include "packets.h"
-#include "ServerListCtrl.h"
-#include "Preferences.h"
-#include "server.h"
-#include "ServerList.h"
-#include "Preferences.h"
-//#include "ServerSocket.h"
-#include <wx/socket.h>
+#include "server.h"                     // Needed for CServer
+#include "ServerList.h"                 // Needed for CServerList
 
 #define CS_FATALERROR	-5
 #define CS_DISCONNECTED	-4
@@ -67,7 +62,7 @@ public:
 	bool	Disconnect();
 	bool	IsConnecting()	{return connecting;}
 	bool	IsConnected()	{return connected;}
-	uint32	GetClientID()		{return clientid;}
+	wxUint32	GetClientID()		{return clientid;}
 	CServer*	GetCurrentServer();
 	uint32	clientid;
 	uint8	pendingConnects;
@@ -76,6 +71,8 @@ public:
 	bool	IsLocalServer(uint32 dwIP, uint16 nPort);
 	void	TryAnotherConnectionrequest();
 	bool	IsSingleConnect()	{return singleconnecting;}
+	void	InitLocalIP();
+	wxUint32	GetLocalIP()		{ return m_nLocalIP; }
 
 private:
 	bool	connecting;
@@ -90,7 +87,15 @@ private:
 	CTypedPtrList<CPtrList,void*>		m_lstOpenSockets;	// list of currently opened sockets
 	//UINT			m_idRetryTimer;
 	wxTimer m_idRetryTimer;
+	wxUint32 	m_nLocalIP;
 
 	CMap<ULONG ,ULONG&,CServerSocket*,CServerSocket*> connectionattemps;
+// Added by sivka [Tarod: Tries after a LowID connection]
+public: 
+	void	ResetLowIDTries() {m_lowid_tries = 0;}
+	int	GetLowIDTries() {return m_lowid_tries;}
+	void	IncrementLowIDTries() {m_lowid_tries++;}
+private:
+	int	m_lowid_tries;
 };
 #endif
