@@ -1,36 +1,43 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+// Some worthless comment to commemorate how Avi Vahl single-handedly 
+// brought cvs down to a crashing halt (well just a little overstated)
+// by trying to rename this file using cvs in Win32 :o 
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// See https://gna.org/support/?func=detailitem&item_id=201 for details.
+// Avi, we love you :-))
 
 #ifndef _UPDOWNCLIENT_H
 #define _UPDOWNCLIENT_H
 
-#include "wintypes.h"
-#include "types.h"
-#include "ListenSocket.h"
-//#include "PartFile.h"
-#include "ClientCredits.h"
-#include "SafeFile.h"
-#include "BarShader.h"
-#include "otherfunctions.h"
+#include "otherstructs.h"               // Needed for Requested_Block_Struct
+#include "EMSocket.h"
+#include "ListenSocket.h"               // Needed for CClientReqServer
+//#include "ClientCredits.h"              // Needed for CClientCredits
+class CClientCredits;
+#include "otherfunctions.h"             // Needed for GetTickCount
+#include <wx/dcmemory.h>                // Needed for wxMemoryDC
 
+class CBarShader;
 class CPartFile;
 class CKnownFile;
 typedef unsigned char byte;
@@ -79,21 +86,21 @@ enum EClientSoftware {
 	SO_MLDONKEY			= 52,
 	SO_OLDEMULE			= 53,
 	SO_UNKNOWN			= 54,
-	SO_NEW_MLDONKEY			= 152,
+	SO_NEW_MLDONKEY			= 152
 };
-#define L 3
+
 enum ESecureIdentState {
 	IS_UNAVAILABLE = 0,
 	IS_ALLREQUESTSSEND = 0,
 	IS_SIGNATURENEEDED = 1,
-	IS_KEYANDSIGNEEDED =2,
+	IS_KEYANDSIGNEEDED = 2
 };
 
 enum EInfoPacketState {
 	IP_NONE = 0,
 	IP_EDONKEYPROTPACK = 1,
 	IP_EMULEPROTPACK = 2,
-	IP_BOTH = 3,
+	IP_BOTH = 3
 };
 
 class CClientReqSocket;
@@ -247,8 +254,8 @@ public:
 	bool			IsUpPartAvailable(uint16 iPart) {return ( (iPart
  >= m_nUpPartCount) || (!m_abyUpPartStatus) )? 0:m_abyUpPartStatus[iPart];}
 	uint8*			GetPartStatus()				{return m_abyPartStatus;}
-	uint32			GetDownloadDatarate()		{return m_nDownDatarate;}
-	uint16			GetRemoteQueueRank()		{return m_nRemoteQueueRank;}
+	uint32			GetDownloadDatarate()		{ return m_nDownDatarate; }
+	uint16			GetRemoteQueueRank()		{ return m_nRemoteQueueRank; }
 	void			SetRemoteQueueFull( bool flag )	{m_bRemoteQueueFull = flag;}
 	bool			IsRemoteQueueFull()			{return m_bRemoteQueueFull;}
 	void			SetRemoteQueueRank(uint16 nr);
@@ -297,14 +304,13 @@ public:
 	int  GetFileListRequested() { return m_iFileListRequested; }
 	void SetFileListRequested(int iFileListRequested) { m_iFileListRequested = iFileListRequested; }
 	uint8	m_cFailed;
-    bool deletethis;
 
 private:
 	CPartFile*		reqfile;
 
 	// base
 	void	Init();
-	bool	ProcessHelloTypePacket(CSafeMemFile* data);
+	bool	ProcessHelloTypePacket(CMemFile* data);
 	void	SendHelloTypePacket(CMemFile* data);
 	bool	m_bIsBotuser;
 //	bool	isfriend;
