@@ -1,43 +1,30 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
-//
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 
-// xmuleDlg.h : Headerdatei
-//
-#ifndef EMULEDLG_H
-#define EMULEDLG_H
+#ifndef XMULEDLG_H
+#define XMULEDLG_H
 
-/*#include "sockets.h"
-#include "ServerListCtrl.h"
-#include "KnownFileList.h"
-#include "TransferWnd.h"
-#include "ServerWnd.h"
-#include "PreferencesDlg.h"
-#include "SharedFilesWnd.h"
-#include "SearchDlg.h"
-#include "ChatWnd.h"
-#include "StatisticsDlg.h"
-#include "SysTray.h"*/
-#include "resource.h"
-#include "types.h"
+#include "resource.h"                   // Needed for IDD_EMULE_DIALOG
+#include "types.h"                      // Needed for uint32
 
 class CTransferWnd;
 class CServerWnd;
@@ -82,7 +69,6 @@ public:
 
 //	void			AddLogLine(bool addtostatusbar,char* line,...);
 	void			AddLogLine(bool addtostatusbar,const wxChar* line,...);
-	void			AddDebugLogLine(bool addtostatusbar,const wxChar* line,...);
 	void			AddServerMessageLine(char* line,...);
 	void			ShowConnectionState(bool connected);
 	void			ShowConnectionState(bool connected,wxString server,bool iconOnly=false);
@@ -126,14 +112,8 @@ protected:
 	void OnSocketTimer(wxTimerEvent& evt);
 	void OnQLTimer(wxTimerEvent& evt);
 
-	void btnServers(wxEvent& ev);
-	void btnSearch(wxEvent& ev);
-	void btnTransfer(wxEvent& ev);
+	void OnToolClick(wxCommandEvent& event);
 	void btnPreferences(wxEvent& ev);
-	void btnFlowChart(wxEvent& ev);
-	void OnBnShared(wxEvent& ev);
-	void OnBnStats(wxEvent& ev);
-	void OnBnMessages(wxEvent& ev);
 
  public:
 	void OnFinishedHashing(wxCommandEvent& evt);
@@ -172,12 +152,13 @@ protected:
 	void		 OnClose();
 	DECLARE_MESSAGE_MAP()
 	*/
-	void OnBnConnect(wxEvent& evt);
+	void OnBnConnect();
 	void OnClose(wxCloseEvent& evt);
 
 	/* Public function to check which tab is active. Needed to check what to redraw. */
 	int GetActiveDialog()	{return m_nActiveDialog;}
 private:
+    void ShutDown();
         void MinimizeDlg(wxIconizeEvent& event);
 	wxString			logtext;
 	bool			ready;	
@@ -213,7 +194,7 @@ private:
 	void CloseConnection();
 	void RestoreWindow();
 	void UpdateTrayIcon(int procent);
-    void shutdown();
+
 	int m_nActiveDialog;	
 public:
     int split_pos;
